@@ -53,6 +53,7 @@
 #include "utils/Constants.hpp"
 #include "components/other/desktop-tools/DesktopTools.hpp"
 
+#include "components/settings/EmojisSettingsModel.hpp"
 #include "components/timeline/TimelineModel.hpp"
 #include "components/timeline/TimelineListModel.hpp"
 #include "components/timeline/TimelineProxyModel.hpp"
@@ -165,34 +166,60 @@ static inline string getConfigPathIfExists (const QCommandLineParser &parser) {
 	return configPath;
 }
 
-bool App::setFetchConfig (QCommandLineParser *parser) {
-	bool fetched = false;
-	QString filePath = parser->value("fetch-config");
+QString App::getFetchConfig (QString filePath, bool * error) {
+	*error = false;
 	if( !filePath.isEmpty()){
 		if(QUrl(filePath).isRelative()){// this is a file path
 			filePath = Utils::coreStringToAppString(Paths::getConfigFilePath(filePath, false));
 			if(!filePath.isEmpty())
 				filePath = "file://"+filePath;
 		}
-		if(!filePath.isEmpty()){
-			auto instance = CoreManager::getInstance();
-			if(instance){
-				auto core = instance->getCore();
-				if(core){
-					filePath.replace('\\','/');
-					if(core->setProvisioningUri(Utils::appStringToCoreString(filePath)) == 0){
-						parser->process(cleanParserKeys(parser, QStringList("fetch-config")));// Remove this parameter from the parser
-						fetched = true;
-					}else
-						fetched = false;
-				}
-			}
-		}
-		if(!fetched){
+		if(filePath.isEmpty()){
 			qWarning() <<"Remote provisionning cannot be retrieved. Command have beend cleaned";
-			createParser();
+			*error = true;
 		}
 	}
+	return filePath;
+}
+
+QString App::getFetchConfig (QCommandLineParser *parser) {
+	QString filePath = parser->value("fetch-config");
+	bool error = false;
+	filePath = getFetchConfig(filePath, &error);
+	if(error) {
+		qWarning() <<"Remote provisionning cannot be retrieved. Command have beend cleaned";
+		createParser();
+	}else if( !filePath.isEmpty())
+		mParser->process(cleanParserKeys(mParser, QStringList("fetch-config")));// Remove this parameter from the parser
+	return filePath;
+}
+
+void App::useFetchConfig(const QString& filePath){
+	if( !filePath.isEmpty()){
+		if(CoreManager::getInstance()->getSettingsModel()->getAutoApplyProvisioningConfigUriHandlerEnabled())
+			setFetchConfig(filePath);
+		else
+			emit requestFetchConfig(filePath);
+	}
+}
+
+bool App::setFetchConfig (QString filePath) {
+	bool fetched = false;
+	qDebug() << "setFetchConfig with " << filePath;
+	if(!filePath.isEmpty()){
+		auto instance = CoreManager::getInstance();
+		if(instance){
+			auto core = instance->getCore();
+			if(core){
+				filePath.replace('\\','/');
+				fetched = core->setProvisioningUri(Utils::appStringToCoreString(filePath)) == 0;
+			}
+		}
+	}
+	if(!fetched){
+		qWarning() <<"Remote provisionning cannot be retrieved. Command have beend cleaned";
+	}else
+		restart();
 	return fetched;
 }
 // -----------------------------------------------------------------------------
@@ -234,6 +261,8 @@ App::App (int &argc, char *argv[]) : SingleApplication(argc, argv, true, Mode::U
 	
 	if (mParser->isSet("verbose"))
 		Logger::getInstance()->setVerbose(true);
+	if (mParser->isSet("qt-logs-only"))
+		Logger::getInstance()->enableQtOnly(true);
 	
 	// List available locales.
 	for (const auto &locale : QDir(Constants::LanguagePath).entryList())
@@ -254,7 +283,14 @@ App::App (int &argc, char *argv[]) : SingleApplication(argc, argv, true, Mode::U
 	mAutoStart = autoStartEnabled();
 	
 	qInfo() << QStringLiteral("Starting " APPLICATION_NAME " (bin: " EXECUTABLE_NAME ")");
-	qInfo() << QStringLiteral("Use locale: %1").arg(mLocale);
+	qInfo() << QStringLiteral("Use locale: %1 with language: %2").arg(mLocale.name()).arg(QLocale::languageToString(mLocale.language()));
+	
+	// Deal with received messages and CLI.
+	QObject::connect(this, &App::receivedMessage, this, [](int, const QByteArray &byteArray) {
+		QString command(byteArray);
+		qInfo() << QStringLiteral("Received command from other application: `%1`.").arg(command);
+		Cli::executeCommand(command);
+	});
 }
 
 App::~App () {
@@ -300,6 +336,7 @@ void App::processArguments(QHash<QString,QString> args){
 }
 
 static QQuickWindow *createSubWindow (QQmlApplicationEngine *engine, const char *path) {
+	QString qPath(path);
 	qInfo() << QStringLiteral("Creating subwindow: `%1`.").arg(path);
 	
 	QQmlComponent component(engine, QUrl(path));
@@ -315,12 +352,29 @@ static QQuickWindow *createSubWindow (QQmlApplicationEngine *engine, const char
 	QQmlEngine::setObjectOwnership(object, QQmlEngine::CppOwnership);
 	object->setParent(engine);
 	
-	return qobject_cast<QQuickWindow *>(object);
+	
+	int totalDuration = 0;
+	int loops = 0;
+	QElapsedTimer timer;
+	timer.start();
+	auto window = qobject_cast<QQuickWindow *>(object);
+	QObject::connect(window, &QQuickWindow::beforeRendering, [totalDuration, loops, timer, path]() mutable{
+		totalDuration += timer.elapsed();
+		++loops;
+		if (totalDuration > 10*1000) {
+			qDebug() << path << " : " << (1000.0 * loops) / totalDuration << "fps";
+			totalDuration = 0;
+			loops = 0;
+		}
+		timer.restart();
+	});
+	return window;
 }
 
 // -----------------------------------------------------------------------------
 
 void App::initContentApp () {
+
 	std::string configPath;
 	shared_ptr<linphone::Config> config;
 	bool mustBeIconified = false;
@@ -329,7 +383,6 @@ void App::initContentApp () {
 	// Destroy qml components and linphone core if necessary.
 	if (mEngine) {
 		needRestart = false;
-		setFetchConfig(mParser);
 		setOpened(false);
 		qInfo() << QStringLiteral("Restarting app...");
 		
@@ -357,12 +410,7 @@ void App::initContentApp () {
 		// Don't quit if last window is closed!!!
 		setQuitOnLastWindowClosed(false);
 		
-		// Deal with received messages and CLI.
-		QObject::connect(this, &App::receivedMessage, this, [](int, const QByteArray &byteArray) {
-			QString command(byteArray);
-			qInfo() << QStringLiteral("Received command from other application: `%1`.").arg(command);
-			Cli::executeCommand(command);
-		});
+		
 		
 #ifndef Q_OS_MACOS
 		mustBeIconified = mParser->isSet("iconified");
@@ -425,7 +473,18 @@ void App::initContentApp () {
 #else
 	mEngine->rootContext()->setContextProperty("applicationLicence", "");
 #endif
-	mEngine->rootContext()->setContextProperty("copyrightRangeDate", COPYRIGHT_RANGE_DATE);
+#ifdef APPLICATION_LICENCE_URL
+	mEngine->rootContext()->setContextProperty("applicationLicenceUrl", APPLICATION_LICENCE_URL);
+#else
+	mEngine->rootContext()->setContextProperty("applicationLicenceUrl", "");
+#endif
+
+
+#ifdef COPYRIGHT_RANGE_DATE
+ 	mEngine->rootContext()->setContextProperty("copyrightRangeDate", COPYRIGHT_RANGE_DATE);
+#else
+	mEngine->rootContext()->setContextProperty("copyrightRangeDate", "");
+#endif
 	mEngine->rootContext()->setContextProperty("Colors", mColorListModel->getQmlData());
 	mEngine->rootContext()->setContextProperty("Images", mImageListModel->getQmlData());
 	
@@ -435,6 +494,7 @@ void App::initContentApp () {
 	registerSharedTypes();
 	registerToolTypes();
 	registerSharedToolTypes();
+	registerUninstalledModules();
 	
 	// Enable notifications.
 	mNotifier = new Notifier(mEngine);
@@ -448,8 +508,9 @@ void App::initContentApp () {
 				CoreManager::getInstance(),
 				&CoreManager::coreManagerInitialized, CoreManager::getInstance(),
 				[this, mustBeIconified]() mutable {
-		if(CoreManager::getInstance()->started())
+		if(CoreManager::getInstance()->started()) {
 			openAppAfterInit(mustBeIconified);
+		}	
 	}
 	);
 	
@@ -558,7 +619,8 @@ void App::createParser () {
 						#ifndef Q_OS_MACOS
 							{ "iconified", tr("commandLineOptionIconified") },
 						#endif // ifndef Q_OS_MACOS
-							{ { "V", "verbose" }, tr("commandLineOptionVerbose") }
+							{ { "V", "verbose" }, tr("commandLineOptionVerbose") },
+							{ "qt-logs-only", tr("commandLineOptionQtLogsOnly") },
 						});
 }
 
@@ -619,8 +681,8 @@ static inline void registerType (const char *name) {
 }
 
 template<typename T>
-static inline void registerToolType (const char *name) {
-	qmlRegisterSingletonType<T>(name, 1, 0, name, [](QQmlEngine *engine, QJSEngine *) -> QObject *{
+static inline void registerToolType (const char *name, const int &major_version = 1 , const int &minor_version = 0) {
+	qmlRegisterSingletonType<T>(name, major_version, minor_version, name, [](QQmlEngine *engine, QJSEngine *) -> QObject *{
 		return new T(engine);
 	});
 }
@@ -672,9 +734,11 @@ void App::registerTypes () {
 	registerType<HistoryProxyModel>("HistoryProxyModel");
 	registerType<LdapProxyModel>("LdapProxyModel");
 	registerType<ParticipantImdnStateProxyModel>("ParticipantImdnStateProxyModel");
+	registerType<RecordingProxyModel>("RecordingProxyModel");
 	registerType<SipAddressesProxyModel>("SipAddressesProxyModel");
 	registerType<SearchSipAddressesModel>("SearchSipAddressesModel");
 	registerType<SearchSipAddressesProxyModel>("SearchSipAddressesProxyModel");
+	registerType<TemporaryFile>("TemporaryFile");
 	registerType<TimeZoneProxyModel>("TimeZoneProxyModel");
 	
 	registerType<ColorProxyModel>("ColorProxyModel");
@@ -707,6 +771,7 @@ void App::registerTypes () {
 	registerUncreatableType<ContactsImporterModel>("ContactsImporterModel");
 	registerUncreatableType<ContentModel>("ContentModel");
 	registerUncreatableType<ContentListModel>("ContentListModel");
+	registerUncreatableType<FileMediaModel>("FileMediaModel");
 	registerUncreatableType<HistoryModel>("HistoryModel");
 	registerUncreatableType<LdapModel>("LdapModel");
 	registerUncreatableType<RecorderModel>("RecorderModel");
@@ -735,6 +800,7 @@ void App::registerSharedTypes () {
 	registerSharedSingletonType<App, &App::getInstance>("App");
 	registerSharedSingletonType<CoreManager, &CoreManager::getInstance>("CoreManager");
 	registerSharedSingletonType<SettingsModel, &CoreManager::getSettingsModel>("SettingsModel");
+	registerSharedSingletonType<EmojisSettingsModel, &CoreManager::getEmojisSettingsModel>("EmojisSettingsModel");
 	registerSharedSingletonType<AccountSettingsModel, &CoreManager::getAccountSettingsModel>("AccountSettingsModel");
 	registerSharedSingletonType<SipAddressesModel, &CoreManager::getSipAddressesModel>("SipAddressesModel");  
 	registerSharedSingletonType<CallsListModel, &CoreManager::getCallsListModel>("CallsListModel");
@@ -767,6 +833,11 @@ void App::registerSharedToolTypes () {
 	registerSharedToolType<ColorListModel,App,  &App::getColorListModel>("ColorsList");
 }
 
+void App::registerUninstalledModules() {
+	if(!isPdfAvailable())
+		qmlRegisterModule("QtQuick.Pdf",5,15);
+}
+
 // -----------------------------------------------------------------------------
 
 void App::setTrayIcon () {
@@ -779,10 +850,13 @@ void App::setTrayIcon () {
 		App::smartShowWindow(getSettingsWindow());
 	});
 	
-	QAction *updateCheckAction = new QAction(tr("checkForUpdates"), root);
-	root->connect(updateCheckAction, &QAction::triggered, root, [this] {
-		checkForUpdates(true);
-	});
+	QAction *updateCheckAction = nullptr;
+	if(SettingsModel::isCheckForUpdateAvailable()){
+		updateCheckAction = new QAction(tr("checkForUpdates"), root);
+		root->connect(updateCheckAction, &QAction::triggered, root, [this] {
+			checkForUpdates(true);
+		});
+	}
 	
 	QAction *aboutAction = new QAction(tr("about"), root);
 	root->connect(aboutAction, &QAction::triggered, root, [root] {
@@ -816,7 +890,8 @@ void App::setTrayIcon () {
 	menu->setTitle(APPLICATION_NAME);
 	// Build trayIcon menu.
 	menu->addAction(settingsAction);
-	menu->addAction(updateCheckAction);
+	if(updateCheckAction)
+		menu->addAction(updateCheckAction);
 	menu->addAction(aboutAction);
 	menu->addSeparator();
 	menu->addAction(restoreAction);
@@ -840,22 +915,34 @@ void App::initLocale (const shared_ptr<linphone::Config> &config) {
 	QString locale;
 	
 	// Use english. This default translator is used if there are no found translations in others loads
-	mLocale = Constants::DefaultLocale;
-	if (!installLocale(*this, *mDefaultTranslator, QLocale(mLocale)))
+	mLocale = QLocale(Constants::DefaultLocale);
+	if (!installLocale(*this, *mDefaultTranslator, mLocale))
 		qFatal("Unable to install default translator.");
 	
 	if (config)
 		locale = Utils::coreStringToAppString(config->getString(SettingsModel::UiSection, "locale", ""));
 	
 	if (!locale.isEmpty() && installLocale(*this, *mTranslator, QLocale(locale))) {
-		mLocale = locale;
+		mLocale = QLocale(locale);
 		return;
 	}
 	
-	// Try to use system locale.
-	QLocale sysLocale = QLocale(QLocale::system().name());// Use Locale from name because Qt has a bug where it didn't use the QLocale::language (aka : translator.language != lolcale.language) on Mac.
+// Try to use system locale.
+//#ifdef Q_OS_MACOS
+// Use this workaround if there is still an issue about detecting wrong language from system on Mac. Qt doesn't use the current system language on QLocale::system(). So we need to get it from user settings and overwrite its Locale.
+//	QSettings settings;
+//	QString preferredLanguage = settings.value("AppleLanguages").toStringList().first();
+//	QStringList qtLocale = QLocale::system().name().split('_');
+//	if(qtLocale[0] != preferredLanguage){
+//		qInfo() << "Override Qt language from " << qtLocale[0] << " to the preferred language : " << preferredLanguage;
+//		qtLocale[0] = preferredLanguage;
+//	}
+//	QLocale sysLocale = QLocale(qtLocale.join('_'));
+//#else
+	QLocale sysLocale(QLocale::system().name());// Use Locale from name because Qt has a bug where it didn't use the QLocale::language (aka : translator.language != locale.language) on Mac.
+//#endif
 	if (installLocale(*this, *mTranslator, sysLocale)) {
-		mLocale = sysLocale.name();
+		mLocale = sysLocale;
 		return;
 	}
 	
@@ -877,7 +964,7 @@ void App::setConfigLocale (const QString &locale) {
 	emit configLocaleChanged(locale);
 }
 
-QString App::getLocale () const {
+QLocale App::getLocale () const {
 	return mLocale;
 }
 
@@ -1033,37 +1120,35 @@ void App::openAppAfterInit (bool mustBeIconified) {
 	
 	checkForUpdates();
 #endif // ifdef ENABLE_UPDATE_CHECK
-	
-	if(setFetchConfig(mParser))
-		restart();
-	else{
-		// Launch call if wanted and clean parser
-		if( mParser->isSet("call") && coreManager->isLastRemoteProvisioningGood()){
-			QString sipAddress = mParser->value("call");
-			mParser->parse(cleanParserKeys(mParser, QStringList("call")));// Clean call from parser
-			if(coreManager->started()){
-				coreManager->getCallsListModel()->launchAudioCall(sipAddress);
-			}else{
-				QObject * context = new QObject();
-				QObject::connect(CoreManager::getInstance(), &CoreManager::coreManagerInitialized,context,
-								 [sipAddress,coreManager, context]() mutable {
-					if(context){
-						delete context;
-						context = nullptr;
-						coreManager->getCallsListModel()->launchAudioCall(sipAddress);
-					}
-				});
-			}
+	// Launch call if wanted and clean parser
+	if( mParser->isSet("call") && coreManager->isLastRemoteProvisioningGood()){
+		QString sipAddress = mParser->value("call");
+		mParser->parse(cleanParserKeys(mParser, QStringList("call")));// Clean call from parser
+		if(coreManager->started()){
+			coreManager->getCallsListModel()->launchAudioCall(sipAddress);
+		}else{
+			QObject * context = new QObject();
+			QObject::connect(CoreManager::getInstance(), &CoreManager::coreManagerInitialized,context,
+							 [sipAddress,coreManager, context]() mutable {
+				if(context){
+					delete context;
+					context = nullptr;
+					coreManager->getCallsListModel()->launchAudioCall(sipAddress);
+				}
+			});
 		}
-#ifndef __APPLE__
-		if (!mustBeIconified)
-			smartShowWindow(mainWindow);
-#else
-		Q_UNUSED(mustBeIconified);
-		smartShowWindow(mainWindow);
-#endif
-		setOpened(true);
 	}
+	QString fetchFilePath = getFetchConfig(mParser);
+	mustBeIconified = mustBeIconified && fetchFilePath.isEmpty();
+#ifndef __APPLE__
+	if (!mustBeIconified)
+		smartShowWindow(mainWindow);
+#else
+	Q_UNUSED(mustBeIconified);
+	smartShowWindow(mainWindow);
+#endif
+	setOpened(true);
+	useFetchConfig(fetchFilePath);
 }
 
 // -----------------------------------------------------------------------------
@@ -1094,3 +1179,11 @@ void App::checkForUpdates(bool force) {
 					Utils::appStringToCoreString(applicationVersion())
 					);
 }
+
+bool App::isPdfAvailable(){
+#ifdef PDF_ENABLED
+	return true;
+#else
+	return false;
+#endif
+}
