@@ -47,11 +47,7 @@ AppController::AppController (int &argc, char *argv[]) {
 	// Useful to share camera on Fullscreen (other context)
 	QApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
 	
-	// Do not use APPLICATION_NAME here.
-	// The EXECUTABLE_NAME will be used in qt standard paths. It's our goal.
-	QCoreApplication::setApplicationName(EXECUTABLE_NAME);
-	QApplication::setOrganizationDomain(EXECUTABLE_NAME);
-	QCoreApplication::setApplicationVersion(APPLICATION_SEMVER);
+	initQtAppDetails();
 #ifdef ENABLE_APP_WEBVIEW
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 	mApp = new App(argc, argv);
@@ -126,4 +122,12 @@ void AppController::stopApp(){
 	}
 	catch(...){
 	}
+}
+
+void AppController::initQtAppDetails(){
+	// Do not use APPLICATION_NAME here.
+	// The EXECUTABLE_NAME will be used in qt standard paths. It's our goal.
+	QCoreApplication::setApplicationName(EXECUTABLE_NAME);
+	QApplication::setOrganizationDomain(EXECUTABLE_NAME);
+	QCoreApplication::setApplicationVersion(APPLICATION_SEMVER);
 }
\ No newline at end of file
