@@ -52,7 +52,6 @@ static void cliShow (QHash<QString, QString> &args) {
 
 static void cliCall (QHash<QString, QString> &args) {
 	QString addressToCall = args["sip-address"];
-	
 	if(args.size() > 1){// Call with options
 		App *app = App::getInstance();
 		args["call"] = args["sip-address"];// Swap cli def to parser
@@ -63,6 +62,30 @@ static void cliCall (QHash<QString, QString> &args) {
 		CoreManager::getInstance()->getCallsListModel()->launchAudioCall(args["sip-address"], "");
 }
 
+static void cliAccept (QHash<QString, QString> &args) {
+	auto currentCall = CoreManager::getInstance()->getCore()->getCurrentCall();
+	App *app = App::getInstance();
+	if( args.size() > 0){
+		app->processArguments(args);
+		app->initContentApp();
+	}
+	if(currentCall){
+		currentCall->accept();
+	}
+}
+
+static void cliDecline (QHash<QString, QString> &args) {
+	auto currentCall = CoreManager::getInstance()->getCore()->getCurrentCall();
+	App *app = App::getInstance();
+	if( args.size() > 0){
+		app->processArguments(args);
+		app->initContentApp();
+	}
+	if(currentCall){
+		currentCall->decline(linphone::Reason::Declined);
+	}
+}
+
 static void cliBye (QHash<QString, QString> &args) {
 	auto currentCall = CoreManager::getInstance()->getCore()->getCurrentCall();
 	if(args.size() > 0) {
@@ -336,6 +359,8 @@ void Cli::Command::execute (QHash<QString, QString> &args) const {
 void Cli::Command::executeUri (const shared_ptr<linphone::Address> &address) const {
 	QHash<QString, QString> args;
 	QString qAddress = Utils::coreStringToAppString(address->asString());
+	if(address->getDomain() == "" && qAddress.back() == '@')
+		qAddress.remove(qAddress.size()-1, 1);
 	QUrl url(qAddress);
 	QString query = url.query();
 
@@ -355,8 +380,7 @@ void Cli::Command::executeUri (const shared_ptr<linphone::Address> &address) con
 		const string header = address->getHeader(Utils::appStringToCoreString(argName));
 		args[argName] = QByteArray::fromBase64(QByteArray(header.c_str(), int(header.length())));
 	}
-	address->clean();
-	args["sip-address"] = Utils::coreStringToAppString(address->asStringUriOnly());
+	args["sip-address"] = qAddress;
 	execute(args);
 }
 
@@ -428,6 +452,8 @@ QMap<QString, Cli::Command> Cli::mCommands = {
 		{ "sip-address", {} }, { "conference-id", {} }, { "guest-sip-address", {} }
 	}),
 	createCommand("bye", QT_TR_NOOP("byeFunctionDescription"), cliBye, QHash<QString, Argument>(), true),
+	createCommand("accept", QT_TR_NOOP("acceptFunctionDescription"), cliAccept, QHash<QString, Argument>(), true),
+	createCommand("decline", QT_TR_NOOP("declineFunctionDescription"), cliDecline, QHash<QString, Argument>(), true),
 };
 
 // -----------------------------------------------------------------------------
@@ -462,7 +488,7 @@ void Cli::executeCommand (const QString &command, CommandFormat *format) {
 
 // Detect if command is a CLI by testing commands
 	const QString &functionName = parseFunctionName(command);
-	
+	const std::string configURI = string(EXECUTABLE_NAME)+"-config";
 	if(!functionName.isEmpty()){// It is a CLI
 		qInfo() << QStringLiteral("Detecting cli command: `%1`...").arg(command);
 		QHash<QString, QString> args = parseArgs(command);
@@ -479,7 +505,7 @@ void Cli::executeCommand (const QString &command, CommandFormat *format) {
 		}else{
 			scheme = tempSipAddress[0].toStdString();
 			bool ok = false;
-			for (const string &validScheme : { string("sip"), "sip-"+string(EXECUTABLE_NAME), string("sips"), "sips-"+string(EXECUTABLE_NAME), string("tel"), string("callto"), string(EXECUTABLE_NAME)+ "-config" })
+			for (const string &validScheme : { string("sip"), "sip-"+string(EXECUTABLE_NAME), string("sips"), "sips-"+string(EXECUTABLE_NAME), string("tel"), string("callto"), configURI })
 				if (scheme == validScheme)
 					ok = true;
 			if( !ok){
@@ -489,28 +515,38 @@ void Cli::executeCommand (const QString &command, CommandFormat *format) {
 			tempSipAddress[0] = "sip";
 			transformedCommand = tempSipAddress.join(':');
 		}
-		if( scheme == string(EXECUTABLE_NAME)+"-config" ){
+		if( scheme == configURI ){
 			QHash<QString, QString> args = parseArgs(command);
+			QString fetchUrl;
 			if(args.contains("fetch-config"))
-				args["fetch-config"] = QByteArray::fromBase64(args["fetch-config"].toUtf8() );
+				fetchUrl = QByteArray::fromBase64(args["fetch-config"].toUtf8() );
 			else {
-				QUrl url(command);
-				url.setScheme("https");
-				args["fetch-config"] = url.toString();
+				QUrl url(command.mid(configURI.size()+1));// Remove 'exec-config:'
+				if(url.scheme().isEmpty())
+					url.setScheme("https");
+				fetchUrl = url.toString();
 			}
 			if (format)
 				*format = CliFormat;
-			mCommands["show"].execute(args);
+			QHash<QString, QString> dummy;
+			mCommands["show"].execute(dummy);// Just open the app.
+			App::getInstance()->useFetchConfig(fetchUrl);
 		}else{
-			shared_ptr<linphone::Address> address = linphone::Factory::get()->createAddress(Utils::appStringToCoreString(transformedCommand));// Test if command is an address
+			shared_ptr<linphone::Address> address;
+			if(Utils::isUsername(transformedCommand)){
+				address = linphone::Factory::get()->createAddress(Utils::appStringToCoreString(transformedCommand+"@to.remove"));
+				if(address)
+					address->setDomain("");
+			}else
+				address = linphone::Factory::get()->createAddress(Utils::appStringToCoreString(transformedCommand));// Test if command is an address
 			if (format)
 				*format = UriFormat;
 			qInfo() << QStringLiteral("Detecting URI command: `%1`...").arg(command);
 			QString functionName;
 			if( address) {
 				functionName = Utils::coreStringToAppString(address->getHeader("method")).isEmpty()
-						? QStringLiteral("call")
-						: Utils::coreStringToAppString(address->getHeader("method"));
+					? QStringLiteral("call")
+					: Utils::coreStringToAppString(address->getHeader("method"));
 			}else{
 				QStringList fields = command.split('?');
 				if(fields.size() >1){
