@@ -54,6 +54,8 @@
 #include "core/CoreManager.hpp"
 #include "file/FileDownloader.hpp"
 #include "file/FileExtractor.hpp"
+#include "file/TemporaryFile.hpp"
+#include "file/FileMediaModel.hpp"
 #include "history/HistoryProxyModel.hpp"
 #include "ldap/LdapModel.hpp"
 #include "ldap/LdapListModel.hpp"
@@ -71,6 +73,8 @@
 #include "presence/OwnPresenceModel.hpp"
 #include "recorder/RecorderModel.hpp"
 #include "recorder/RecorderManager.hpp"
+#include "recorder/RecordingListModel.hpp"
+#include "recorder/RecordingProxyModel.hpp"
 #include "settings/AccountSettingsModel.hpp"
 #include "settings/SettingsModel.hpp"
 #include "search/SearchResultModel.hpp"
