@@ -28,10 +28,18 @@
 
 #include "AssistantModel.hpp"
 
+#ifdef ENABLE_OAUTH2
+#include "components/authentication/OAuth2Model.hpp"
+#endif
+
+#ifdef ENABLE_QRCODE
 #include <linphone/FlexiAPIClient.hh>
+#endif
 
 #include <QtDebug>
 #include <QTimer>
+#include <QDesktopServices>
+#include <QJsonDocument>
 
 // =============================================================================
 
@@ -45,12 +53,17 @@ public:
 	
 private:
 	void createAccount (const shared_ptr<linphone::AccountCreator> &creator) {
-		shared_ptr<linphone::ProxyConfig> proxyConfig = creator->createProxyConfig();
-		auto account = CoreManager::getInstance()->getCore()->getAccountByIdkey(proxyConfig->getIdkey());
+		auto account = creator->createAccountInCore();
 		if(account){
+			AccountSettingsModel *accountSettingsModel = CoreManager::getInstance()->getAccountSettingsModel();
 			CoreManager::getInstance()->addingAccount(account->getParams());
-			CoreManager::getInstance()->getSettingsModel()->configureRlsUri(account);
-			CoreManager::getInstance()->getAccountSettingsModel()->setDefaultAccount(account);
+			auto accountParams = account->getParams()->clone();
+			auto natPolicy = accountParams->getNatPolicy();
+			if(natPolicy)
+				accountParams->setNatPolicy(natPolicy->clone());// Be sure to have a 'ref' entry on a nat_policy. When using default values, the 'ref' entry is lost where it should be pointing to default. We get one by cloning the policy.
+			if (accountSettingsModel->addOrUpdateAccount(account, accountParams)) {
+				accountSettingsModel->setDefaultAccount(account);
+			}
 		}
 	}
 	
@@ -69,6 +82,7 @@ private:
 			else
 				emit mAssistant->createStatusChanged(tr("accountAlreadyExists"));
 		}
+		mAssistant->setIsProcessing(false);
 	}
 	
 	void onIsAccountExist (
@@ -86,6 +100,56 @@ private:
 			else
 				emit mAssistant->loginStatusChanged(tr("loginWithUsernameFailed"));
 		}
+		mAssistant->setIsProcessing(false);
+	}
+	
+	virtual void onAccountCreationRequestToken(const std::shared_ptr<linphone::AccountCreator> & creator, linphone::AccountCreator::Status status, const std::string & response) override{
+		if( status == linphone::AccountCreator::Status::RequestOk){
+			QJsonDocument doc = QJsonDocument::fromJson(response.c_str());
+			bool error = false;
+			QVariantMap description = doc.toVariant().toMap();
+			if( description.contains("token") && description.contains("validation_url")){
+				QString url = description.value("validation_url").toString();
+				QString token = description.value("token").toString();
+				creator->setAccountCreationRequestToken(token.toStdString());
+				if(!QDesktopServices::openUrl(url)){
+					qCritical() << "Cannot open validation url for the account creation request token";
+					emit mAssistant->createStatusChanged("Cannot open validation url for the account creation request token");
+					mAssistant->setIsProcessing(false);
+				}else {
+					emit mAssistant->createStatusChanged("Waiting for validation at " + url);
+					creator->requestAccountCreationTokenUsingRequestToken();
+				}
+			}else{
+				qCritical() << "The answer of account creation request token doesn't have token and validation_url fields";
+				emit mAssistant->createStatusChanged("The answer of account creation request token doesn't have token and validation_url fields");
+				mAssistant->setIsProcessing(false);
+			}
+		}else{
+			qCritical() << "Cannot get request token for account creation (" << (int)status << ")";
+			emit mAssistant->createStatusChanged("Cannot get request token for account creation (" +QString::number((int)status) + ")");
+			mAssistant->setIsProcessing(false);
+		}
+	}
+	
+	virtual void onAccountCreationTokenUsingRequestToken(const std::shared_ptr<linphone::AccountCreator> & creator, linphone::AccountCreator::Status status, const std::string & response) override{
+		if(status ==  linphone::AccountCreator::Status::RequestOk){
+			QJsonDocument doc = QJsonDocument::fromJson(response.c_str());
+			bool error = false;
+			QVariantMap description = doc.toVariant().toMap();
+			creator->setToken(description.value("token").toString().toStdString());
+			// it will automatically use the account creation token.
+			if (mAssistant->mUsePhoneNumber) {
+				emit mAssistant->createStatusChanged("Recovering account");
+				creator->recoverAccount();
+			}else{
+				emit mAssistant->createStatusChanged("Creating account");
+				creator->createAccount();
+			}
+		}else
+			QTimer::singleShot(2000, [creator](){
+				creator->requestAccountCreationTokenUsingRequestToken();
+			});
 	}
 	
 	void onActivateAccount (
@@ -124,12 +188,13 @@ private:
 			else
 				emit mAssistant->activateStatusChanged(tr("emailActivationFailed"));
 		}
+		mAssistant->setIsProcessing(false);
 	}
 	
 	void onRecoverAccount (
-			const shared_ptr<linphone::AccountCreator> &,
+			const shared_ptr<linphone::AccountCreator> &accountCreator,
 			linphone::AccountCreator::Status status,
-			const string &
+			const string &response
 			) override {
 		if (status == linphone::AccountCreator::Status::RequestOk) {
 			CoreManager::getInstance()->getSipAddressesModel()->reset();
@@ -142,8 +207,23 @@ private:
 			else
 				emit mAssistant->recoverStatusChanged(tr("loginWithPhoneNumberFailed"));
 		}
+		mAssistant->setIsProcessing(false);
+	}
+	virtual void onLoginLinphoneAccount(
+			const std::shared_ptr<linphone::AccountCreator> & creator,
+			linphone::AccountCreator::Status status,
+			const std::string & response) override {
+		if( status == linphone::AccountCreator::Status::RequestOk){
+			createAccount(creator);
+			CoreManager::getInstance()->getSipAddressesModel()->reset();
+			emit mAssistant->activateStatusChanged(QString(""));
+		} else {
+			if (status == linphone::AccountCreator::Status::RequestFailed)
+				emit mAssistant->activateStatusChanged(tr("requestFailed"));
+			else
+				emit mAssistant->activateStatusChanged(tr("smsActivationFailed"));
+		}
 	}
-	
 private:
 	AssistantModel *mAssistant;
 };
@@ -155,6 +235,7 @@ AssistantModel::AssistantModel (QObject *parent) : QObject(parent) {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	connect(CoreManager::getInstance()->getHandlers().get(), &CoreHandlers::foundQRCode, this, &AssistantModel::onQRCodeFound);
 	mIsReadingQRCode = false;
+	mIsProcessing = false;
 	mAccountCreator = core->createAccountCreator(
 				core->getConfig()->getString("assistant", "xmlrpc_url", Constants::DefaultXmlrpcUri)
 				);
@@ -164,24 +245,38 @@ AssistantModel::AssistantModel (QObject *parent) : QObject(parent) {
 
 AssistantModel::~AssistantModel(){
 	setIsReadingQRCode(false);
+#ifdef ENABLE_OAUTH2
+	if(oAuth2Model)
+		oAuth2Model->deleteLater();
+	oAuth2Model = nullptr;
+#endif
 }
 
 // -----------------------------------------------------------------------------
 
 void AssistantModel::activate () {
-	if (mAccountCreator->getEmail().empty())
-		mAccountCreator->activateAccount();
-	else
+	setIsProcessing(true);
+	if (mAccountCreator->getEmail().empty()){
+		if(mAccountCreator->getUsername().empty())
+			mAccountCreator->setUsername(mAccountCreator->getPhoneNumber());
+		mAccountCreator->loginLinphoneAccount();// It will detect if phone is an alias or not. 
+	}else
 		mAccountCreator->isAccountActivated();
 }
 
 void AssistantModel::create () {
-	mAccountCreator->createAccount();
+	setIsProcessing(true);
+	emit createStatusChanged("Requesting validation url");
+	mAccountCreator->requestAccountCreationRequestToken();
 }
 
 void AssistantModel::login () {
-	if (!mCountryCode.isEmpty()) {
-		mAccountCreator->recoverAccount();
+	setIsProcessing(true);
+	if(mAccountCreator->getUsername().empty())
+		mAccountCreator->setUsername(mAccountCreator->getPhoneNumber());
+	if (mUsePhoneNumber) {
+		emit createStatusChanged("Requesting validation url");
+		mAccountCreator->requestAccountCreationRequestToken();
 		return;
 	}
 	
@@ -191,12 +286,25 @@ void AssistantModel::login () {
 		return;
 	}
 	
-	// No verification if no xmlrpc url. Use addOtherSipAccount directly.
+	// No verification if no xmlrpc url.
+	auto account = mAccountCreator->createAccountInCore();
+	if(account){
+		AccountSettingsModel *accountSettingsModel = CoreManager::getInstance()->getAccountSettingsModel();
+		if (accountSettingsModel->addOrUpdateAccount(account, account->getParams()->clone())) {
+			accountSettingsModel->setDefaultAccount(account);
+		}
+		emit loginStatusChanged("");
+		return;
+	}
+	
+	// Cannot create new account from account creator. Use addOtherSipAccount directly.
 	QVariantMap map;
 	map["sipDomain"] = Utils::coreStringToAppString(config->getString("assistant", "domain", ""));
 	map["username"] = getUsername();
 	map["password"] = getPassword();
+	map["transport"] = LinphoneEnums::toString(LinphoneEnums::fromLinphone(mAccountCreator->getTransport()));
 	emit loginStatusChanged(addOtherSipAccount(map) ? QString("") : tr("unableToAddAccount"));
+	setIsProcessing(false);
 }
 
 void AssistantModel::reset () {
@@ -220,7 +328,11 @@ bool AssistantModel::addOtherSipAccount (const QVariantMap &map) {
 	std::string accountIdKey = map["accountIdKey"].toString().toStdString();
 	if( accountIdKey  != "")
 		account = core->getAccountByIdkey(accountIdKey);
-	shared_ptr<linphone::AccountParams> accountParams = core->createAccountParams();
+	shared_ptr<linphone::AccountParams> accountParams;
+	if(account)
+		accountParams = account->getParams()->clone();
+	else
+		accountParams = core->createAccountParams();
 	
 	
 	const QString domain = map["sipDomain"].toString();
@@ -282,6 +394,7 @@ bool AssistantModel::addOtherSipAccount (const QVariantMap &map) {
 void AssistantModel::createTestAccount(){
 }
 void AssistantModel::generateQRCode(){
+#ifdef ENABLE_QRCODE
 	auto flexiAPIClient = make_shared<FlexiAPIClient>(CoreManager::getInstance()->getCore()->cPtr());
 	flexiAPIClient
 		->accountProvision()
@@ -291,8 +404,10 @@ void AssistantModel::generateQRCode(){
 		->error([this](FlexiAPIClient::Response response){
 			emit newQRCodeNotReceived(Utils::coreStringToAppString(response.body), response.code);
 		});
+#endif
 }
 void AssistantModel::requestQRCode(){
+#ifdef ENABLE_QRCODE
 	auto flexiAPIClient = make_shared<FlexiAPIClient>(CoreManager::getInstance()->getCore()->cPtr());
 	
 	flexiAPIClient
@@ -305,6 +420,7 @@ void AssistantModel::requestQRCode(){
 			qWarning() << response.code << " => " << response.body.c_str();
 			emit newQRCodeNotReceived(Utils::coreStringToAppString(response.body), response.code);
 		});
+#endif
 }
 
 void AssistantModel::readQRCode(){
@@ -314,6 +430,7 @@ void AssistantModel::newQRCodeNotReceivedTest(){
 	emit newQRCodeNotReceived("Cannot generate a provisioning key",0);
 }
 void AssistantModel::checkLinkingAccount(){
+#ifdef ENABLE_QRCODE
 	auto flexiAPIClient = make_shared<FlexiAPIClient>(CoreManager::getInstance()->getCore()->cPtr());
 	flexiAPIClient
 		->accountApiKeyFromAuthTokenGenerate(mToken.toStdString())
@@ -322,9 +439,11 @@ void AssistantModel::checkLinkingAccount(){
 		})->error([this](FlexiAPIClient::Response){
 			QTimer::singleShot(5000, this, &AssistantModel::checkLinkingAccount);
 	});
+#endif
 }
 
 void AssistantModel::onApiReceived(QString apiKey){
+#ifdef ENABLE_QRCODE
 	auto flexiAPIClient = make_shared<FlexiAPIClient>(CoreManager::getInstance()->getCore()->cPtr());
 	flexiAPIClient->setApiKey(Utils::appStringToCoreString(apiKey).c_str())
 		->accountProvision()
@@ -334,6 +453,7 @@ void AssistantModel::onApiReceived(QString apiKey){
 			//it provisioningTokenReceived("token");
 			emit this->newQRCodeNotReceived("Cannot generate a provisioning key"+(response.body.empty() ? "" : " : " +Utils::coreStringToAppString(response.body)), response.code);
 	});
+#endif
 }
 void AssistantModel::onQRCodeFound(const std::string & result){
 	setIsReadingQRCode(false);
@@ -341,6 +461,7 @@ void AssistantModel::onQRCodeFound(const std::string & result){
 }
 
 void AssistantModel::attachAccount(const QString& token){
+#ifdef ENABLE_QRCODE
 	auto flexiAPIClient = make_shared<FlexiAPIClient>(CoreManager::getInstance()->getCore()->cPtr());
 	flexiAPIClient->
 	accountAuthTokenAttach(Utils::appStringToCoreString(token))
@@ -351,6 +472,29 @@ void AssistantModel::attachAccount(const QString& token){
 		->error([this](FlexiAPIClient::Response response){
 			emit qRCodeNotAttached("Cannot attach"+ (response.body.empty() ? "" : " : " +Utils::coreStringToAppString(response.body)), response.code);
 		});
+#endif
+}
+
+bool AssistantModel::isOAuth2Available(){
+#ifdef ENABLE_OAUTH2
+	return OAuth2Model::isAvailable();
+#else
+	return false;
+#endif
+}
+
+void AssistantModel::requestOauth2(){
+#ifdef ENABLE_OAUTH2
+	if(isOAuth2Available()){
+		if(oAuth2Model)
+			oAuth2Model->deleteLater();
+		oAuth2Model = new OAuth2Model();
+		connect(oAuth2Model, &OAuth2Model::requestFailed, this, &AssistantModel::oauth2RequestFailed);
+		connect(oAuth2Model, &OAuth2Model::statusChanged, this, &AssistantModel::oauth2StatusChanged);
+		connect(oAuth2Model, &OAuth2Model::authenticated, this, &AssistantModel::oauth2AuthenticationGranted);
+		oAuth2Model->grant();
+	}
+#endif
 }
 
 // -----------------------------------------------------------------------------
@@ -417,12 +561,29 @@ QString AssistantModel::getCountryCode () const {
 
 void AssistantModel::setCountryCode (const QString &countryCode) {
 	mCountryCode = countryCode;
+	mAccountCreator->setPhoneNumber(Utils::appStringToCoreString(mPhoneNumber), Utils::appStringToCoreString(mCountryCode));
 	emit countryCodeChanged(countryCode);
+	emit computedPhoneNumberChanged();
 }
 
 // -----------------------------------------------------------------------------
 
+bool AssistantModel::getUsePhoneNumber() const{
+	return mUsePhoneNumber;
+}
+
+void AssistantModel::setUsePhoneNumber(bool use) {
+	if(mUsePhoneNumber != use){
+		mUsePhoneNumber = use;
+		emit usePhoneNumberChanged();
+	}
+}
+
 QString AssistantModel::getPhoneNumber () const {
+	return mPhoneNumber;
+}
+
+QString AssistantModel::getComputedPhoneNumber () const{
 	return Utils::coreStringToAppString(mAccountCreator->getPhoneNumber());
 }
 
@@ -450,8 +611,20 @@ void AssistantModel::setPhoneNumber (const QString &phoneNumber) {
 		default:
 			break;
 	}
-	
+	mPhoneNumber = phoneNumber;
 	emit phoneNumberChanged(phoneNumber, error);
+	emit computedPhoneNumberChanged();
+}
+
+QString AssistantModel::getPhoneCountryCode() const {
+	return mPhoneCountryCode;
+}
+
+void AssistantModel::setPhoneCountryCode(const QString &code) {
+	if( mPhoneCountryCode != code) {
+		mPhoneCountryCode = code;
+		emit phoneCountryCodeChanged();
+	}
 }
 
 // -----------------------------------------------------------------------------
@@ -529,6 +702,17 @@ void AssistantModel::setIsReadingQRCode(bool isReading){
 	}
 }
 
+bool AssistantModel::getIsProcessing() const{
+	return mIsProcessing;
+}
+
+void AssistantModel::setIsProcessing(bool isProcessing){
+	if(mIsProcessing != isProcessing){
+		mIsProcessing = isProcessing;
+		emit isProcessingChanged();
+	}
+}
+
 // -----------------------------------------------------------------------------
 
 QString AssistantModel::mapAccountCreatorUsernameStatusToString (linphone::AccountCreator::UsernameStatus status) const {
