@@ -63,12 +63,13 @@ CallModel::CallModel (shared_ptr<linphone::Call> call){
 	connect(this, &CallModel::callIdChanged, this, &CallModel::chatRoomModelChanged);// When the call Id change, the chat room change.
 	connect(this, &CallModel::encryptionChanged, this, &CallModel::securityUpdated);
 	connect(this, &CallModel::isPQZrtpChanged, this, &CallModel::securityUpdated);
+	connect(this, &CallModel::securityUpdated, this, &CallModel::onSecurityUpdated);
 	
 	mCall = call;
 	if(mCall)
 		mCall->setData("call-model", *this);
 	updateIsInConference();
-	if(mCall) {
+	if(mCall && mCall->getState() != linphone::Call::State::End) {
 		mCallListener = std::make_shared<CallListener>();
 		connectTo(mCallListener.get());
 		mCall->addListener(mCallListener);
@@ -130,6 +131,10 @@ CallModel::CallModel (shared_ptr<linphone::Call> call){
 
 CallModel::~CallModel () {
 	mMagicSearch->removeListener(mSearch);
+	removeCall();
+}
+
+void CallModel::removeCall(){
 	if(mCall){
 		mCall->removeListener(mCallListener);
 		mConferenceModel = nullptr;// Ordering deletion.
@@ -164,7 +169,7 @@ std::shared_ptr<linphone::Address> CallModel::getConferenceAddress () const{
 		
 		if (mCall->getDir() == linphone::Call::Dir::Incoming){
 			if( remoteContact != "" )
-				conferenceAddress = CoreManager::getInstance()->getCore()->interpretUrl(remoteContact);
+				conferenceAddress = Utils::interpretUrl(Utils::coreStringToAppString(remoteContact));
 		}else
 			conferenceAddress = mCall->getRemoteAddress()->clone();
 	}	
@@ -240,7 +245,7 @@ ConferenceInfoModel * CallModel::getConferenceInfoModel(){
 }
 
 QSharedPointer<ConferenceModel> CallModel::getConferenceSharedModel(){
-	if(mCall->getConference() && !mConferenceModel){
+	if(mCall->getState() != linphone::Call::State::End && mCall->getConference() && !mConferenceModel){
 		mConferenceModel = ConferenceModel::create(mCall->getConference());
 		connect(mConferenceModel.get(), &ConferenceModel::participantAdminStatusChanged, this, &CallModel::onParticipantAdminStatusChanged);
 		emit conferenceModelChanged();
@@ -248,6 +253,10 @@ QSharedPointer<ConferenceModel> CallModel::getConferenceSharedModel(){
 	return mConferenceModel;
 }
 
+bool CallModel::isInConference () const{
+	return mIsInConference;
+}
+
 bool CallModel::isConference () const{
 // Check status to avoid crash when requesting a conference on an ended call.
 	bool isConf = false;
@@ -479,7 +488,7 @@ void CallModel::stopRecording () {
 // -----------------------------------------------------------------------------
 
 void CallModel::handleCallEncryptionChanged (const shared_ptr<linphone::Call> &call) {
-	if (call == mCall){
+	if (call == mCall && mCall->getState() != linphone::Call::State::End){
 		if(!setEncryption(static_cast<CallEncryption>(mCall->getCurrentParams()->getMediaEncryption())))
 			emit securityUpdated();
 	}
@@ -494,6 +503,7 @@ void CallModel::handleCallStateChanged (const shared_ptr<linphone::Call> &call,
 		auto conferenceInfo = CoreManager::getInstance()->getCore()->findConferenceInformationFromUri(getConferenceAddress());
 		if(	conferenceInfo ){
 				mConferenceInfoModel = ConferenceInfoModel::create(conferenceInfo);
+				getConferenceSharedModel();	// emit new conferenceModel if it was not created.
 				emit conferenceInfoModelChanged();
 		}
 	}
@@ -503,16 +513,16 @@ void CallModel::handleCallStateChanged (const shared_ptr<linphone::Call> &call,
 			setCallErrorFromReason(call->getReason());
 			stopAutoAnswerTimer();
 			stopRecording();
-			mPausedByRemote = false;
+			setPausedByRemote(false);
 			break;
 			
 		case linphone::Call::State::StreamsRunning: {
-			
+			getConferenceSharedModel();
 			if (!mWasConnected && CoreManager::getInstance()->getSettingsModel()->getAutomaticallyRecordCalls()) {
 				startRecording();
 				mWasConnected = true;
 			}
-			mPausedByRemote = false;
+			setPausedByRemote(false);
 			updateConferenceVideoLayout();
 			setCallId(QString::fromStdString(mCall->getCallLog()->getCallId()));
 			updateEncryption();
@@ -521,12 +531,12 @@ void CallModel::handleCallStateChanged (const shared_ptr<linphone::Call> &call,
 		case linphone::Call::State::Connected: getConferenceSharedModel();
 		case linphone::Call::State::Referred:
 		case linphone::Call::State::Released:
-			mPausedByRemote = false;
+			setPausedByRemote(false);
 			break;
 			
 		case linphone::Call::State::PausedByRemote:
 			mNotifyCameraFirstFrameReceived = true;
-			mPausedByRemote = true;
+			setPausedByRemote(true);
 			break;
 			
 		case linphone::Call::State::Pausing:
@@ -578,7 +588,6 @@ void CallModel::accept (bool withVideo) {
 		} else
 			App::smartShowWindow(callsWindow);
 	}
-	qApp->processEvents();  // Process GUI events before accepting in order to be synchronized with Call objects and be ready to get SDK events
 	shared_ptr<linphone::Core> core = coreManager->getCore();
 	if(mCall) {
 		shared_ptr<linphone::CallParams> params = core->createCallParams(mCall);
@@ -599,7 +608,7 @@ void CallModel::accept (bool withVideo) {
 // -----------------------------------------------------------------------------
 
 void CallModel::updateIsInConference () {
-	if (mIsInConference != (mCall &&  mCall->getCurrentParams()->getLocalConferenceMode() )) {
+	if (mIsInConference != (mCall && mCall->getState() != linphone::Call::State::End && mCall->getCurrentParams()->getLocalConferenceMode() )) {
 		mIsInConference = !mIsInConference;
 	}
 	emit isInConferenceChanged(mIsInConference);
@@ -618,27 +627,32 @@ void CallModel::stopAutoAnswerTimer () const {
 // -----------------------------------------------------------------------------
 
 CallModel::CallStatus CallModel::getStatus () const {
+	CallModel::CallStatus status;
 	if(mCall){
 		switch (mCall->getState()) {
 			case linphone::Call::State::Connected:
 			case linphone::Call::State::StreamsRunning:
-				return CallStatusConnected;
+				status = CallStatusConnected;
+				break;
 				
 			case linphone::Call::State::End:
 			case linphone::Call::State::Error:
 			case linphone::Call::State::Referred:
 			case linphone::Call::State::Released:
-				return CallStatusEnded;
+				status = CallStatusEnded;
+				break;
 				
 			case linphone::Call::State::Paused:
 			case linphone::Call::State::PausedByRemote:
 			case linphone::Call::State::Pausing:
 			case linphone::Call::State::Resuming:
-				return CallStatusPaused;
+				status = CallStatusPaused;
+				break;
 				
 			case linphone::Call::State::Updating:
 			case linphone::Call::State::UpdatedByRemote:
-				return mPausedByRemote ? CallStatusPaused : CallStatusConnected;
+				status = mPausedByRemote ? CallStatusPaused : CallStatusConnected;
+				break;
 				
 			case linphone::Call::State::EarlyUpdatedByRemote:
 			case linphone::Call::State::EarlyUpdating:
@@ -649,12 +663,13 @@ CallModel::CallStatus CallModel::getStatus () const {
 			case linphone::Call::State::OutgoingInit:
 			case linphone::Call::State::OutgoingProgress:
 			case linphone::Call::State::OutgoingRinging:
-				break;
+			default:{
+				status = mCall->getDir() == linphone::Call::Dir::Incoming ? CallStatusIncoming : CallStatusOutgoing;	
+			}
 		}
-		
-		return mCall->getDir() == linphone::Call::Dir::Incoming ? CallStatusIncoming : CallStatusOutgoing;
 	}else
-		return CallStatusIdle;
+		status = CallStatusIdle;
+	return status;
 }
 
 // -----------------------------------------------------------------------------
@@ -665,7 +680,7 @@ void CallModel::acceptWithAutoAnswerDelay () {
 	
 	// Use auto-answer if activated and it's the only call.
 	if (settingsModel->getAutoAnswerStatus() && coreManager->getCore()->getCallsNb() == 1) {
-		if (mCall && mCall->getRemoteParams()->videoEnabled() && settingsModel->getAutoAnswerVideoStatus() && settingsModel->getVideoSupported())
+		if (mCall && mCall->getRemoteParams()->videoEnabled() && settingsModel->getAutoAnswerVideoStatus() && settingsModel->getVideoEnabled())
 			acceptWithVideo();
 		else
 			accept();
@@ -768,13 +783,13 @@ void CallModel::setMicroMuted (bool status) {
 // -----------------------------------------------------------------------------
 
 bool CallModel::getCameraEnabled () const{
-	return mCall && (((int)mCall->getCurrentParams()->getVideoDirection() & (int)linphone::MediaDirection::SendOnly) == (int)linphone::MediaDirection::SendOnly);
+	return mCall && mCall->getState() != linphone::Call::State::End && (((int)mCall->getCurrentParams()->getVideoDirection() & (int)linphone::MediaDirection::SendOnly) == (int)linphone::MediaDirection::SendOnly);
 }
 
 void CallModel::setCameraEnabled (bool status){
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	if (!core->videoSupported()) {
-		qWarning() << QStringLiteral("Unable to update video call property. (Video not supported.)");
+	if (!CoreManager::getInstance()->getSettingsModel()->getVideoEnabled()) {
+		qWarning() << QStringLiteral("Unable to update video call property. (Video not enabled.)");
 		return;
 	}
 	if(mCall) {
@@ -824,6 +839,16 @@ void CallModel::setPausedByUser (bool status) {
 	}
 }
 
+bool CallModel::getPausedByRemote () const {
+	return mPausedByRemote;
+}
+
+void CallModel::setPausedByRemote (bool status) {
+	if(mPausedByRemote != status){
+		mPausedByRemote = status;
+		emit pausedByRemoteChanged();
+	}
+}
 // -----------------------------------------------------------------------------
 bool CallModel::getRemoteVideoEnabled () const {
 	shared_ptr<const linphone::CallParams> params = mCall->getRemoteParams();
@@ -840,16 +865,18 @@ bool CallModel::getLocalVideoEnabled () const {
 
 bool CallModel::getVideoEnabled () const {
 	if(mCall){
+		if(mCall->getState() == linphone::Call::State::End )
+			return false;
 		shared_ptr<const linphone::CallParams> params = mCall->getCurrentParams();
 		return params && params->videoEnabled();
 	}else
-		return true;
+		return CoreManager::getInstance()->getSettingsModel()->getVideoEnabled();
 }
 
 void CallModel::setVideoEnabled (bool status) {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	if (!core->videoSupported()) {
-		qWarning() << QStringLiteral("Unable to update video call property. (Video not supported.)");
+	if (!CoreManager::getInstance()->getSettingsModel()->getVideoEnabled()) {
+		qWarning() << QStringLiteral("Unable to update video call property. (Video not enabled.)");
 		return;
 	}
 	if(mCall) {
@@ -913,7 +940,7 @@ void CallModel::sendDtmf (const QString &dtmf) {
 // -----------------------------------------------------------------------------
 
 void CallModel::verifyAuthenticationToken (bool verify) {
-	if(mCall)
+	if(mCall && getStatus() != CallStatusEnded)
 		mCall->setAuthenticationTokenVerified(verify);
 	emit securityUpdated();
 }
@@ -998,6 +1025,12 @@ void CallModel::onParticipantAdminStatusChanged(const std::shared_ptr<const linp
 	}
 }
 
+void CallModel::onSecurityUpdated(){
+	ChatRoomModel * model = getChatRoomModel();
+	if(model)
+		model->updateSecurityLevel();
+}
+
 void CallModel::setRemoteDisplayName(const std::string& name){
 	mRemoteAddress->setDisplayName(name);
 	if(mCall) {
@@ -1088,7 +1121,7 @@ bool CallModel::setEncryption(const CallModel::CallEncryption& encryption){
 }
 
 void CallModel::updateEncryption(){
-	if(mCall){
+	if(mCall && mCall->getState() != linphone::Call::State::End){
 		auto currentParams =  mCall->getCurrentParams();
 		if( currentParams){
 			setEncryption(static_cast<CallEncryption>(currentParams->getMediaEncryption()));
@@ -1176,7 +1209,7 @@ static inline QVariantMap createStat (const QString &key, const QString &value)
 }
 
 void CallModel::updateStats (const shared_ptr<const linphone::CallStats> &callStats, QVariantList &statsList) {
-	if(mCall){
+	if(mCall && mCall->getState() != linphone::Call::State::End){
 		shared_ptr<const linphone::CallParams> params = mCall->getCurrentParams();
 		shared_ptr<const linphone::PayloadType> payloadType;
 		
@@ -1250,7 +1283,7 @@ void CallModel::updateStats (const shared_ptr<const linphone::CallStats> &callSt
 	}
 }
 void CallModel::updateEncrypionStats (const shared_ptr<const linphone::CallStats> &callStats, QVariantList &statsList) {
-	if( callStats->getType() == linphone::StreamType::Audio) {// just in case
+	if( callStats->getType() == linphone::StreamType::Audio && mCall->getState() != linphone::Call::State::End) {// just in case
 		statsList.clear();
 		if(isSecured()) {
 		//: 'Media encryption' : label in encryption section of call statistics
@@ -1312,7 +1345,7 @@ QString CallModel::generateSavedFilename () const {
 
 QString CallModel::generateSavedFilename (const QString &from, const QString &to) {
 	auto escape = [](const QString &str) {
-		constexpr char ReservedCharacters[] = "[<|>|:|\"|/|\\\\|\\?|\\*|\\+|\\|]+";
+		constexpr char ReservedCharacters[] = "[<|>|:|\"|/|\\\\|\\?|\\*|\\+|\\||_|-]+";
 		static QRegularExpression regexp(ReservedCharacters);
 		return QString(str).replace(regexp, "");
 	};
@@ -1321,3 +1354,35 @@ QString CallModel::generateSavedFilename (const QString &from, const QString &to
 			.arg(escape(from))
 			.arg(escape(to));
 }
+
+QStringList CallModel::splitSavedFilename(const QString& filename){
+	QStringList fields = filename.split('_');
+	if(fields.size() == 4 && fields[0].split('-').size() == 3 && fields[1].split('-').size() == 3){
+		return fields;
+	}else
+		return QStringList(filename);
+}
+
+QDateTime CallModel::getDateTimeSavedFilename(const QString& filename){
+	auto fields = splitSavedFilename(filename);
+	if(fields.size() > 1)
+		return QDateTime::fromString(fields[0] + "_" +fields[1], "yyyy-MM-dd_hh-mm-ss");
+	else
+		return QDateTime();
+}
+
+QString CallModel::getFromSavedFilename(const QString& filename){
+	auto fields = splitSavedFilename(filename);
+	if(fields.size() > 1)
+		return fields[2];
+	else
+		return "";
+}
+
+QString CallModel::getToSavedFilename(const QString& filename){
+	auto fields = splitSavedFilename(filename);
+	if(fields.size() > 1)
+		return fields[3];
+	else
+		return "";
+}
