@@ -136,7 +136,7 @@ void CallsListModel::launchSecureAudioCall (const QString &sipAddress, LinphoneE
 	CoreManager::getInstance()->getTimelineListModel()->mAutoSelectAfterCreation = true;
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	
-	shared_ptr<linphone::Address> address = core->interpretUrl(Utils::appStringToCoreString(sipAddress));
+	shared_ptr<linphone::Address> address = Utils::interpretUrl(sipAddress);
 	if (!address)
 		return;
 	
@@ -174,19 +174,19 @@ void CallsListModel::launchSecureAudioCall (const QString &sipAddress, LinphoneE
 void CallsListModel::launchVideoCall (const QString &sipAddress, const QString& prepareTransfertAddress, const bool& autoSelectAfterCreation, QVariantMap options) const {
 	CoreManager::getInstance()->getTimelineListModel()->mAutoSelectAfterCreation = autoSelectAfterCreation;
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	if (!core->videoSupported()) {
-		qWarning() << QStringLiteral("Unable to launch video call. (Video not supported.) Launching audio call...");
+	if (!CoreManager::getInstance()->getSettingsModel()->getVideoEnabled()) {
+		qWarning() << QStringLiteral("Unable to launch video call. (Video not enabled.) Launching audio call...");
 		launchAudioCall(sipAddress, prepareTransfertAddress, {});
 		return;
 	}
 	
-	shared_ptr<linphone::Address> address = core->interpretUrl(Utils::appStringToCoreString(sipAddress));
+	shared_ptr<linphone::Address> address = Utils::interpretUrl(sipAddress);
 	if (!address)
 		return;
 	
 	shared_ptr<linphone::CallParams> params = core->createCallParams(nullptr);
 	
-	auto layout = options.contains("layout") ? LinphoneEnums::toLinphone((LinphoneEnums::ConferenceLayout)options["layout"].toInt()) : linphone::ConferenceLayout::Grid;
+	auto layout = options.contains("layout") ? LinphoneEnums::toLinphone((LinphoneEnums::ConferenceLayout)options["layout"].toInt()) : LinphoneEnums::toLinphone(CoreManager::getInstance()->getSettingsModel()->getVideoConferenceLayout());
 	bool enableMicro =options.contains("micro") ? options["micro"].toBool() : true;
 	bool enableVideo = options.contains("video") ? options["video"].toBool() : true;
 	bool enableCamera = options.contains("camera") ? options["camera"].toBool() : true;
@@ -201,9 +201,13 @@ void CallsListModel::launchVideoCall (const QString &sipAddress, const QString&
 	CallModel::setRecordFile(params, Utils::coreStringToAppString(address->getUsername()));
 	
 	auto call = core->inviteAddressWithParams(address, params);
-	call->setSpeakerMuted(!enableSpeaker);
-	qInfo() << "Launch " << (enableVideo ? "video" : "audio") << " call; camera: " << enableCamera<< " speaker:" << enableSpeaker << ", micro:" << params->micEnabled() << ", layout:" << (int)layout;
-	CallModel::prepareTransfert(call, prepareTransfertAddress);
+	if(!call)
+		qWarning() << "Cannot initiate call. Maybe another one is currently done: delay the call.";
+	else{
+		call->setSpeakerMuted(!enableSpeaker);
+		qInfo() << "Launch " << (enableVideo ? "video" : "audio") << " call; camera: " << enableCamera<< " speaker:" << enableSpeaker << ", micro:" << params->micEnabled() << ", layout:" << (int)layout;
+		CallModel::prepareTransfert(call, prepareTransfertAddress);
+	}
 }
 
 QVariantMap CallsListModel::launchChat(const QString &sipAddress, const int& securityLevel) const{
@@ -215,7 +219,7 @@ QVariantMap CallsListModel::launchChat(const QString &sipAddress, const int& sec
 ChatRoomModel* CallsListModel::createChat (const QString &participantAddress) const{
 	CoreManager::getInstance()->getTimelineListModel()->mAutoSelectAfterCreation = true;
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	shared_ptr<linphone::Address> address = core->interpretUrl(Utils::appStringToCoreString(participantAddress));
+	shared_ptr<linphone::Address> address = Utils::interpretUrl(participantAddress);
 	if (!address)
 		return nullptr;
 	
@@ -248,7 +252,7 @@ ChatRoomModel* CallsListModel::createChat (CallModel * model){
 bool CallsListModel::createSecureChat (const QString& subject, const QString &participantAddress) const{
 	CoreManager::getInstance()->getTimelineListModel()->mAutoSelectAfterCreation = true;
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
-	shared_ptr<linphone::Address> address = core->interpretUrl(Utils::appStringToCoreString(participantAddress));
+	shared_ptr<linphone::Address> address = Utils::interpretUrl(participantAddress);
 	if (!address)
 		return false;
 	
@@ -257,7 +261,6 @@ bool CallsListModel::createSecureChat (const QString& subject, const QString &pa
 	std::shared_ptr<const linphone::Address> localAddress;
 	participants.push_back(address);
 	params->enableEncryption(true);
-	
 	params->setSubject(Utils::appStringToCoreString(subject));
 	params->enableEncryption(true);
 	params->enableGroup(true);
@@ -361,6 +364,13 @@ QVariantMap CallsListModel::createChatRoom(const QString& subject, const int& se
 	}
 	if( !chatRoom)
 		qWarning() << "Chat room cannot be created";
+	else if(securityLevel > 0) {
+		int ephemeralTime = CoreManager::getInstance()->getSettingsModel()->getCreateEphemeralChatRooms();
+		if( ephemeralTime>0){
+			chatRoom->setEphemeralLifetime(ephemeralTime);
+			chatRoom->enableEphemeral(true);
+		}
+	}
 	result["created"] = (chatRoom != nullptr);
 	
 	return result;
@@ -472,7 +482,7 @@ void CallsListModel::terminateAllCalls () const {
 }
 void CallsListModel::terminateCall (const QString& sipAddress) const{
 	auto coreManager = CoreManager::getInstance();
-	shared_ptr<linphone::Address> address = coreManager->getCore()->interpretUrl(Utils::appStringToCoreString(sipAddress));
+	shared_ptr<linphone::Address> address = Utils::interpretUrl(sipAddress);
 	if (!address)
 		qWarning() << "Cannot terminate Call. The address cannot be parsed : " << sipAddress;
 	else{
@@ -524,6 +534,7 @@ static void joinConference (const shared_ptr<linphone::Call> &call) {
 	addModel->update();
 }
 
+// Global handler on core (is call before call model receive it). Used for model creation.
 void CallsListModel::handleCallStateChanged (const shared_ptr<linphone::Call> &call, linphone::Call::State state) {
 	switch (state) {
 		case linphone::Call::State::IncomingReceived:
@@ -534,41 +545,52 @@ void CallsListModel::handleCallStateChanged (const shared_ptr<linphone::Call> &c
 		case linphone::Call::State::OutgoingInit:
 			addCall(call);
 			break;
-			
-		case linphone::Call::State::End:
-		case linphone::Call::State::Error:{
-			if(call->dataExists("call-model")) {
-				CallModel * model = &call->getData<CallModel>("call-model");
-				model->endCall();
-			}
-		} break;
-		case linphone::Call::State::Released:
-			removeCall(call);
-		break;
-		
-		case linphone::Call::State::StreamsRunning: {
-			int index = findCallIndex(mList, call);
-			emit callRunning(index, &call->getData<CallModel>("call-model"));
-		} break;
-			
 		default:
 			break;
 	}
 }
 
+// Call handler
+void CallsListModel::handleCallStatusChanged () {
+	auto callModel = qobject_cast<CallModel*>(sender());
+	auto call = callModel->getCall();
+	if( call){
+		auto state = call->getState();
+		switch (state) {
+			case linphone::Call::State::End:
+			case linphone::Call::State::Error:{
+				callModel->endCall();
+				if(callModel->getCallError() == "")
+					removeCall(call);
+			} break;
+			case linphone::Call::State::Released:
+				removeCall(call);
+			break;
+			
+			case linphone::Call::State::StreamsRunning: {
+				int index = findCallIndex(mList, call);
+				emit callRunning(index, callModel);
+			} break;
+				
+			default:
+				break;
+		}
+	}
+}
+
 // -----------------------------------------------------------------------------
 
 void CallsListModel::addCall (const shared_ptr<linphone::Call> &call) {
 	int index = findCallIndex(mList, call);
 	if( index < 0){
-		QSharedPointer<CallModel> callModel = QSharedPointer<CallModel>::create(call);
+		QSharedPointer<CallModel> callModel = QSharedPointer<CallModel>(new CallModel(call), &QObject::deleteLater);
 		qInfo() << QStringLiteral("Add call:") << callModel->getFullLocalAddress() << callModel->getFullPeerAddress();
 		App::getInstance()->getEngine()->setObjectOwnership(callModel.get(), QQmlEngine::CppOwnership);
 		
 		connect(callModel.get(), &CallModel::meAdminChanged, this, &CallsListModel::canMergeCallsChanged);
+		connect(callModel.get(), &CallModel::statusChanged, this, &CallsListModel::handleCallStatusChanged);
 		
 		add(callModel);
-		emit layoutChanged();
 		
 		if (call->getDir() == linphone::Call::Dir::Outgoing) {
 			QQuickWindow *callsWindow = App::getInstance()->getCallsWindow();
@@ -590,7 +612,7 @@ void CallsListModel::addDummyCall () {
 			App::smartShowWindow(callsWindow);
 	}
 	
-	QSharedPointer<CallModel> callModel = QSharedPointer<CallModel>::create(nullptr);
+	QSharedPointer<CallModel> callModel = QSharedPointer<CallModel>(new CallModel(nullptr), &QObject::deleteLater);
 	qInfo() << QStringLiteral("Add call:") << callModel->getFullLocalAddress() << callModel->getFullPeerAddress();
 	App::getInstance()->getEngine()->setObjectOwnership(callModel.get(), QQmlEngine::CppOwnership);
 	
@@ -600,30 +622,27 @@ void CallsListModel::addDummyCall () {
 		emit dataChanged(index(id, 0), index(id, 0));
 	});
 	connect(callModel.get(), &CallModel::meAdminChanged, this, &CallsListModel::canMergeCallsChanged);
+	connect(callModel.get(), &CallModel::statusChanged, this, &CallsListModel::handleCallStatusChanged);
 	
 	add(callModel);
-	emit layoutChanged();
 }
 
 void CallsListModel::removeCall (const shared_ptr<linphone::Call> &call) {
 	CallModel *callModel = nullptr;
 	
-	try {
-		callModel = &call->getData<CallModel>("call-model");
-	} catch (const out_of_range &) {
-		// The call model not exists because the linphone call state
-		// `CallStateIncomingReceived`/`CallStateOutgoingInit` was not notified.
-		qWarning() << QStringLiteral("Unable to find call:") << call.get();
+	if(!call->dataExists("call-model"))
 		return;
-	}
+	callModel = &call->getData<CallModel>("call-model");
 	if( callModel && callModel->getCallError() != ""){	// Wait some time to display an error on ending call.
 		QTimer::singleShot( DelayBeforeRemoveCall , this, [this, callModel] {
 				removeCallCb(callModel);
 		});
-	}else
+	}else{
 		remove(callModel);
+	}
 }
 
 void CallsListModel::removeCallCb (CallModel *callModel) {
+	callModel->removeCall();
 	remove(callModel);
 }
