@@ -27,6 +27,7 @@
 #include <QElapsedTimer>
 #include <QFileInfo>
 #include <QMimeDatabase>
+#include <QSettings>
 #include <QTimer>
 #include <QUuid>
 #include <QMessageBox>
@@ -37,8 +38,6 @@
 #include "ChatRoomListener.hpp"
 
 #include "app/App.hpp"
-#include "app/paths/Paths.hpp"
-#include "app/providers/ThumbnailProvider.hpp"
 #include "components/calls/CallsListModel.hpp"
 #include "components/chat/ChatModel.hpp"
 #include "components/chat-events/ChatCallModel.hpp"
@@ -52,8 +51,6 @@
 #include "components/content/ContentModel.hpp"
 #include "components/core/CoreHandlers.hpp"
 #include "components/core/CoreManager.hpp"
-#include "components/notifier/Notifier.hpp"
-#include "components/settings/AccountSettingsModel.hpp"
 #include "components/settings/SettingsModel.hpp"
 #include "components/participant/ParticipantModel.hpp"
 #include "components/participant/ParticipantListModel.hpp"
@@ -63,9 +60,7 @@
 #include "components/timeline/TimelineModel.hpp"
 #include "components/timeline/TimelineListModel.hpp"
 #include "components/core/event-count-notifier/AbstractEventCountNotifier.hpp"
-#include "utils/QExifImageHeader.hpp"
 #include "utils/Utils.hpp"
-#include "utils/Constants.hpp"
 #include "utils/LinphoneEnums.hpp"
 
 
@@ -81,6 +76,7 @@ void ChatRoomModel::connectTo(ChatRoomListener * listener){
 	connect(listener, &ChatRoomListener::messageReceived, this, &ChatRoomModel::onMessageReceived);
 	connect(listener, &ChatRoomListener::messagesReceived, this, &ChatRoomModel::onMessagesReceived);
 	connect(listener, &ChatRoomListener::newEvent, this, &ChatRoomModel::onNewEvent);
+	connect(listener, &ChatRoomListener::newEvents, this, &ChatRoomModel::onNewEvents);
 	connect(listener, &ChatRoomListener::chatMessageReceived, this, &ChatRoomModel::onChatMessageReceived);
 	connect(listener, &ChatRoomListener::chatMessagesReceived, this, &ChatRoomModel::onChatMessagesReceived);
 	connect(listener, &ChatRoomListener::chatMessageSending, this, &ChatRoomModel::onChatMessageSending);
@@ -107,8 +103,8 @@ void ChatRoomModel::connectTo(ChatRoomListener * listener){
 }
 
 // -----------------------------------------------------------------------------
-QSharedPointer<ChatRoomModel> ChatRoomModel::create(const std::shared_ptr<linphone::ChatRoom>& chatRoom, const std::list<std::shared_ptr<linphone::CallLog>>& callLogs){
-	QSharedPointer<ChatRoomModel> model = QSharedPointer<ChatRoomModel>::create(chatRoom, callLogs);
+QSharedPointer<ChatRoomModel> ChatRoomModel::create(const std::shared_ptr<linphone::ChatRoom>& chatRoom, const QMap<QString,QMap<QString, std::shared_ptr<linphone::CallLog>>>& lastCalls){
+	QSharedPointer<ChatRoomModel> model = QSharedPointer<ChatRoomModel>::create(chatRoom, lastCalls);
 	if(model){
 		model->mSelf = model;
 		 //chatRoom->addListener(model);
@@ -117,7 +113,7 @@ QSharedPointer<ChatRoomModel> ChatRoomModel::create(const std::shared_ptr<linpho
 		return nullptr;
 }
 
-ChatRoomModel::ChatRoomModel (const std::shared_ptr<linphone::ChatRoom>& chatRoom, const std::list<std::shared_ptr<linphone::CallLog>>& callLogs, QObject * parent) : ProxyListModel(parent){
+ChatRoomModel::ChatRoomModel (const std::shared_ptr<linphone::ChatRoom>& chatRoom, const QMap<QString,QMap<QString, std::shared_ptr<linphone::CallLog>>>& lastCalls, QObject * parent) : ProxyListModel(parent){
 	App::getInstance()->getEngine()->setObjectOwnership(this, QQmlEngine::CppOwnership);// Avoid QML to destroy it when passing by Q_INVOKABLE
 	CoreManager *coreManager = CoreManager::getInstance();
 	mCoreHandlers = coreManager->getHandlers();
@@ -129,9 +125,9 @@ ChatRoomModel::ChatRoomModel (const std::shared_ptr<linphone::ChatRoom>& chatRoo
 	
 	// Get messages.
 	mList.clear();
-	
-	setUnreadMessagesCount(mChatRoom->getUnreadMessagesCount());
-	setMissedCallsCount(0);
+
+	mUnreadMessagesCount = mChatRoom->getUnreadMessagesCount();
+	mMissedCallsCount = 0;
 	
 	QElapsedTimer timer;
 	timer.start();
@@ -161,34 +157,23 @@ ChatRoomModel::ChatRoomModel (const std::shared_ptr<linphone::ChatRoom>& chatRoo
 				connect(contact.get(), &ContactModel::contactUpdated, this, &ChatRoomModel::fullPeerAddressChanged);
 			}
 		}
-		
-		std::shared_ptr<linphone::CallLog> lastCall = nullptr;
-		QString peerAddress = getParticipantAddress();
-		std::shared_ptr<const linphone::Address> lLocalAddress = mChatRoom->getLocalAddress();
-		QString localAddress = Utils::coreStringToAppString(lLocalAddress->asStringUriOnly());
-		
-		if(callLogs.size() == 0) {
-			auto callHistory = CallsListModel::getCallHistory(peerAddress, localAddress);
-			if(callHistory.size() > 0)
-				lastCall = callHistory.front();
-		}else{// Find the last call in list
-			std::shared_ptr<linphone::Address> lPeerAddress = Utils::interpretUrl(peerAddress);
-			if( lPeerAddress && lLocalAddress){
-				auto itCallLog = std::find_if(callLogs.begin(), callLogs.end(), [lPeerAddress, lLocalAddress](std::shared_ptr<linphone::CallLog> c){
-					return c->getLocalAddress()->weakEqual(lLocalAddress) && c->getRemoteAddress()->weakEqual(lPeerAddress);
-				});
-				if( itCallLog != callLogs.end())
-					lastCall = *itCallLog;
+		time_t callDate = 0;
+		if(lastCalls.size() > 0){
+			QString peerAddress = getParticipantAddress();
+			QString localAddress = Utils::coreStringToAppString(mChatRoom->getLocalAddress()->asStringUriOnly());
+
+			auto itLocal = lastCalls.find(localAddress);
+			if(itLocal != lastCalls.end()){
+				auto itPeer = itLocal->find(peerAddress);
+				if(itPeer != itLocal->end()) {
+					callDate = itPeer.value()->getStartDate();
+					if( itPeer.value()->getStatus() == linphone::Call::Status::Success )
+						callDate += itPeer.value()->getDuration();
 				}
+			}
 		}
-			
-		if(lastCall){
-			auto callDate = lastCall->getStartDate();
-			if( lastCall->getStatus() == linphone::Call::Status::Success )
-				callDate += lastCall->getDuration();
-			setLastUpdateTime(QDateTime::fromMSecsSinceEpoch(std::max(mChatRoom->getLastUpdateTime(), callDate )*1000));
-		}else
-			setLastUpdateTime(QDateTime::fromMSecsSinceEpoch(mChatRoom->getLastUpdateTime()*1000));
+		setLastUpdateTime(QDateTime::fromMSecsSinceEpoch(std::max(mChatRoom->getLastUpdateTime(), callDate )*1000));
+		mSecurityLevel = (int)mChatRoom->getSecurityLevel();
 	}else
 		mParticipantListModel = nullptr;
 }
@@ -231,7 +216,7 @@ QVariant ChatRoomModel::data (const QModelIndex &index, int role) const {
 	
 	switch (role) {
 		case Roles::ChatEntry: return QVariant::fromValue(mList[row].get());
-		case Roles::SectionDate: return QVariant::fromValue(mList[row].objectCast<ChatEvent>()->getTimestamp().date());
+		case Roles::SectionDate: return QVariant::fromValue(mList[row].objectCast<ChatEvent>()->getReceivedTimestamp().date());
 	}
 	
 	return QVariant();
@@ -257,6 +242,7 @@ bool ChatRoomModel::removeRows (int row, int count, const QModelIndex &parent) {
 	else if (limit == mList.count())
 		emit lastEntryRemoved();
 	emit focused();// Removing rows is like having focus. Don't wait asynchronous events.
+	emit dataChanged(index(row), index(limit));
 	return true;
 }
 
@@ -391,6 +377,19 @@ int ChatRoomModel::getPresenceStatus() const {
 		return -1;
 }
 
+QDateTime ChatRoomModel::getPresenceTimestamp() const {
+	if( mChatRoom && mChatRoom->getNbParticipants() == 1 && !isGroupEnabled()){
+		auto participants = getParticipants(false);
+		auto contact = CoreManager::getInstance()->getContactsListModel()->findContactModelFromSipAddress(Utils::coreStringToAppString((*participants.begin())->getAddress()->asString()));
+		if(contact) {
+			return contact->getPresenceTimestamp();
+		}
+		else
+			return QDateTime();
+	}else
+		return QDateTime();
+}
+
 ParticipantListModel* ChatRoomModel::getParticipantListModel() const{
 	return mParticipantListModel.get();
 }
@@ -442,8 +441,20 @@ bool ChatRoomModel::isSecure() const{
 			|| mChatRoom->getSecurityLevel() == linphone::ChatRoomSecurityLevel::Safe);
 }
 
-int ChatRoomModel::getSecurityLevel() const{
-	return mChatRoom ? (int)mChatRoom->getSecurityLevel() : 0;
+int ChatRoomModel::getSecurityLevel() const {
+	return mSecurityLevel;
+}
+
+void ChatRoomModel::updateSecurityLevel(){
+	if(mChatRoom ) {
+		setSecurityLevel((int)mChatRoom->getSecurityLevel());
+	}
+}
+void ChatRoomModel::setSecurityLevel(int level){
+	if( mSecurityLevel != level){
+		mSecurityLevel = level;
+		emit securityLevelChanged(mSecurityLevel);
+	}
 }
 
 bool ChatRoomModel::isGroupEnabled() const{
@@ -486,6 +497,14 @@ bool ChatRoomModel::isUpdating() const{
 	return getState() == LinphoneEnums::ChatRoomStateCreationPending || getState() == LinphoneEnums::ChatRoomStateTerminationPending;
 }
 
+bool ChatRoomModel::isNotificationsEnabled() const{
+	auto id = getChatRoomId();
+	QSettings settings;
+	settings.beginGroup("chatrooms");
+	settings.beginGroup(id);
+	return settings.value("notifications", true).toBool();
+}
+
 std::shared_ptr<linphone::ChatRoom> ChatRoomModel::getChatRoom(){
 	return mChatRoom;
 }
@@ -494,7 +513,7 @@ QList<QString> ChatRoomModel::getComposers(){
 	return mComposers.values();
 }
 
-QString ChatRoomModel::getParticipantAddress(){
+QString ChatRoomModel::getParticipantAddress() const{
 	if(!isSecure()){
 		auto peerAddress = mChatRoom->getPeerAddress();
 		if( peerAddress)
@@ -601,6 +620,16 @@ void ChatRoomModel::enableMarkAsRead(const bool& enable){
 		emit markAsReadEnabledChanged();
 	}
 }
+void ChatRoomModel::enableNotifications(const bool& enable){
+	if(enable != isNotificationsEnabled()){
+		auto id = getChatRoomId();
+		QSettings settings;
+		settings.beginGroup("chatrooms");
+		settings.beginGroup(id);
+		settings.setValue("notifications", enable);
+		notificationsEnabledChanged();
+	}
+}
 
 void ChatRoomModel::setReply(ChatMessageModel * model){
 	if(model != mReplyModel.get()){
@@ -825,25 +854,25 @@ public:
 void ChatRoomModel::updateNewMessageNotice(const int& count){
 	if( mChatRoom ) {
 		if(mUnreadMessageNotice ) {
-				removeEntry(mUnreadMessageNotice.get());
+				remove(mUnreadMessageNotice);
 				mUnreadMessageNotice = nullptr;
 		}
 		if(count > 0){
 			QDateTime lastUnreadMessage = QDateTime::currentDateTime();
+			QDateTime lastReceivedMessage = lastUnreadMessage;
 			enableMarkAsRead(false);
 // Get chat messages
 			for (auto &message : mChatRoom->getHistory(mLastEntriesStep)) {
 				if( !message->isRead()) {
 					lastUnreadMessage = min(lastUnreadMessage, QDateTime::fromMSecsSinceEpoch(message->getTime() * 1000 - 1 ));	//-1 to be sure that event will be before the message
+					lastReceivedMessage = min(lastReceivedMessage, ChatMessageModel::initReceivedTimestamp(message, false).addMSecs(-1));
 				}
 			}			
-			mUnreadMessageNotice = ChatNoticeModel::create(ChatNoticeModel::NoticeType::NoticeUnreadMessages, lastUnreadMessage, QString::number(count));
-			beginInsertRows(QModelIndex(), 0, 0);
-			mList.prepend(mUnreadMessageNotice);
-			endInsertRows();
-			qDebug() << "New message notice timestamp to :" << lastUnreadMessage.toString();
+			mUnreadMessageNotice = ChatNoticeModel::create(ChatNoticeModel::NoticeType::NoticeUnreadMessages, lastUnreadMessage,lastReceivedMessage, QString::number(count));
+			if(mIsInitialized)
+				prepend(mUnreadMessageNotice);
+			qDebug() << "New message notice timestamp to :" << lastUnreadMessage.toString() << " recv at " << lastReceivedMessage.toString();
 		}
-		//emit layoutChanged();
 	}
 }
 
@@ -915,21 +944,23 @@ void ChatRoomModel::removeBindingCall(){
 }
 
 void ChatRoomModel::resetData(){
-	if( mBindingCalls == 0)
+	if( mBindingCalls == 0) {
 		ProxyListModel::resetData();
+		mIsInitialized = false;
+	}
 }
 
 void ChatRoomModel::initEntries(){
 	if( mList.size() > mLastEntriesStep)
 		resetData();
-	if(mList.size() == 0) {
+	if(!mIsInitialized) {
 		qDebug() << "Internal Entries : Init";
 	// On call : reinitialize all entries. This allow to free up memory
 		QList<QSharedPointer<ChatEvent> > entries;
 		QList<EntrySorterHelper> prepareEntries;
 	// Get chat messages
 		for (auto &message : mChatRoom->getHistory(mFirstLastEntriesStep)) {
-			prepareEntries << EntrySorterHelper(message->getTime() ,MessageEntry, message);
+			prepareEntries << EntrySorterHelper(ChatMessageModel::initReceivedTimestamp(message, false).toTime_t() ,MessageEntry, message);
 		}
 	// Get events
 		for(auto &eventLog : mChatRoom->getHistoryEvents(mFirstLastEntriesStep))
@@ -937,9 +968,10 @@ void ChatRoomModel::initEntries(){
 	// Get calls.
 		bool secureChatEnabled = CoreManager::getInstance()->getSettingsModel()->getSecureChatEnabled();
 		bool standardChatEnabled = CoreManager::getInstance()->getSettingsModel()->getStandardChatEnabled();
+		bool noChat = !secureChatEnabled && !standardChatEnabled;
 	
-		if( isOneToOne() && (secureChatEnabled && !standardChatEnabled && isSecure()
-			|| standardChatEnabled && !isSecure()) ) {
+		if(noChat || (isOneToOne() && (secureChatEnabled && !standardChatEnabled && isSecure()
+			|| standardChatEnabled && !isSecure())) ) {
 			auto callHistory = CallsListModel::getCallHistory(getParticipantAddress(), Utils::coreStringToAppString(mChatRoom->getLocalAddress()->asStringUriOnly()));
 			// callhistory is sorted from newest to oldest
 			int count = 0;
@@ -951,21 +983,29 @@ void ChatRoomModel::initEntries(){
 		EntrySorterHelper::getLimitedSelection(&entries, prepareEntries, mFirstLastEntriesStep, this);
 		qDebug() << "Internal Entries : Built";
 		if(entries.size() >0){
+			auto firstIndex = index(mList.size()-1,0);
 			beginInsertRows(QModelIndex(),0, entries.size()-1);
-			for(auto e : entries)
+			for(auto e : entries) {
+				if( e->mType == ChatRoomModel::EntryType::MessageEntry){
+					connect(e.objectCast<ChatMessageModel>().get(), &ChatMessageModel::remove, this, &ChatRoomModel::removeEntry);
+					auto model = e.objectCast<ChatMessageModel>().get();
+					qDebug() << "Adding" << model->getReceivedTimestamp().toString("yyyy/MM/dd hh:mm:ss.zzz") << model->getTimestamp().toString("yyyy/MM/dd hh:mm:ss.zzz") << (CoreManager::getInstance()->getSettingsModel()->isDeveloperSettingsAvailable() ? QString(model->getChatMessage()->getUtf8Text().c_str()).left(5) : "");
+				}
 				mList.push_back(e);
+			}
 			endInsertRows();
-			updateNewMessageNotice(mChatRoom->getUnreadMessagesCount());
+			auto lastIndex = index(mList.size()-1,0);
+			emit dataChanged(firstIndex,lastIndex);
+			updateNewMessageNotice(mChatRoom->getUnreadMessagesCount());// it will prepend notice if needed.
 		}
-		qDebug() << "Internal Entries : End";
+		qDebug() << "Internal Entries (" << mList.size() << ") : End ";
+		mIsInitialized = true;
 	}
-	mIsInitialized = true;
 }
 void ChatRoomModel::setEntriesLoading(const bool& loading){
 	if( mEntriesLoading != loading){
 		mEntriesLoading = loading;
 		emit entriesLoadingChanged(mEntriesLoading);
-		qApp->processEvents();
 	}
 }
 
@@ -1000,15 +1040,16 @@ int ChatRoomModel::loadMoreEntries(){
 				++itEntries;
 			}
 			if(!haveEntry)
-				prepareEntries << EntrySorterHelper(message->getTime() ,MessageEntry, message);
+				prepareEntries << EntrySorterHelper(ChatMessageModel::initReceivedTimestamp(message, false).toTime_t() ,MessageEntry, message);
 		}
 	
 	// Calls
 		bool secureChatEnabled = CoreManager::getInstance()->getSettingsModel()->getSecureChatEnabled();
 		bool standardChatEnabled = CoreManager::getInstance()->getSettingsModel()->getStandardChatEnabled();
+		bool noChat = !secureChatEnabled && !standardChatEnabled;
 	
-		if( isOneToOne() && (secureChatEnabled && !standardChatEnabled && isSecure()
-			|| standardChatEnabled && !isSecure()) ) {
+		if( noChat || (isOneToOne() && (secureChatEnabled && !standardChatEnabled && isSecure()
+			|| standardChatEnabled && !isSecure())) ) {
 			auto callHistory = CallsListModel::getCallHistory(getParticipantAddress(), Utils::coreStringToAppString(mChatRoom->getLocalAddress()->asStringUriOnly()));
 			int count = 0;
 			auto itCallHistory = callHistory.begin();
@@ -1037,13 +1078,16 @@ int ChatRoomModel::loadMoreEntries(){
 		EntrySorterHelper::getLimitedSelection(&entries, prepareEntries, mLastEntriesStep, this);
 		
 		if(entries.size() >0){
-			if(mPostModelChangedEvents)
+			if(mPostModelChangedEvents){
+				
 				beginInsertRows(QModelIndex(), 0, entries.size()-1);
+			}
 			for(auto entry : entries)
 				mList.prepend(entry);
-			if(mPostModelChangedEvents)
+			if(mPostModelChangedEvents){
 				endInsertRows();
-			//emit layoutChanged();
+				emit dataChanged(index(0),index(entries.size()-1));
+			}
 			updateLastUpdateTime();
 		}
 		newEntries = entries.size();
@@ -1078,6 +1122,8 @@ void ChatRoomModel::insertCall (const std::shared_ptr<linphone::CallLog> &callLo
 			beginInsertRows(QModelIndex(), row, row);
 			mList << model;
 			endInsertRows();
+			auto lastIndex = index(mList.size()-1,0);
+			emit dataChanged(lastIndex,lastIndex );
 			if (callLog->getStatus() == linphone::Call::Status::Success) {
 				model = ChatCallModel::create(callLog, false);
 				if(model)
@@ -1105,7 +1151,6 @@ void ChatRoomModel::insertCalls (const QList<std::shared_ptr<linphone::CallLog>
 		}
 		if(entries.size() > 0){
 			prepend(entries);
-			emit layoutChanged();
 		}
 	}
 }
@@ -1115,6 +1160,7 @@ QSharedPointer<ChatMessageModel> ChatRoomModel::insertMessageAtEnd (const std::s
 	if(mIsInitialized && !exists(message)){
 		model = ChatMessageModel::create(message);
 		if(model){
+			qDebug() << "Adding at end" << model->getReceivedTimestamp().toString("hh:mm:ss.zzz") << model->getTimestamp().toString("hh:mm:ss.zzz") << QString(message->getUtf8Text().c_str()).left(5);
 			connect(model.get(), &ChatMessageModel::remove, this, &ChatRoomModel::removeEntry);
 			setUnreadMessagesCount(mChatRoom->getUnreadMessagesCount());
 			add(model);
@@ -1136,7 +1182,6 @@ void ChatRoomModel::insertMessages (const QList<std::shared_ptr<linphone::ChatMe
 		if(entries.size() > 0){
 			prepend(entries);
 			setUnreadMessagesCount(mChatRoom->getUnreadMessagesCount());
-			emit layoutChanged();
 		}
 	}
 }
@@ -1160,11 +1205,24 @@ void ChatRoomModel::insertNotices (const QList<std::shared_ptr<linphone::EventLo
 		}
 		if(entries.size() > 0){
 			prepend(entries);
-			emit layoutChanged();
 		}
 	}
 }
 
+QString ChatRoomModel::getChatRoomId()const{
+	return getChatRoomId(getLocalAddress(), getPeerAddress());
+}
+
+QString ChatRoomModel::getChatRoomId(const QString& localAddress, const QString& remoteAddress){
+	return localAddress + "~"+remoteAddress;
+}
+
+QString ChatRoomModel::getChatRoomId(const std::shared_ptr<linphone::ChatRoom>& chatRoom){
+	auto localAddress = chatRoom->getLocalAddress()->clone();
+	localAddress->clean();
+	return getChatRoomId(Utils::coreStringToAppString(localAddress->asStringUriOnly()), (chatRoom->getPeerAddress() ? Utils::coreStringToAppString(chatRoom->getPeerAddress()->asStringUriOnly()) : ""));
+}
+
 // -----------------------------------------------------------------------------
 /*
 void ChatRoomModel::removeUnreadMessagesNotice() {
@@ -1209,9 +1267,7 @@ void ChatRoomModel::handlePresenceStatusReceived(std::shared_ptr<linphone::Frien
 				if(contact){
 					auto friendsAddresses = contact->getVcardModel()->getSipAddresses();
 					for(auto friendAddress = friendsAddresses.begin() ; !canUpdatePresence && friendAddress != friendsAddresses.end() ; ++friendAddress){
-						shared_ptr<linphone::Address> lAddress = CoreManager::getInstance()->getCore()->interpretUrl(
-									Utils::appStringToCoreString(friendAddress->toString())
-									);
+						shared_ptr<linphone::Address> lAddress = Utils::interpretUrl(friendAddress->toString());
 						canUpdatePresence = lAddress->weakEqual(*itContactAddress);
 					}	
 				}
@@ -1240,28 +1296,51 @@ void ChatRoomModel::onIsComposingReceived(const std::shared_ptr<linphone::ChatRo
 }
 
 void ChatRoomModel::onMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message){
+	if(message) ChatMessageModel::initReceivedTimestamp(message, true);
 	setUnreadMessagesCount(chatRoom->getUnreadMessagesCount());
 	updateLastUpdateTime();
 }
 
 void ChatRoomModel::onMessagesReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::list<std::shared_ptr<linphone::ChatMessage>> & messages){
+	for(auto message : messages)
+		if(message) ChatMessageModel::initReceivedTimestamp(message, true);
 	setUnreadMessagesCount(chatRoom->getUnreadMessagesCount());
 	updateLastUpdateTime();
 }
 
 
 void ChatRoomModel::onNewEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog){
-	if( eventLog->getType() == linphone::EventLog::Type::ConferenceCallEnded ){
-		setMissedCallsCount(mMissedCallsCount+1);
-	}else if( eventLog->getType() == linphone::EventLog::Type::ConferenceCreated ){
-		emit fullPeerAddressChanged();
+	if(eventLog){
+		if( eventLog->getType() == linphone::EventLog::Type::ConferenceCallEnded ){
+			setMissedCallsCount(mMissedCallsCount+1);
+		}else if( eventLog->getType() == linphone::EventLog::Type::ConferenceCreated ){
+			emit fullPeerAddressChanged();
+		}
+		updateLastUpdateTime();
 	}
+}
+
+void ChatRoomModel::onNewEvents(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::list<std::shared_ptr<linphone::EventLog>> & eventLogs){
+	int missCount = 0;
+	bool updatePeerAddress = false;
+	for(auto eventLog : eventLogs)
+		if(eventLog){
+			if( eventLog->getType() == linphone::EventLog::Type::ConferenceCallEnded )
+				++missCount;
+			if( eventLog->getType() == linphone::EventLog::Type::ConferenceCreated )
+				updatePeerAddress = true;
+		}
+	if(missCount > 0)
+		setMissedCallsCount(mMissedCallsCount+missCount);
+	if(updatePeerAddress)
+		emit fullPeerAddressChanged();
 	updateLastUpdateTime();
 }
 
 void ChatRoomModel::onChatMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) {
 	auto message = eventLog->getChatMessage();
 	if(message){
+		ChatMessageModel::initReceivedTimestamp(message, true);
 		insertMessageAtEnd(message);
 		updateLastUpdateTime();
 		emit messageReceived(message);
@@ -1272,6 +1351,7 @@ void ChatRoomModel::onChatMessagesReceived(const std::shared_ptr<linphone::ChatR
 	for(auto eventLog : eventLogs){
 		auto message = eventLog->getChatMessage();
 		if(message){
+			ChatMessageModel::initReceivedTimestamp(message, true);
 			insertMessageAtEnd(message);
 			updateLastUpdateTime();
 			emit messageReceived(message);
@@ -1282,6 +1362,7 @@ void ChatRoomModel::onChatMessagesReceived(const std::shared_ptr<linphone::ChatR
 void ChatRoomModel::onChatMessageSending(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog){
 	auto message = eventLog->getChatMessage();
 	if(message){
+		ChatMessageModel::initReceivedTimestamp(message, true, true);
 		insertMessageAtEnd(message);
 		updateLastUpdateTime();
 		emit messageReceived(message);
@@ -1289,6 +1370,8 @@ void ChatRoomModel::onChatMessageSending(const std::shared_ptr<linphone::ChatRoo
 }
 
 void ChatRoomModel::onChatMessageSent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog){
+	auto message = eventLog->getChatMessage();
+	if(message) ChatMessageModel::initReceivedTimestamp(message, true);	// Just in case
 	updateLastUpdateTime();
 }
 
@@ -1339,7 +1422,7 @@ void ChatRoomModel::onSecurityEvent(const std::shared_ptr<linphone::ChatRoom> &
 	if( e != events.end() )
 		insertNotice(*e);
 	updateLastUpdateTime();
-	emit securityLevelChanged((int)chatRoom->getSecurityLevel());
+	updateSecurityLevel();
 }
 void ChatRoomModel::onSubjectChanged(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog) {
 	auto events = chatRoom->getHistoryEvents(0);
@@ -1381,6 +1464,7 @@ void ChatRoomModel::onConferenceJoined(const std::shared_ptr<linphone::ChatRoom>
 	emit usernameChanged();
 	emit conferenceJoined(eventLog);
 	emit isReadOnlyChanged();
+	emit isMeAdminChanged();
 }
 
 void ChatRoomModel::onConferenceLeft(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog){
