@@ -64,7 +64,7 @@ public:
 	Q_PROPERTY(int unreadMessagesCount MEMBER mUnreadMessagesCount WRITE setUnreadMessagesCount NOTIFY unreadMessagesCountChanged)
 	Q_PROPERTY(int missedCallsCount MEMBER mMissedCallsCount WRITE setMissedCallsCount NOTIFY missedCallsCountChanged)
 	
-	Q_PROPERTY(int securityLevel READ getSecurityLevel NOTIFY securityLevelChanged)
+	Q_PROPERTY(int securityLevel READ getSecurityLevel WRITE setSecurityLevel NOTIFY securityLevelChanged)
 	Q_PROPERTY(bool groupEnabled READ isGroupEnabled NOTIFY groupEnabledChanged)
 	Q_PROPERTY(bool isConference READ isConference CONSTANT)
 	Q_PROPERTY(bool isOneToOne READ isOneToOne CONSTANT)
@@ -82,12 +82,14 @@ public:
 	Q_PROPERTY(QString username READ getUsername NOTIFY usernameChanged)
 	Q_PROPERTY(QString avatar READ getAvatar NOTIFY avatarChanged)
 	Q_PROPERTY(int presenceStatus READ getPresenceStatus NOTIFY presenceStatusChanged)
+	Q_PROPERTY(QDateTime presenceTimestamp READ getPresenceTimestamp NOTIFY presenceStatusChanged)
 	Q_PROPERTY(LinphoneEnums::ChatRoomState state READ getState NOTIFY stateChanged)
 	
 	Q_PROPERTY(long ephemeralLifetime READ getEphemeralLifetime WRITE setEphemeralLifetime NOTIFY ephemeralLifetimeChanged)
 	Q_PROPERTY(bool ephemeralEnabled READ isEphemeralEnabled WRITE setEphemeralEnabled NOTIFY ephemeralEnabledChanged)
 	Q_PROPERTY(bool canBeEphemeral READ canBeEphemeral NOTIFY canBeEphemeralChanged)
 	Q_PROPERTY(bool markAsReadEnabled READ markAsReadEnabled WRITE enableMarkAsRead NOTIFY markAsReadEnabledChanged)
+	Q_PROPERTY(bool notificationsEnabled READ isNotificationsEnabled WRITE enableNotifications NOTIFY notificationsEnabledChanged)
 	
 	Q_PROPERTY(ParticipantListModel* participants READ getParticipantListModel CONSTANT)
 	
@@ -96,8 +98,8 @@ public:
 	Q_PROPERTY(bool entriesLoading READ isEntriesLoading WRITE setEntriesLoading NOTIFY entriesLoadingChanged)
 	
 	
-	static QSharedPointer<ChatRoomModel> create(const std::shared_ptr<linphone::ChatRoom>& chatRoom, const std::list<std::shared_ptr<linphone::CallLog>>& callLogs = std::list<std::shared_ptr<linphone::CallLog>>());
-	ChatRoomModel (const std::shared_ptr<linphone::ChatRoom>& chatRoom, const std::list<std::shared_ptr<linphone::CallLog>>& callLogs = std::list<std::shared_ptr<linphone::CallLog>>(), QObject * parent = nullptr);
+	static QSharedPointer<ChatRoomModel> create(const std::shared_ptr<linphone::ChatRoom>& chatRoom, const QMap<QString,QMap<QString, std::shared_ptr<linphone::CallLog>>>& lastCalls = QMap<QString,QMap<QString, std::shared_ptr<linphone::CallLog>>>());
+	ChatRoomModel (const std::shared_ptr<linphone::ChatRoom>& chatRoom, const QMap<QString,QMap<QString, std::shared_ptr<linphone::CallLog>>>& lastCalls = QMap<QString,QMap<QString, std::shared_ptr<linphone::CallLog>>>(), QObject * parent = nullptr);
 	
 	~ChatRoomModel ();
 	
@@ -114,11 +116,13 @@ public:
 	Q_INVOKABLE QString getFullPeerAddress () const;
 	Q_INVOKABLE QString getFullLocalAddress () const;
 	Q_INVOKABLE QString getConferenceAddress () const;
-	
+	Q_INVOKABLE QString getParticipantAddress() const;	// return peerAddress if not secure else return the first participant SIP address.
+		
 	QString getSubject () const;
 	QString getUsername () const;
 	QString getAvatar () const;
 	int getPresenceStatus() const;
+	QDateTime getPresenceTimestamp() const;
 	LinphoneEnums::ChatRoomState getState() const;
 	bool isReadOnly() const;
 	bool isEphemeralEnabled() const;
@@ -129,6 +133,8 @@ public:
 	bool markAsReadEnabled() const;
 	Q_INVOKABLE bool isSecure() const;
 	int getSecurityLevel() const;
+	void updateSecurityLevel();
+	void setSecurityLevel(int level);
 	bool isGroupEnabled() const;
 	bool isConference() const;
 	bool isOneToOne() const;
@@ -139,12 +145,12 @@ public:
 	bool isEntriesLoading() const;
 	bool isBasic() const;
 	bool isUpdating() const;
+	bool isNotificationsEnabled() const;
 	
 	ParticipantListModel* getParticipantListModel() const;
 	std::list<std::shared_ptr<linphone::Participant>> getParticipants(const bool& withMe = true) const;
 	std::shared_ptr<linphone::ChatRoom> getChatRoom();
 	QList<QString> getComposers();
-	QString getParticipantAddress();	// return peerAddress if not secure else return the first participant SIP address.
 	int getAllUnreadCount();	// Return unread messages and missed call.
 		
 //---- Setters
@@ -159,6 +165,7 @@ public:
 	void setEphemeralEnabled(bool enabled);
 	void setEphemeralLifetime(long lifetime);
 	void enableMarkAsRead(const bool& enable);
+	void enableNotifications(const bool& enable);
 	
 	void setReply(ChatMessageModel * model);
 	ChatMessageModel * getReply()const;
@@ -194,7 +201,7 @@ public:
 	
 	bool mDeleteChatRoom = false;	// Use as workaround because of core->deleteChatRoom() that call destructor without takking account of count ref : call it in ChatRoomModel destructor	
 	int mLastEntriesStep = 50;		// Retrieve a part of the history to avoid too much processing
-	int mFirstLastEntriesStep = 10;	// Retrieve a part of the history to avoid too much processing at the init
+	int mFirstLastEntriesStep = 20;	// Retrieve a part of the history to avoid too much processing at the init
 	bool mMarkAsReadEnabled = true;
 	bool mEntriesLoading = false;
 	
@@ -206,6 +213,10 @@ public:
 	void insertNotice (const std::shared_ptr<linphone::EventLog> &enventLog);
 	void insertNotices (const QList<std::shared_ptr<linphone::EventLog>> &eventLogs);
 	
+	QString getChatRoomId()const;
+	static QString getChatRoomId(const QString& localAddress, const QString& remoteAddress);
+	static QString getChatRoomId(const std::shared_ptr<linphone::ChatRoom>& chatRoom);	// For convenience
+	
 	//--------------------		CHAT ROOM HANDLER
 	
 public slots:
@@ -213,6 +224,7 @@ public slots:
 	virtual void onMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<linphone::ChatMessage> & message);
 	virtual void onMessagesReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::list<std::shared_ptr<linphone::ChatMessage>> & messages);
 	virtual void onNewEvent(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
+	virtual void onNewEvents(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::list<std::shared_ptr<linphone::EventLog>> & eventLogs);
 	virtual void onChatMessageReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
 	virtual void onChatMessagesReceived(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::list<std::shared_ptr<linphone::EventLog>> & eventLogs);
 	virtual void onChatMessageSending(const std::shared_ptr<linphone::ChatRoom> & chatRoom, const std::shared_ptr<const linphone::EventLog> & eventLog);
@@ -279,6 +291,7 @@ signals:
 	void chatRoomDeleted();// Must be connected with DirectConnection mode
 	void replyChanged();
 	void updatingChanged();
+	void notificationsEnabledChanged();
 	
 // Chat Room listener callbacks	
 	
@@ -312,6 +325,7 @@ private:
 	QSharedPointer<ChatNoticeModel> mUnreadMessageNotice;
 	int mBindingCalls = 0;
 	bool mPostModelChangedEvents = true;
+	int mSecurityLevel = 0;
 	
 	QWeakPointer<ChatRoomModel> mSelf;
 };
