@@ -22,19 +22,18 @@
 
 #include <QQmlApplicationEngine>
 #include <QDesktopServices>
-#include <QImageReader>
 #include <QMessageBox>
+#include <QPainter>
 
 #include "app/App.hpp"
-#include "app/paths/Paths.hpp"
 #include "app/providers/ThumbnailProvider.hpp"
 
 #include "components/chat-events/ChatMessageModel.hpp"
+#include "components/conferenceInfo/ConferenceInfoModel.hpp"
+#include "components/core/CoreManager.hpp"
+#include "components/settings/SettingsModel.hpp"
 
-#include "utils/QExifImageHeader.hpp"
 #include "utils/Utils.hpp"
-#include "utils/Constants.hpp"
-#include "components/Components.hpp"
 
 // =============================================================================
 
@@ -157,75 +156,13 @@ void ContentModel::createThumbnail (const bool& force) {
 	if(force || isFile() || isFileEncrypted() || isFileTransfer()){
 		QString id;
 		QString path = getFilePath();
-		
-		auto appdata = ChatMessageModel::AppDataManager(mChatMessageModel ? QString::fromStdString(mChatMessageModel->getChatMessage()->getAppdata()) : "");
-		
-		if(!appdata.mData.contains(path) 
-				|| !QFileInfo(QString::fromStdString(Paths::getThumbnailsDirPath())+appdata.mData[path]).isFile()){
-			// File don't exist. Create the thumbnail
-			
-			QImage image(path);
-			if( image.isNull()){// Try to determine format from headers
-				QImageReader reader(path);
-				reader.setDecideFormatFromContent(true);
-				QByteArray format = reader.format();
-				if(!format.isEmpty())
-					image = QImage(path, format);
-			}
-			if (!image.isNull()){
-				int rotation = 0;
-				QExifImageHeader exifImageHeader;
-				if (exifImageHeader.loadFromJpeg(path))
-					rotation = int(exifImageHeader.value(QExifImageHeader::ImageTag::Orientation).toShort());
-				QImage thumbnail = image.scaled(
-							Constants::ThumbnailImageFileWidth, Constants::ThumbnailImageFileHeight,
-							Qt::KeepAspectRatio, Qt::SmoothTransformation
-							);
-				
-				if (rotation != 0) {
-					QTransform transform;
-					if (rotation == 3 || rotation == 4)
-						transform.rotate(180);
-					else if (rotation == 5 || rotation == 6)
-						transform.rotate(90);
-					else if (rotation == 7 || rotation == 8)
-						transform.rotate(-90);
-					thumbnail = thumbnail.transformed(transform);
-					if (rotation == 2 || rotation == 4 || rotation == 5 || rotation == 7)
-						thumbnail = thumbnail.mirrored(true, false);
-				}
-				QString uuid = QUuid::createUuid().toString();
-				id = QStringLiteral("%1.jpg").arg(uuid.mid(1, uuid.length() - 2));
-				
-				if (!thumbnail.save(QString::fromStdString(Paths::getThumbnailsDirPath()) + id , "jpg", 100)) {
-					qWarning() << QStringLiteral("Unable to create thumbnail of: `%1`.").arg(path);
-				}else{
-					appdata.mData[path] = id;
-					mAppData.mData[path] = id;
-					if(mChatMessageModel)
-						mChatMessageModel->getChatMessage()->setAppdata(appdata.toString().toStdString());
-				}
-			}
-		}
-		
 		if( path != ""){
 			setWasDownloaded( !path.isEmpty() && QFileInfo(path).isFile());
-			if(appdata.mData.contains(path) && !appdata.mData[path].isEmpty())
-				setThumbnail(QStringLiteral("image://%1/%2").arg(ThumbnailProvider::ProviderId).arg(appdata.mData[path]));
+			setThumbnail(QStringLiteral("image://%1/%2").arg(ThumbnailProvider::ProviderId).arg(path));
 		}
 	}
 }
 
-void ContentModel::removeThumbnail(){
-	for(QMap<QString, QString>::iterator itData = mAppData.mData.begin() ; itData != mAppData.mData.end() ; ++itData){
-		QString thumbnailPath = QString::fromStdString(Paths::getThumbnailsDirPath()) +itData.value();
-		if( QFileInfo(thumbnailPath).isFile()){
-			QFile(thumbnailPath).remove();
-		}
-	}
-	mAppData.mData.clear();
-}
-
 void ContentModel::removeDownloadedFile(){
 	QString path = getFilePath();
 	if( path != ""){
@@ -294,5 +231,30 @@ void ContentModel::openFile (bool showDirectory) {
 	}
 }
 
+bool ContentModel::saveAs (const QString& path){
+	QString cachePath = Utils::coreStringToAppString(mContent->exportPlainFile());
+	bool toDelete = true;
+	bool result = false;
+	if(cachePath.isEmpty()) {
+		cachePath = Utils::coreStringToAppString(mContent->getFilePath());
+		toDelete = false;
+	}
+	if(!cachePath.isEmpty())
+	{
+		QString decodedPath = QUrl::fromPercentEncoding(path.toUtf8());
+		QFile file(cachePath);
+		QFile newFile(decodedPath);
+		if(newFile.exists())
+			newFile.remove();
+		result = file.copy(decodedPath);
+		if(toDelete)
+			file.remove();
+		if(result)
+			QDesktopServices::openUrl(QUrl(QStringLiteral("file:///%1").arg(decodedPath)));
+	}
+	
+	return result;
+}
+
 void ContentModel::updateTransferData(){
 }
\ No newline at end of file
