@@ -20,15 +20,18 @@
 
 #include <QMutex>
 #include <QtDebug>
+#include <QSettings>
 #include <QThread>
 #include <QTimer>
 
 #include "app/App.hpp"
 #include "components/call/CallModel.hpp"
+#include "components/chat-events/ChatMessageModel.hpp"
 #include "components/contact/ContactModel.hpp"
 #include "components/notifier/Notifier.hpp"
 #include "components/settings/AccountSettingsModel.hpp"
 #include "components/settings/SettingsModel.hpp"
+#include "components/sip-addresses/SipAddressesModel.hpp"
 #include "components/timeline/TimelineListModel.hpp"
 #include "utils/Utils.hpp"
 
@@ -223,19 +226,30 @@ void CoreHandlers::onMessagesReceived (
 	SettingsModel *settingsModel = coreManager->getSettingsModel();
 	const App *app = App::getInstance();
 	QStringList notNotifyReasons;
+	QSettings appSettings;
 	
+	appSettings.beginGroup("chatrooms");
 	for(auto message : messages){
+		if(message) ChatMessageModel::initReceivedTimestamp(message, true);
 		if( !message || message->isOutgoing()  )
 			continue;
-		
-		messagesToSignal.push_back(message);
-		
 		// 1. Do not notify if chat is not activated.
 		if (chatRoom->getCurrentParams()->getEncryptionBackend() == linphone::ChatRoomEncryptionBackend::None && !settingsModel->getStandardChatEnabled()
 			|| chatRoom->getCurrentParams()->getEncryptionBackend() != linphone::ChatRoomEncryptionBackend::None && !settingsModel->getSecureChatEnabled())
 			continue;
+			
+		messagesToSignal.push_back(message);
 		
-		// 2. Notify with Notification popup.
+		// 2. Do not notify if the chatroom's notification has been deactivated.
+		appSettings.beginGroup(ChatRoomModel::getChatRoomId(chatRoom));
+		if(!appSettings.value("notifications", true).toBool()){
+			appSettings.endGroup();
+			continue;
+		}else{
+			appSettings.endGroup();
+		}
+		
+		// 3. Notify with Notification popup.
 		if (coreManager->getSettingsModel()->getChatNotificationsEnabled() 
 				&& (!app->hasFocus() || !Utils::isMe(chatRoom->getLocalAddress()))
 				&& !message->isRead())// On aggregation, the list can contains already displayed messages.
