@@ -38,6 +38,7 @@
 #include "components/ldap/LdapListModel.hpp"
 #include "components/recorder/RecorderManager.hpp"
 #include "components/settings/AccountSettingsModel.hpp"
+#include "components/settings/EmojisSettingsModel.hpp"
 #include "components/settings/SettingsModel.hpp"
 #include "components/sip-addresses/SipAddressesModel.hpp"
 #include "components/timeline/TimelineListModel.hpp"
@@ -92,14 +93,16 @@ CoreManager::~CoreManager(){
 
 void CoreManager::initCoreManager(){
 	qInfo() << "Init CoreManager";
+	mContactsListModel = new ContactsListModel(this);
+	mSipAddressesModel = new SipAddressesModel(this);	// at first in order to prioritzed on handler signals.
 	mAccountSettingsModel = new AccountSettingsModel(this);
 	mSettingsModel = new SettingsModel(this);
+	mEmojisSettingsModel = new EmojisSettingsModel(this);
 	mCallsListModel = new CallsListModel(this);
 	mChatModel = new ChatModel(this);
-	mContactsListModel = new ContactsListModel(this);
+	
 	mContactsImporterListModel = new ContactsImporterListModel(this);
 	mLdapListModel = new LdapListModel(this);
-	mSipAddressesModel = new SipAddressesModel(this);
 	mEventCountNotifier = new EventCountNotifier(this);
 	mTimelineListModel = new TimelineListModel(this);
 	mEventCountNotifier->updateUnreadMessageCount();
@@ -111,6 +114,10 @@ void CoreManager::initCoreManager(){
 	emit coreManagerInitialized();
 }
 
+bool CoreManager::isInitialized() const{
+	return mStarted;
+}
+
 AbstractEventCountNotifier * CoreManager::getEventCountNotifier(){
 	return mEventCountNotifier;
 }
@@ -213,18 +220,16 @@ void CoreManager::cleanLogs () const {
 
 void CoreManager::setDatabasesPaths () {
 	SET_DATABASE_PATH(Friends, Paths::getFriendsListFilePath());
-	linphone_core_set_call_logs_database_path(mCore->cPtr(), Paths::getCallHistoryFilePath().c_str());// Setting the message database let SDK to migrate data
 	if(QFile::exists(Utils::coreStringToAppString(Paths::getMessageHistoryFilePath()))){
 		linphone_core_set_chat_database_path(mCore->cPtr(), Paths::getMessageHistoryFilePath().c_str());// Setting the message database let SDK to migrate data
 		QFile::remove(Utils::coreStringToAppString(Paths::getMessageHistoryFilePath()));
 	}
 }
 
-#undef SET_DATABASE_PATH
-
 // -----------------------------------------------------------------------------
 
 void CoreManager::setOtherPaths () {
+	SET_DATABASE_PATH(CallLogs, Paths::getCallHistoryFilePath());// Setting the call logs database let SDK to migrate data
 	if (mCore->getZrtpSecretsFile().empty() || !Paths::filePathExists(mCore->getZrtpSecretsFile(), true))
 		mCore->setZrtpSecretsFile(Paths::getZrtpSecretsFilePath());// Use application path if Linphone default is not available
 	qInfo() << "Using ZrtpSecrets path : " << QString::fromStdString(mCore->getZrtpSecretsFile());
@@ -249,6 +254,8 @@ void CoreManager::setResourcesPaths () {
 
 // -----------------------------------------------------------------------------
 
+#undef SET_DATABASE_PATH
+
 void CoreManager::createLinphoneCore (const QString &configPath) {
 	qInfo() << QStringLiteral("Launch async core creation.");
 	
@@ -268,7 +275,6 @@ void CoreManager::createLinphoneCore (const QString &configPath) {
 	mCore->addListener(mHandlers);
 	mCore->setVideoDisplayFilter("MSQOGL");
 	mCore->usePreviewWindow(true);
-	mCore->enableVideoPreview(false);
 	// Force capture/display.
 	// Useful if the app was built without video support.
 	// (The capture/display attributes are reset by the core in this case.)
@@ -277,12 +283,15 @@ void CoreManager::createLinphoneCore (const QString &configPath) {
 		config->setInt("video", "capture", 1);
 		config->setInt("video", "display", 1);
 	}
+	mCore->enableVideoPreview(false);// SDK doesn't write the state in configuration if not ready.
+	config->setInt("video", "show_local", 0);// So : write ourself to turn off camera before starting the core.
 	QString userAgent = Utils::computeUserAgent(config);
 	mCore->setUserAgent(Utils::appStringToCoreString(userAgent), mCore->getVersion());
 	mCore->start();
 	setOtherPaths();
 	mCore->enableFriendListSubscription(true);
 	mCore->enableRecordAware(true);
+	mCore->setAccountCreatorBackend(linphone::AccountCreatorBackend::FlexiAPI);
 	if(mCore->getAccountCreatorUrl() == "")
 		mCore->setAccountCreatorUrl(Constants::DefaultFlexiAPIURL);
 	if( mCore->getAccountList().size() == 0)
@@ -310,7 +319,10 @@ void CoreManager::migrate () {
 	shared_ptr<linphone::Config> config = mCore->getConfig();
 	auto oldLimeServerUrl = mCore->getLimeX3DhServerUrl();// core url is deprecated : If core url exists, it must be copied to all linphone accounts.
 	int rcVersion = config->getInt(SettingsModel::UiSection, Constants::RcVersionName, 0);
-	if (oldLimeServerUrl.empty() && rcVersion == Constants::RcVersionCurrent)
+	if( !oldLimeServerUrl.empty()) {
+		mCore->setLimeX3DhServerUrl("");
+		mCore->enableLimeX3Dh(true);
+	}else if( rcVersion == Constants::RcVersionCurrent)
 		return;
 	if (rcVersion > Constants::RcVersionCurrent) {
 		qWarning() << QStringLiteral("RC file version (%1) is more recent than app rc file version (%2)!!!")
@@ -320,7 +332,6 @@ void CoreManager::migrate () {
 	
 	qInfo() << QStringLiteral("Migrate from old rc file (%1 to %2).")
 			   .arg(rcVersion).arg(Constants::RcVersionCurrent);
-	
 	bool setLimeServerUrl = false;
 	for(const auto &account : getAccountList()){
 		auto params = account->getParams();
@@ -356,19 +367,21 @@ void CoreManager::migrate () {
 				qInfo() << "Migrating" << accountIdentity << "for version 5. Video conference factory URI" << (exists ? std::string("unchanged") : std::string("= ") +Constants::DefaultVideoConferenceURI).c_str();
 				// note: using std::string.c_str() to avoid having double quotes in qInfo()
 			}
-			
-			if(!oldLimeServerUrl.empty())
-				newParams->setLimeServerUrl(oldLimeServerUrl);
-			else if( setLimeServerUrl)
-				newParams->setLimeServerUrl(Constants::DefaultLimeServerURL);
+			if( rcVersion < 6) {
+				newParams->setPublishExpires(Constants::DefaultPublishExpires);
+				qInfo() << "Migrating" << accountIdentity << "for version 6. publish expires =" << Constants::DefaultPublishExpires;
+			}
+			if(newParams->getLimeServerUrl().empty()){
+				if(!oldLimeServerUrl.empty())
+					newParams->setLimeServerUrl(oldLimeServerUrl);
+				else if( setLimeServerUrl)
+					newParams->setLimeServerUrl(Constants::DefaultLimeServerURL);
+			}
 			
 			account->setParams(newParams);
 		}
 	}
-	if( !oldLimeServerUrl.empty()) {
-		mCore->setLimeX3DhServerUrl("");
-		mCore->enableLimeX3Dh(true);
-	}else if(setLimeServerUrl) {
+	if( oldLimeServerUrl.empty() && setLimeServerUrl) {
 		mCore->enableLimeX3Dh(true);
 	}
 	
