@@ -43,6 +43,7 @@ class EventCountNotifier;
 class HistoryModel;
 class LdapListModel;
 class RecorderManager;
+class EmojisSettingsModel;
 class SettingsModel;
 class SipAddressesModel;
 class VcardModel;
@@ -56,6 +57,7 @@ class CoreManager : public QObject {
 	Q_PROPERTY(QString downloadUrl READ getDownloadUrl CONSTANT)
 	Q_PROPERTY(int eventCount READ getEventCount NOTIFY eventCountChanged)
 	Q_PROPERTY(int callLogsCount READ getCallLogsCount NOTIFY callLogsCountChanged)
+	Q_PROPERTY(bool initialized READ isInitialized NOTIFY coreManagerInitialized)
 	
 public:
 	bool started () const {
@@ -118,6 +120,9 @@ public:
 		Q_CHECK_PTR(mSettingsModel);
 		return mSettingsModel;
 	}
+	EmojisSettingsModel *getEmojisSettingsModel () const {
+		return mEmojisSettingsModel;
+	}
 	
 	AccountSettingsModel *getAccountSettingsModel () const {
 		Q_CHECK_PTR(mAccountSettingsModel);
@@ -162,6 +167,7 @@ public:
 	std::list<std::shared_ptr<linphone::Account>> getAccountList()const;
 	
 	static bool isInstanciated(){return mInstance!=nullptr;}
+	bool isInitialized() const;
 	
 	Q_INVOKABLE bool isLastRemoteProvisioningGood();
 	Q_INVOKABLE QString getUserAgent()const;
@@ -222,6 +228,7 @@ private:
 	
 	SipAddressesModel *mSipAddressesModel = nullptr;
 	SettingsModel *mSettingsModel = nullptr;
+	EmojisSettingsModel *mEmojisSettingsModel =nullptr;
 	AccountSettingsModel *mAccountSettingsModel = nullptr;
 	
 	EventCountNotifier *mEventCountNotifier = nullptr;
