@@ -31,14 +31,8 @@
 #include <QUrlQuery>
 #include <QImageReader>
 
-#include "app/App.hpp"
-#include "app/paths/Paths.hpp"
-#include "app/providers/ThumbnailProvider.hpp"
 #include "components/core/CoreHandlers.hpp"
 #include "components/core/CoreManager.hpp"
-#include "components/notifier/Notifier.hpp"
-#include "components/settings/SettingsModel.hpp"
-#include "utils/QExifImageHeader.hpp"
 #include "utils/Utils.hpp"
 
 #include "HistoryModel.hpp"
@@ -50,12 +44,15 @@ using namespace std;
 static inline void fillCallStartEntry (QVariantMap &dest, const shared_ptr<linphone::CallLog> &callLog) {
 	dest["type"] = HistoryModel::CallEntry;
 	dest["timestamp"] = QDateTime::fromMSecsSinceEpoch(callLog->getStartDate() * 1000);
+	dest["receivedTimestamp"] = dest["timestamp"];
 	dest["isOutgoing"] = callLog->getDir() == linphone::Call::Dir::Outgoing;
 	dest["status"] = static_cast<HistoryModel::CallStatus>(callLog->getStatus());
 	dest["isStart"] = true;
-	if(callLog->getConferenceInfo())
+	if(callLog->getConferenceInfo()){
 		dest["title"] = Utils::coreStringToAppString(callLog->getConferenceInfo()->getSubject());
-	dest["sipAddress"] = Utils::coreStringToAppString(callLog->getRemoteAddress()->asString());
+		dest["sipAddress"] = Utils::coreStringToAppString(callLog->getConferenceInfo()->getUri()->asString());
+	}else
+		dest["sipAddress"] = Utils::coreStringToAppString(callLog->getRemoteAddress()->asString());
 	dest["callId"] = Utils::coreStringToAppString(callLog->getCallId());
 	dest["wasConference"] = callLog->wasConference();
 }
@@ -63,12 +60,15 @@ static inline void fillCallStartEntry (QVariantMap &dest, const shared_ptr<linph
 static inline void fillCallEndEntry (QVariantMap &dest, const shared_ptr<linphone::CallLog> &callLog) {
 	dest["type"] = HistoryModel::CallEntry;
 	dest["timestamp"] = QDateTime::fromMSecsSinceEpoch((callLog->getStartDate() + callLog->getDuration()) * 1000);
+	dest["receivedTimestamp"] = dest["timestamp"];
 	dest["isOutgoing"] = callLog->getDir() == linphone::Call::Dir::Outgoing;
 	dest["status"] = static_cast<HistoryModel::CallStatus>(callLog->getStatus());
 	dest["isStart"] = false;
-	if(callLog->getConferenceInfo())
+	if(callLog->getConferenceInfo()){
 		dest["title"] = Utils::coreStringToAppString(callLog->getConferenceInfo()->getSubject());
-	dest["sipAddress"] = Utils::coreStringToAppString(callLog->getRemoteAddress()->asString());
+		dest["sipAddress"] = Utils::coreStringToAppString(callLog->getConferenceInfo()->getUri()->asString());
+	}else
+		dest["sipAddress"] = Utils::coreStringToAppString(callLog->getRemoteAddress()->asString());
 	dest["callId"] = Utils::coreStringToAppString(callLog->getCallId());
 	dest["wasConference"] = callLog->wasConference();
 }
@@ -112,7 +112,7 @@ QVariant HistoryModel::data (const QModelIndex &index, int role) const {
 		return QVariant::fromValue(data);
 	}
 	case Roles::SectionDate:
-		return QVariant::fromValue(mEntries[row].first["timestamp"].toDate());
+		return QVariant::fromValue(mEntries[row].first["receivedTimestamp"].toDate());
 	}
 	
 	return QVariant();
@@ -127,7 +127,7 @@ bool HistoryModel::removeRows (int row, int count, const QModelIndex &parent) {
 	
 	if (row < 0 || count < 0 || limit >= mEntries.count())
 		return false;
-	
+	emit layoutAboutToBeChanged();
 	beginRemoveRows(parent, row, limit);
 	
 	for (int i = 0; i < count; ++i) {
@@ -143,6 +143,7 @@ bool HistoryModel::removeRows (int row, int count, const QModelIndex &parent) {
 		emit lastEntryRemoved();
 	emit CoreManager::getInstance()->callLogsCountChanged();
 	emit focused();// Removing rows is like having focus. Don't wait asynchronous events.
+	emit layoutChanged();
 	return true;
 }
 
@@ -231,11 +232,11 @@ void HistoryModel::insertCall (const shared_ptr<linphone::CallLog> &callLog) {
 	const QList<HistoryEntryData>::iterator *start = nullptr
 	) {
 		auto it = lower_bound(start ? *start : mEntries.begin(), mEntries.end(), entry, [](const HistoryEntryData &a, const HistoryEntryData &b) {
-			return a.first["timestamp"] < b.first["timestamp"];
+			return a.first["receivedTimestamp"] < b.first["receivedTimestamp"];
 		});
 		
 		int row = int(distance(mEntries.begin(), it));
-		
+		emit layoutAboutToBeChanged();
 		beginInsertRows(QModelIndex(), row, row);
 		it = mEntries.insert(it, entry);
 		endInsertRows();
