@@ -281,13 +281,20 @@ void Notifier::notifyReceivedMessages (const list<shared_ptr<linphone::ChatMessa
 		shared_ptr<linphone::ChatMessage> message = messages.front();
 		
 		if( messages.size() == 1){
-			if(! message->getFileTransferInformation() ){
+			auto fileContent = message->getFileTransferInformation();
+			if(!fileContent  ){
 				foreach(auto content, message->getContents()){
 					if(content->isText())
 						txt += content->getUtf8Text().c_str();
 				}
-			}else
+			}else if( fileContent->isVoiceRecording())
+			//: 'Voice message received!' : message to warn the user in a notofication for voice messages.
+				txt = tr("newVoiceMessage");
+			else
 				txt = tr("newFileMessage");
+			if(txt.isEmpty() && message->hasConferenceInvitationContent())
+			//: 'Conference invitation received!' : Notification about receiving an invitation to a conference.
+				txt = tr("newConferenceInvitation");
 		}else
 		//: 'New messages received!' Notification that warn the user of new messages.
 			txt = tr("newChatRoomMessages");
@@ -324,10 +331,13 @@ void Notifier::notifyReceivedCall (const shared_ptr<linphone::Call> &call) {
 	map["call"].setValue(callModel);
 	CREATE_NOTIFICATION(Notifier::ReceivedCall, map)
 			
-			QObject::connect(callModel, &CallModel::statusChanged, notification, [this, notification](CallModel::CallStatus status) {
+	QObject::connect(callModel, &CallModel::statusChanged, notification, [this, notification](CallModel::CallStatus status) {
 		if (status == CallModel::CallStatusEnded || status == CallModel::CallStatusConnected)
 			deleteNotification(QVariant::fromValue(notification));
 	});
+	QObject::connect(callModel, &CallModel::destroyed, notification, [this, notification]() {
+			deleteNotification(QVariant::fromValue(notification));
+	});
 	
 }
 
