@@ -33,7 +33,7 @@
 #include "app/proxyModel/ProxyListModel.hpp"
 
 #define ADD_COLOR(COLOR, VALUE, DESCRIPTION) \
-	color = QSharedPointer<ColorModel>::create(COLOR, VALUE, DESCRIPTION); \
+	color = QSharedPointer<ColorModel>::create(COLOR, QColor(VALUE), QColor(), DESCRIPTION, ColorModel::CONTEXT_NORMAL); \
 	add(color);
 
 #define ADD_COLOR_WITH_LINK(COLOR, VALUE, DESCRIPTION, LINK) \
@@ -76,8 +76,14 @@ class ColorListModel : public ProxyListModel {
 		ADD_COLOR("n", "#A1A1A1", "Primary color for pressed button")
 		ADD_COLOR("o", "#D0D8DE", "Primary color for disabled button")
 		
-		ADD_COLOR("outgoing_bg","#F3F3F3","Outgoing message background")
-		ADD_COLOR("incoming_bg","#D0D8DE","Incoming message background")
+		ADD_COLOR("outgoing_bg","#FFEEE5","Outgoing message background")
+		ADD_COLOR("incoming_bg","#F3F3F3","Incoming message background")
+		
+		ADD_COLOR("outgoing_reply_mark_bg","#FF9E67","Outgoing reply message mark background")
+		ADD_COLOR("incoming_reply_mark_bg","#9B9B9B","Incoming reply message mark background")
+		
+		ADD_COLOR("reply_file_bg","#F4F4F4","File icon background in reply")
+		ADD_COLOR("extension_file_border","#DEDEDE","File icon border in reply")
 		
 		ADD_COLOR("primary_accept", "#9ECD1D", "Primary color for accepting button")
 		
@@ -191,6 +197,17 @@ class ColorListModel : public ProxyListModel {
 		ADD_COLOR("ma_d_b_fg", "white", "[M] Main disabled button : foreground")
 		ADD_COLOR("ma_h_b_fg", "white", "[M] Main hovered button : foreground")
 		ADD_COLOR("ma_p_b_fg", "white", "[M] Main pressed button : foreground")
+		
+// Inverse
+		ADD_COLOR("ma_n_b_inv_bg", "transparent", "[M] Main normal button : inverse background")
+		ADD_COLOR("ma_d_b_inv_bg", "transparent", "[M] Main disabled button : inverse background")
+		ADD_COLOR("ma_h_b_inv_bg", "transparent", "[M] Main hovered button : inverse background")
+		ADD_COLOR("ma_p_b_inv_bg", "transparent", "[M] Main pressed button : inverse background")
+		
+		ADD_COLOR_WITH_LINK("ma_n_b_inv_fg", "", "[M] Main normal button : inverse foreground", "i")
+		ADD_COLOR_WITH_LINK("ma_d_b_inv_fg", "", "[M] Main disabled button : inverse foreground", "primary_d")
+		ADD_COLOR_WITH_LINK("ma_h_b_inv_fg", "", "[M] Main hovered button : inverse foreground", "b")
+		ADD_COLOR_WITH_LINK("ma_p_b_inv_fg", "", "[M] Main pressed button : inverse foreground", "m")
 //-------------------------------------
 // Accept Actions : like accepting a call
 		ADD_COLOR_WITH_LINK("a_n_b_bg", "", "[M] Accept normal button : background", "primary_accept")
@@ -285,7 +302,7 @@ class ColorListModel : public ProxyListModel {
 		
 		// Field error.
 		ADD_COLOR("error", "#FF0000", "Error Generic button.")
-		
+		ADD_COLOR_WITH_ALPHA("c", 80, "")
 		ADD_COLOR_WITH_ALPHA("g", 10, "")
 		ADD_COLOR_WITH_ALPHA("g", 20, "")
 		ADD_COLOR_WITH_ALPHA("g", 90, "")
@@ -316,7 +333,7 @@ public:
 // color : if empty, use the color from link
 // description : describe the color
 // idLink : link this color with another ID
-	Q_INVOKABLE ColorModel * add(const QString& id, const QString& idLink, QString description = "", QString color = "", const int& overrideAlpha = -1, const  ColorModel::ContextMode& context = ColorModel::CONTEXT_NORMAL);
+	Q_INVOKABLE ColorModel * add(const QString& id, const QString& idLink, QString description = "", QString color = "", const int& overrideAlpha = -1, ColorModel::ContextMode context = ColorModel::CONTEXT_FROMLINK);
 	Q_INVOKABLE ColorModel * addImageColor(const QString& id, const QString& imageId, const QString& idLink, QString description = "", QString color = "");
 	
 	void addLink(const QString& a, const QString& b);
@@ -337,6 +354,10 @@ public slots:
 signals:
 	void colorChanged();
 	
+// Internal mechanics
+	void uiResetColors();
+	void uiAddColor(ColorModel* colorModel);
+	
 private:
 	void add(QSharedPointer<ColorModel> imdn);
 	QString buildDescription(QString description);	// return a description from id by splitting '_'
