@@ -51,6 +51,7 @@ public:
 	Q_PROPERTY(time_t timeOfJoining READ getTimeOfJoining CONSTANT)
 	Q_PROPERTY(bool videoEnabled READ isVideoEnabled NOTIFY videoEnabledChanged)
 	Q_PROPERTY(bool isMe READ isMe CONSTANT)
+	Q_PROPERTY(bool isLocal READ isLocal WRITE setIsLocal NOTIFY isLocalChanged)// Can change on call update. Not really used but it just in case as Object can be initialized with empty call/device.
 	Q_PROPERTY(bool isPaused READ getPaused WRITE setPaused NOTIFY isPausedChanged)
 	Q_PROPERTY(bool isSpeaking READ getIsSpeaking WRITE setIsSpeaking NOTIFY isSpeakingChanged)
 	Q_PROPERTY(bool isMuted READ getIsMuted NOTIFY isMutedChanged)
@@ -63,6 +64,7 @@ public:
 	time_t getTimeOfJoining() const;
 	bool isVideoEnabled() const;
 	bool isMe() const;
+	bool isLocal()const;
 	bool getPaused() const;
 	bool getIsSpeaking() const;
 	bool getIsMuted() const;
@@ -72,6 +74,7 @@ public:
 	
 	void setPaused(bool paused);
 	void setIsSpeaking(bool speaking);
+	void setIsLocal(bool local);
 	void setState(LinphoneEnums::ParticipantDeviceState state);
 	
 	virtual void onIsSpeakingChanged(const std::shared_ptr<linphone::ParticipantDevice> & participantDevice, bool isSpeaking);
@@ -82,6 +85,7 @@ public:
 	
 	void connectTo(ParticipantDeviceListener * listener);
 	void updateVideoEnabled();
+	void updateIsLocal();
 	
 public slots:
 	void onSecurityLevelChanged(std::shared_ptr<const linphone::Address> device);
@@ -92,11 +96,13 @@ signals:
 	void isPausedChanged();
 	void isSpeakingChanged();
 	void isMutedChanged();
+	void isLocalChanged();
 	void stateChanged();
 
 private:
 
 	bool mIsMe = false;
+	bool mIsLocal = false;
 	bool mIsVideoEnabled;
 	bool mIsPaused = false;
 	bool mIsSpeaking = false;
