@@ -19,8 +19,7 @@
  */
 
 #include "components/core/CoreManager.hpp"
-#include "components/settings/AccountSettingsModel.hpp"
-#include "components/sip-addresses/SipAddressesModel.hpp"
+#include "components/settings/SettingsModel.hpp"
 #include "components/conference/ConferenceModel.hpp"
 #include "utils/Utils.hpp"
 
@@ -92,8 +91,11 @@ QString ParticipantListModel::addressesToString()const{
 	QStringList txt;
 	for(auto item : mList){
 		auto participant = item.objectCast<ParticipantModel>();
-		if( participant->getParticipant())// is Participant. We test it because this participant is not accepted by chat room yet.
-			txt << Utils::coreStringToAppString(participant->getParticipant()->getAddress()->asStringUriOnly());
+		if( participant->getParticipant()) {// is Participant. We test it because this participant is not accepted by chat room yet.
+			auto address = participant->getParticipant()->getAddress()->clone();
+			address->clean();
+			txt << Utils::toDisplayString(Utils::coreStringToAppString(address->asStringUriOnly()), CoreManager::getInstance()->getSettingsModel()->getSipDisplayMode());
+		}
 	}
 	txt.removeFirst();// Remove me
 	return txt.join(", ");
@@ -153,6 +155,8 @@ void ParticipantListModel::updateParticipants () {
 			}
 			if( itDbParticipant == dbParticipants.end()){
 				int row = itParticipant - mList.begin();
+				if(!changed)
+					emit layoutAboutToBeChanged();
 				beginRemoveRows(QModelIndex(), row, row);
 				itParticipant = mList.erase(itParticipant);
 				endRemoveRows();
@@ -196,7 +200,6 @@ void ParticipantListModel::add (QSharedPointer<ParticipantModel> participant){
 	connect(this, &ParticipantListModel::securityLevelChanged, participant.get(), &ParticipantModel::onSecurityLevelChanged);
 	connect(participant.get(),&ParticipantModel::updateAdminStatus, this, &ParticipantListModel::setAdminStatus);
 	ProxyListModel::add(participant);
-	emit layoutChanged();
 	emit participantsChanged();
 }
 
