@@ -75,6 +75,7 @@ AccountSettingsModel::AccountSettingsModel (QObject *parent) : QObject(parent) {
 	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::primaryUsernameChanged);
 	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::primarySipAddressChanged);
 	QObject::connect(this, &AccountSettingsModel::accountSettingsUpdated, this, &AccountSettingsModel::accountsChanged);
+	mSelectedAccount = coreManager->getCore()->getDefaultAccount();
 }
 
 // -----------------------------------------------------------------------------
@@ -85,6 +86,16 @@ shared_ptr<const linphone::Address> AccountSettingsModel::getUsedSipAddress () c
 	return account ? account->getParams()->getIdentityAddress() : core->createPrimaryContactParsed();
 }
 
+ std::shared_ptr<linphone::Account> AccountSettingsModel::findAccount(shared_ptr<const linphone::Address> address) const {
+	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
+	list<shared_ptr<linphone::Account>> accounts = CoreManager::getInstance()->getAccountList();
+	for(auto account : accounts){
+		if(account && account->getContactAddress() && account->getContactAddress()->weakEqual(address))
+			return account;
+	}
+	return nullptr;
+}
+
 void AccountSettingsModel::setUsedSipAddress (const shared_ptr<const linphone::Address> &address) {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	shared_ptr<linphone::Account> account = core->getDefaultAccount();
@@ -129,9 +140,7 @@ bool AccountSettingsModel::addOrUpdateAccount (std::shared_ptr<linphone::Account
 		}
 		
 		coreManager->addingAccount(account->getParams());
-		coreManager->getSettingsModel()->configureRlsUri(account);
-	}else
-		coreManager->getSettingsModel()->configureRlsUri();
+	}
 	
 	emit accountSettingsUpdated();
 	
@@ -149,7 +158,8 @@ QVariantMap AccountSettingsModel::getAccountDescription (const shared_ptr<linpho
 				: QString("");
 	}
 	map["serverAddress"] = Utils::coreStringToAppString(accountParams->getServerAddress()->asString());
-	map["registrationDuration"] = accountParams->getPublishExpires();
+	map["registrationDuration"] = accountParams->getExpires();
+	map["publishDuration"] = accountParams->getPublishExpires();
 	
 	if( map["serverAddress"].toString().toUpper().contains("TRANSPORT="))// transport has been specified : let the RFC select the transport
 		map["transport"] = LinphoneEnums::toString(LinphoneEnums::fromLinphone(accountParams->getTransport()));
@@ -171,6 +181,10 @@ QVariantMap AccountSettingsModel::getAccountDescription (const shared_ptr<linpho
 	map["publishPresence"] = accountParams->publishEnabled();
 	map["avpfEnabled"] = accountParams->getAvpfMode() == linphone::AVPFMode::Enabled;
 	map["registrationState"] = mapLinphoneRegistrationStateToUi(account->getState());
+	map["dialPrefix"] = Utils::coreStringToAppString(accountParams->getInternationalPrefix());
+	map["dialPrefixCallChat"] = accountParams->getUseInternationalPrefixForCallsAndChats();
+	map["dialEscapePlus"] = accountParams->dialEscapePlusEnabled();
+	map["rtpBundleEnabled"] = accountParams->rtpBundleEnabled();
 	
 	shared_ptr<linphone::NatPolicy> natPolicy = accountParams->getNatPolicy();
 	bool createdNat = !natPolicy;
@@ -179,6 +193,7 @@ QVariantMap AccountSettingsModel::getAccountDescription (const shared_ptr<linpho
 	map["iceEnabled"] = natPolicy->iceEnabled();
 	map["turnEnabled"] = natPolicy->turnEnabled();
 	
+	
 	const string &turnUser(natPolicy->getStunServerUsername());
 	const string &stunServer(natPolicy->getStunServer());
 	
@@ -190,11 +205,13 @@ QVariantMap AccountSettingsModel::getAccountDescription (const shared_ptr<linpho
 		accountParamsUpdated->setNatPolicy(natPolicy);
 		account->setParams(accountParamsUpdated);
 	}
-	
-	shared_ptr<const linphone::AuthInfo> authInfo = CoreManager::getInstance()->getCore()->findAuthInfo(
+	if(turnUser != ""){
+		shared_ptr<const linphone::AuthInfo> authInfo = CoreManager::getInstance()->getCore()->findAuthInfo(
 				"", turnUser, stunServer
 				);
-	map["turnPassword"] = authInfo ? Utils::coreStringToAppString(authInfo->getPassword()) : QString("");
+		map["turnPassword"] = authInfo ? Utils::coreStringToAppString(authInfo->getPassword()) : QString("");
+	}else
+		map["turnPassword"] = "";
 	
 	return map;
 }
@@ -221,6 +238,16 @@ QString AccountSettingsModel::getLimeServerUrl() const{
 	return account ? Utils::coreStringToAppString(account->getParams()->getLimeServerUrl()) : "";
 }
 
+bool AccountSettingsModel::getUseInternationalPrefixForCallsAndChats() const{
+	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
+	if(core){
+		shared_ptr<linphone::Account> account = core->getDefaultAccount();
+		if(account)
+			return account->getParams()->getUseInternationalPrefixForCallsAndChats();
+	}
+	return false;
+}
+
 void AccountSettingsModel::setDefaultAccount (const shared_ptr<linphone::Account> &account) {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	if (mSelectedAccount != account) {
@@ -247,6 +274,13 @@ void AccountSettingsModel::setDefaultAccountFromSipAddress (const QString &sipAd
 	
 	qWarning() << "Unable to set default account from:" << sipAddress;
 }
+
+void AccountSettingsModel::enableRegister (std::shared_ptr<linphone::Account> account, bool enable){
+	auto params = account->getParams()->clone();
+	enableRegister(params, enable, Utils::coreStringToAppString(params->getContactParameters()));
+	account->setParams(params);
+}
+
 void AccountSettingsModel::removeAccount (const shared_ptr<linphone::Account> &account) {
 	
 	CoreManager *coreManager = CoreManager::getInstance();
@@ -263,7 +297,7 @@ void AccountSettingsModel::removeAccount (const shared_ptr<linphone::Account> &a
 	}
 // "message-expires" is used to keep contact for messages. Setting to 0 will remove the contact for messages too.
 // Check if a "message-expires" exists and set it to 0
-	QStringList parameters = Utils::coreStringToAppString(account->getParams()->getContactParameters()).split(";");
+	QStringList parameters = Utils::coreStringToAppString(account->getParams()->getContactParameters()).split(";", Qt::SkipEmptyParts);
 	for(int i = 0 ; i < parameters.size() ; ++i){
 		QStringList fields = parameters[i].split("=");
 		if( fields.size() > 1 && fields[0].simplified() == "message-expires"){
@@ -272,10 +306,11 @@ void AccountSettingsModel::removeAccount (const shared_ptr<linphone::Account> &a
 	}
 	auto accountParams = account->getParams()->clone();
 	accountParams->setContactParameters(Utils::appStringToCoreString(parameters.join(";")));	
+	bool isRegistered = account->getState() == linphone::RegistrationState::Ok;
 	if (account->setParams(accountParams) == -1) {
 		qWarning() << QStringLiteral("Unable to reset message-expiry property before removing account: `%1`.")
 				  .arg(QString::fromStdString(account->getParams()->getIdentityAddress()->asString()));
-	}else if(account->getParams()->registerEnabled()) { // Wait for update
+	}else if(isRegistered && account->getParams()->registerEnabled()) { // Wait for update
 		mRemovingAccounts.push_back(account);
 	}else{// Registration is not enabled : Removing without wait.
 		CoreManager::getInstance()->getCore()->removeAccount(account);
@@ -284,6 +319,29 @@ void AccountSettingsModel::removeAccount (const shared_ptr<linphone::Account> &a
 	emit accountSettingsUpdated();
 }
 
+void AccountSettingsModel::enableRegister(std::shared_ptr<linphone::AccountParams> params, bool registerEnabled, QString contactParameters){
+	bool findMessageExpires = false;
+	QStringList parameters = contactParameters.split(";", Qt::SkipEmptyParts);
+	for(int i = 0 ; i < parameters.size() ; ++i){
+		QStringList fields = parameters[i].split("=");
+		if( fields.size() > 1 && fields[0].simplified() == "message-expires"){
+			findMessageExpires = true;
+			if(!registerEnabled)// replace message-expires by 0 in order to not get new incoming messages.
+				parameters[i] = Constants::DefaultContactParametersOnRemove;
+			else if(!params->registerEnabled() && fields[1].toInt() == 0)
+				parameters[i] = Constants::DefaultContactParameters;
+		}
+	}
+	if(!findMessageExpires){
+		if(!registerEnabled)// message-expires was not found we need to disable the account.
+			parameters.push_back(Constants::DefaultContactParametersOnRemove);
+		else if(!params->registerEnabled())// Switch on
+			parameters.push_back(Constants::DefaultContactParameters);
+	}
+	params->setContactParameters(Utils::appStringToCoreString(parameters.join(";")));
+	params->enableRegister(registerEnabled);
+}
+
 bool AccountSettingsModel::addOrUpdateAccount(
 		const shared_ptr<linphone::Account> &account,
 		const QVariantMap &data
@@ -320,8 +378,10 @@ bool AccountSettingsModel::addOrUpdateAccount(
 	}
 	
 	if(data.contains("registrationDuration"))
-		accountParams->setPublishExpires(data["registrationDuration"].toInt());
-	if(data.contains("route")) {
+		accountParams->setExpires(data["registrationDuration"].toInt());
+	if(data.contains("publishDuration"))
+		accountParams->setPublishExpires(data["publishDuration"].toInt());
+	if(data.contains("route") && data["route"].toString() != "") {
 		std::list<std::shared_ptr<linphone::Address>> routes;
 		routes.push_back(Utils::interpretUrl(data["route"].toString()));
 		accountParams->setRoutesAddresses(routes);
@@ -331,13 +391,17 @@ bool AccountSettingsModel::addOrUpdateAccount(
 	txt = data["videoConferenceUri"].toString();
 	accountParams->setAudioVideoConferenceFactoryAddress(Utils::interpretUrl(txt));
 	accountParams->setLimeServerUrl(Utils::appStringToCoreString(data["limeServerUrl"].toString()));
-		
+
+	QString contactParameters = Utils::coreStringToAppString(accountParams->getContactParameters());
 	if(data.contains("contactParams"))
-		accountParams->setContactParameters(Utils::appStringToCoreString(data["contactParams"].toString()));
+		contactParameters = data["contactParams"].toString();
 	if(data.contains("avpfInterval"))
 		accountParams->setAvpfRrInterval(uint8_t(data["avpfInterval"].toInt()));
-	if(data.contains("registerEnabled"))
-		accountParams->enableRegister(data.contains("registerEnabled") ? data["registerEnabled"].toBool() : true);
+	if(data.contains("registerEnabled")){
+		enableRegister(accountParams, data["registerEnabled"].toBool(), contactParameters);
+	}else{
+		accountParams->setContactParameters(Utils::appStringToCoreString(contactParameters));
+	}
 	if(data.contains("publishPresence")) {
 		newPublishPresence = accountParams->publishEnabled() != data["publishPresence"].toBool();
 		accountParams->enablePublish(data["publishPresence"].toBool());
@@ -348,6 +412,15 @@ bool AccountSettingsModel::addOrUpdateAccount(
 			? linphone::AVPFMode::Enabled
 			: linphone::AVPFMode::Default
 			  );
+	if(data.contains("dialPrefix"))
+		accountParams->setInternationalPrefix(Utils::appStringToCoreString(data["dialPrefix"].toString()));
+	if(data.contains("dialPrefixCallChat"))
+		accountParams->setUseInternationalPrefixForCallsAndChats(data["dialPrefixCallChat"].toBool());
+	if(data.contains("dialEscapePlus"))
+		accountParams->enableDialEscapePlus(data["dialEscapePlus"].toBool());
+	if(data.contains("rtpBundleEnabled"))
+		accountParams->enableRtpBundle(data["rtpBundleEnabled"].toBool());
+	
 	
 	shared_ptr<linphone::NatPolicy> natPolicy = accountParams->getNatPolicy();
 	bool createdNat = !natPolicy;
@@ -370,24 +443,26 @@ bool AccountSettingsModel::addOrUpdateAccount(
 	if( createdNat)
 		accountParams->setNatPolicy(natPolicy);
 	
-	shared_ptr<linphone::Core> core(CoreManager::getInstance()->getCore());
-	shared_ptr<const linphone::AuthInfo> authInfo(core->findAuthInfo("", turnUser, stunServer));
-	if (authInfo) {
-		shared_ptr<linphone::AuthInfo> clonedAuthInfo(authInfo->clone());
-		clonedAuthInfo->setUserid(turnUser);
-		clonedAuthInfo->setUsername(turnUser);
-		clonedAuthInfo->setPassword(Utils::appStringToCoreString(data["turnPassword"].toString()));
-		core->addAuthInfo(clonedAuthInfo);
-		core->removeAuthInfo(authInfo);
-	} else
-		core->addAuthInfo(linphone::Factory::get()->createAuthInfo(
-							  turnUser,
-							  turnUser,
-							  Utils::appStringToCoreString(data["turnPassword"].toString()),
-						  "",
-						  stunServer,
-						  ""
-    ));
+	if( turnUser != ""){
+		shared_ptr<linphone::Core> core(CoreManager::getInstance()->getCore());
+		shared_ptr<const linphone::AuthInfo> authInfo(core->findAuthInfo("", turnUser, stunServer));
+		if (authInfo) {
+			shared_ptr<linphone::AuthInfo> clonedAuthInfo(authInfo->clone());
+			clonedAuthInfo->setUserid(turnUser);
+			clonedAuthInfo->setUsername(turnUser);
+			clonedAuthInfo->setPassword(Utils::appStringToCoreString(data["turnPassword"].toString()));
+			core->addAuthInfo(clonedAuthInfo);
+			core->removeAuthInfo(authInfo);
+		} else
+			core->addAuthInfo(linphone::Factory::get()->createAuthInfo(
+								  turnUser,
+								  turnUser,
+								  Utils::appStringToCoreString(data["turnPassword"].toString()),
+							  "",
+							  stunServer,
+							  ""
+		));
+	}
 	if( newPublishPresence)
 		emit publishPresenceChanged();
 	return addOrUpdateAccount(account, accountParams);
@@ -398,7 +473,7 @@ bool AccountSettingsModel::addOrUpdateAccount (
 ) {
 	shared_ptr<linphone::Account> account;
 	QString sipAddress = data["sipAddress"].toString();
-	shared_ptr<linphone::Address> address = CoreManager::getInstance()->getCore()->interpretUrl(sipAddress.toStdString());
+	shared_ptr<linphone::Address> address = Utils::interpretUrl(sipAddress);
 	
 	for (const auto &databaseAccount : CoreManager::getInstance()->getAccountList())
 	  if (databaseAccount->getParams()->getIdentityAddress()->weakEqual(address)) {
@@ -519,12 +594,12 @@ QString AccountSettingsModel::getDefaultAccountDomain() const{
 QVariantList AccountSettingsModel::getAccounts () const {
 	shared_ptr<linphone::Core> core = CoreManager::getInstance()->getCore();
 	QVariantList accounts;
-	
-	if(CoreManager::getInstance()->getSettingsModel()->getShowLocalSipAccount()) {
+	auto settingsModel = CoreManager::getInstance()->getSettingsModel();
+	if(settingsModel->getShowLocalSipAccount()) {
 		QVariantMap account;
 		account["sipAddress"] = Utils::coreStringToAppString(core->createPrimaryContactParsed()->asStringUriOnly());
 		account["fullSipAddress"] = Utils::coreStringToAppString(core->createPrimaryContactParsed()->asString());
-		account["unreadMessageCount"] = core->getUnreadChatMessageCountFromLocal(core->createPrimaryContactParsed());
+		account["unreadMessageCount"] = settingsModel->getStandardChatEnabled() || settingsModel->getSecureChatEnabled() ?  core->getUnreadChatMessageCountFromLocal(core->createPrimaryContactParsed()) : 0;
 		account["missedCallCount"] = CoreManager::getInstance()->getMissedCallCountFromLocal(account["sipAddress"].toString());
 		account["account"].setValue(nullptr);
 		accounts << account;
@@ -532,11 +607,13 @@ QVariantList AccountSettingsModel::getAccounts () const {
 	
 	for (const auto &account : CoreManager::getInstance()->getAccountList()) {
 		QVariantMap accountMap;
-		accountMap["sipAddress"] = Utils::coreStringToAppString(account->getParams()->getIdentityAddress()->asStringUriOnly());
-		accountMap["fullSipAddress"] = Utils::coreStringToAppString(account->getParams()->getIdentityAddress()->asString());
+		auto params = account->getParams();
+		accountMap["sipAddress"] = Utils::coreStringToAppString(params->getIdentityAddress()->asStringUriOnly());
+		accountMap["fullSipAddress"] = Utils::coreStringToAppString(params->getIdentityAddress()->asString());
 		accountMap["account"].setValue(account);
-		accountMap["unreadMessageCount"] = account->getUnreadChatMessageCount();
+		accountMap["unreadMessageCount"] = settingsModel->getStandardChatEnabled() || settingsModel->getSecureChatEnabled() ? account->getUnreadChatMessageCount() : 0;
 		accountMap["missedCallCount"] = CoreManager::getInstance()->getMissedCallCountFromLocal(accountMap["sipAddress"].toString());
+		accountMap["registerEnabled"] = params->registerEnabled();
 		accounts << accountMap;
 	}
 	
@@ -558,7 +635,6 @@ void AccountSettingsModel::handleRegistrationStateChanged (
 			QTimer::singleShot(60000, [authInfo](){// 60s is just to be sure. account_update remove deleted account only after 32s
 				CoreManager::getInstance()->getCore()->removeAuthInfo(authInfo);
 			});
-		coreManager->getSettingsModel()->configureRlsUri();
 	}else if(mRemovingAccounts.contains(account)){
 		mRemovingAccounts.removeAll(account);
 		QTimer::singleShot(100, [account, this](){// removeAccount cannot be called from callback
