@@ -32,6 +32,7 @@
 #include "app/logger/Logger.hpp"
 #include "app/paths/Paths.hpp"
 
+#include "components/assistant/AssistantModel.hpp"
 #include "components/core/CoreManager.hpp"
 #include "components/tunnel/TunnelModel.hpp"
 #include "include/LinphoneApp/PluginNetworkHelper.hpp"
@@ -52,6 +53,9 @@ const string SettingsModel::ContactsSection("contacts_import");
 SettingsModel::SettingsModel (QObject *parent) : QObject(parent) {
 	CoreManager *coreManager = CoreManager::getInstance();
 	mConfig = coreManager->getCore()->getConfig();
+	
+	connect(this, &SettingsModel::dontAskAgainInfoEncryptionChanged, this, &SettingsModel::haveDontAskAgainChoicesChanged);
+	connect(this, &SettingsModel::haveAtLeastOneVideoCodecChanged, this, &SettingsModel::videoAvailableChanged);
 
 	QObject::connect(coreManager->getHandlers().get(), &CoreHandlers::callCreated,
 			 this, &SettingsModel::handleCallCreated);
@@ -68,8 +72,48 @@ SettingsModel::SettingsModel (QObject *parent) : QObject(parent) {
 	connect(coreManager->getAccountSettingsModel(), &AccountSettingsModel::accountSettingsUpdated, this, &SettingsModel::groupChatEnabledChanged);
 	connect(coreManager->getAccountSettingsModel(), &AccountSettingsModel::accountSettingsUpdated, this, &SettingsModel::videoConferenceEnabledChanged);
 	connect(coreManager->getAccountSettingsModel(), &AccountSettingsModel::accountSettingsUpdated, this, &SettingsModel::secureChatEnabledChanged);
+#ifdef ENABLE_QT_KEYCHAIN
+	connect(&mVfsUtils, &VfsUtils::keyRead, this, [&](const QString& key, const QString& value){
+		if(key == mVfsUtils.getApplicationVfsEncryptionKey()){
+			if(!getVfsEncrypted()){
+				QSettings settings;
+				settings.beginGroup("keychain");
+				settings.setValue("enabled", true);
+				emit vfsEncryptedChanged();
+			}
+		}
+	});
+	connect(&mVfsUtils, &VfsUtils::keyWritten, this, [&](const QString& key){
+		if(key == mVfsUtils.getApplicationVfsEncryptionKey()){
+			if(!getVfsEncrypted()){
+				QSettings settings;
+				settings.beginGroup("keychain");
+				settings.setValue("enabled", true);
+				emit vfsEncryptedChanged();
+			}
+		}
+	});
+	connect(&mVfsUtils, &VfsUtils::keyDeleted, this, [&](const QString& key){
+		if(key == mVfsUtils.getApplicationVfsEncryptionKey()){
+			QSettings settings;
+			settings.beginGroup("keychain");
+			settings.setValue("enabled", false);
+			emit vfsEncryptedChanged();
+			if(mVfsUtils.needToDeleteUserData())
+				Utils::deleteAllUserData();
+			else{
+				qInfo() << "Exiting App from VFS settings";
+				App::getInstance()->quit();
+			}
+		}
+	});
 	
-	configureRlsUri();
+	
+	connect(&mVfsUtils, &VfsUtils::error, this, [&](){
+		
+	});
+#endif
+	updateRlsUri();
 }
 
 SettingsModel::~SettingsModel()
@@ -178,15 +222,27 @@ void SettingsModel::setFetchRemoteConfigurationEnabled (bool status) {
 	emit fetchRemoteConfigurationEnabledChanged(status);
 }
 
+bool SettingsModel::getAutoApplyProvisioningConfigUriHandlerEnabled () const {
+	return !!mConfig->getInt(UiSection, "auto_apply_provisioning_config_uri_handler", 0);
+}
+
+void SettingsModel::setAutoApplyProvisioningConfigUriHandlerEnabled (bool status) {
+	mConfig->setInt(UiSection, "auto_apply_provisioning_config_uri_handler", status);
+	emit autoApplyProvisioningConfigUriHandlerEnabledChanged();
+}
+
+
 // ---------------------------------------------------------------------------
 
 bool SettingsModel::getAssistantSupportsPhoneNumbers () const {
-	return !!mConfig->getInt(UiSection, "assistant_supports_phone_numbers", 1);
+	return !!mConfig->getInt(UiSection, getEntryFullName(UiSection, "assistant_supports_phone_numbers") , 1);
 }
 
 void SettingsModel::setAssistantSupportsPhoneNumbers (bool status) {
-	mConfig->setInt(UiSection, "assistant_supports_phone_numbers", status);
-	emit assistantSupportsPhoneNumbersChanged(status);
+	if(!isReadOnly(UiSection, "assistant_supports_phone_numbers")) {
+		mConfig->setInt(UiSection, "assistant_supports_phone_numbers", status);
+		emit assistantSupportsPhoneNumbersChanged(status);
+	}
 }
 
 bool SettingsModel::useWebview() const{
@@ -225,7 +281,12 @@ void SettingsModel::setAssistantLogoutUrl (QString url) {
 }
 
 bool SettingsModel::isCguAccepted () const{
-	return !!mConfig->getInt(UiSection, "read_and_agree_terms_and_privacy", 0);
+#ifdef APPLICATION_VENDOR
+	QString applicationVendor = APPLICATION_VENDOR;
+#else
+	QString applicationVendor;
+#endif
+	return !!mConfig->getInt(UiSection, "read_and_agree_terms_and_privacy", ( applicationVendor != "" && Constants::CguUrl != QString("") && Constants::PrivatePolicyUrl != QString("") ? 0 : 1));
 }
 
 void SettingsModel::acceptCgu(const bool accept){
@@ -573,15 +634,15 @@ QVariantMap SettingsModel::getVideoDefinition () const {
 }
 
 QVariantMap SettingsModel::getCurrentPreviewVideoDefinition () const {
-	auto definition = CoreManager::getInstance()->getCore()->getCurrentPreviewVideoDefinition();
-	if(definition)
-		return createMapFromVideoDefinition(definition);
-	else {
-		QVariantMap map;
-		map["width"] = 0;
-		map["height"] = 0;
-		return map;
+	if(CoreManager::getInstance()->getCore()->videoPreviewEnabled()){
+		auto definition = CoreManager::getInstance()->getCore()->getCurrentPreviewVideoDefinition();
+		if(definition)
+			return createMapFromVideoDefinition(definition);
 	}
+	QVariantMap map;
+	map["width"] = 0;
+	map["height"] = 0;
+	return map;
 }
 
 void SettingsModel::setVideoDefinition (const QVariantMap &definition) {
@@ -592,9 +653,17 @@ void SettingsModel::setVideoDefinition (const QVariantMap &definition) {
 	emit videoDefinitionChanged(definition);
 }
 
-bool SettingsModel::getVideoSupported () const {
-	return CoreManager::getInstance()->getCore()->videoSupported();
+bool SettingsModel::getVideoEnabled() const {
+	return CoreManager::getInstance()->getCore()->videoSupported() && !!mConfig->getInt(UiSection, "video_enabled", 1);
 }
+
+void SettingsModel::setVideoEnabled(const bool& enable){
+	if( CoreManager::getInstance()->getCore()->videoSupported()){
+		mConfig->setInt(UiSection, "video_enabled", enable);
+		emit videoEnabledChanged();
+	}
+}
+
 void SettingsModel::setHighMosaicQuality(){
 	mConfig->setString("video", "max_mosaic_size", "");
 }
@@ -612,6 +681,19 @@ void SettingsModel::setShowVideoCodecs (bool status) {
 	emit showVideoCodecsChanged(status);
 }
 
+bool SettingsModel::getVideoAvailable() const{
+	return getVideoEnabled() && haveAtLeastOneVideoCodec();
+}
+
+bool SettingsModel::haveAtLeastOneVideoCodec() const{
+	auto codecs = CoreManager::getInstance()->getCore()->getVideoPayloadTypes();
+	for (auto &codec : codecs){
+		if(codec->enabled() && codec->isUsable())
+			return true;
+	}
+	return false;
+}
+
 // =============================================================================
 void SettingsModel::updateCameraMode(){
 	auto mode = mConfig->getString("video", "main_display_mode", "OccupyAllSpace");	
@@ -1015,6 +1097,21 @@ bool SettingsModel::getPostQuantumAvailable() const{
 	return CoreManager::getInstance()->getCore() && CoreManager::getInstance()->getCore()->getPostQuantumAvailable();
 }
 
+bool SettingsModel::getDontAskAgainInfoEncryption() const{
+	return mConfig->getBool(UiSection, "dont_ask_again_info_encryption", false);
+}
+
+void SettingsModel::setDontAskAgainInfoEncryption(bool show){
+	if(show != getDontAskAgainInfoEncryption()) {
+		mConfig->setBool(UiSection, "dont_ask_again_info_encryption", show);
+		emit dontAskAgainInfoEncryptionChanged();
+	}
+}
+
+bool SettingsModel::getHaveDontAskAgainChoices() const {
+	return getDontAskAgainInfoEncryption();
+}
+
 // -----------------------------------------------------------------------------
 
 bool SettingsModel::getLimeState () const {
@@ -1033,7 +1130,7 @@ void SettingsModel::setLimeState (const bool& state) {
 // -----------------------------------------------------------------------------
 
 bool SettingsModel::getContactsEnabled () const {
-	return !!mConfig->getInt(UiSection, "contacts_enabled", 1);
+	return !!mConfig->getInt(UiSection, getEntryFullName(UiSection, "contacts_enabled"), 1);
 }
 
 void SettingsModel::setContactsEnabled (bool status) {
@@ -1045,6 +1142,17 @@ void SettingsModel::setContactsEnabled (bool status) {
 int SettingsModel::getIncomingCallTimeout() const {
 	return CoreManager::getInstance()->getCore()->getIncTimeout();
 }
+
+int SettingsModel::getCreateEphemeralChatRooms() const{
+	return mConfig->getInt(UiSection, "create_ephemeral_chat_rooms", 0);
+}
+
+void SettingsModel::setCreateEphemeralChatRooms(int seconds) {
+	if(!isReadOnly(UiSection, "create_ephemeral_chat_rooms"))
+		mConfig->setInt(UiSection, "create_ephemeral_chat_rooms", seconds);
+	emit createEphemeralsChatRoomsChanged();
+}
+
 // =============================================================================
 // Network.
 // =============================================================================
@@ -1344,57 +1452,30 @@ bool SettingsModel::getRlsUriEnabled () const {
 }
 
 void SettingsModel::setRlsUriEnabled (bool status) {
+	if(getRlsUriEnabled () != status){
+		mConfig->setInt(UiSection, "rls_uri_enabled", status);
+		emit rlsUriEnabledChanged(status);
+	}
+}
+
+QString SettingsModel::getRlsUri() const{
+	return Utils::coreStringToAppString(mConfig->getString("sip", "rls_uri", ""));
+}
+
+void SettingsModel::setRlsUri (const QString& rlsUri){
+	bool status = !rlsUri.isEmpty();
 	mConfig->setInt(UiSection, "rls_uri_enabled", status);
-	mConfig->setString("sip", "rls_uri", status ? Constants::DefaultRlsUri : "");
+	mConfig->setString("sip", "rls_uri", Utils::appStringToCoreString(rlsUri));
+	emit rlsUriChanged();
 	emit rlsUriEnabledChanged(status);
 }
 
-static string getRlsUriDomain () {
-	static string domain;
-	if (!domain.empty())
-		return domain;
-
-	shared_ptr<linphone::Address> linphoneAddress = CoreManager::getInstance()->getCore()->createAddress(Constants::DefaultRlsUri);
-	Q_CHECK_PTR(linphoneAddress);
-	domain = linphoneAddress->getDomain();
-	return domain;
-}
-
-void SettingsModel::configureRlsUri () {
-	// Ensure rls uri is empty.
-	if (!getRlsUriEnabled()) {
-		mConfig->setString("sip", "rls_uri", "");
-		return;
+void SettingsModel::updateRlsUri(){
+	if( getRlsUriEnabled() && getRlsUri().isEmpty()){// if enabled, uri should not be empty : set default. This allow to take account of old configuration.
+		setRlsUri(Constants::DefaultRlsUri);
 	}
-
-	// Set rls uri if necessary.
-	const string domain = getRlsUriDomain();
-	for (const auto &account : CoreManager::getInstance()->getAccountList())
-		if (account->getParams()->getDomain() == domain) {
-			mConfig->setString("sip", "rls_uri", Constants::DefaultRlsUri);
-			return;
-		}
-
-	mConfig->setString("sip", "rls_uri", "");
 }
 
-void SettingsModel::configureRlsUri (const std::string& domain) {
-	if (!getRlsUriEnabled()) {
-		mConfig->setString("sip", "rls_uri", "");
-		return;
-	}
-
-	const string currentDomain = getRlsUriDomain();
-	if (domain == currentDomain) {
-		mConfig->setString("sip", "rls_uri", Constants::DefaultRlsUri);
-		return;
-	}
-
-	mConfig->setString("sip", "rls_uri", "");
-}
-void SettingsModel::configureRlsUri (const shared_ptr<const linphone::Account> &account) {
-	configureRlsUri(account->getParams()->getDomain());
-}
 //------------------------------------------------------------------------------
 
 bool SettingsModel::tunnelAvailable() const{
@@ -1416,26 +1497,64 @@ QFont SettingsModel::getTextMessageFont() const{
 }
 
 void SettingsModel::setTextMessageFont(const QFont& font){
-	mConfig->setString(UiSection, "text_message_font", Utils::appStringToCoreString(font.family()));
-	setTextMessageFontSize(font.pointSize());
+	QString family;
+	int pointSize;
+	if(font == QFont()){
+		family = Constants::DefaultFont;
+		pointSize = Constants::DefaultFontPointSize;
+	}else{
+		family = font.family();
+		pointSize = font.pointSize();
+	}
+	mConfig->setString(UiSection, "text_message_font", Utils::appStringToCoreString(family));
+	setTextMessageFontSize(pointSize);
 	emit textMessageFontChanged(font);
 }
 
 int SettingsModel::getTextMessageFontSize() const{
-	return mConfig->getInt(UiSection, "text_message_font_size", 10);
+	return mConfig->getInt(UiSection, "text_message_font_size", Constants::DefaultFontPointSize);
 }
 
 void SettingsModel::setTextMessageFontSize(const int& size){
 	mConfig->setInt(UiSection, "text_message_font_size", size);
 	emit textMessageFontSizeChanged(size);
 }
+
+QFont SettingsModel::getEmojiFont() const{
+	QString family = Utils::coreStringToAppString(mConfig->getString(UiSection, "emoji_font", Utils::appStringToCoreString(QFont(Constants::DefaultEmojiFont).family())));
+	int pointSize = getTextMessageFontSize();
+	return QFont(family,pointSize);
+}
+
+void SettingsModel::setEmojiFont(const QFont& font){
+	QString family;
+	int pointSize;
+	if(font == QFont()){
+		family = Constants::DefaultEmojiFont;
+		pointSize = Constants::DefaultEmojiFontPointSize;
+	}else{
+		family = font.family();
+		pointSize = font.pointSize();
+	}
+	mConfig->setString(UiSection, "emoji_font", Utils::appStringToCoreString(family));
+	setEmojiFontSize(pointSize);
+	emit emojiFontChanged(font);
+}
+
+int SettingsModel::getEmojiFontSize() const{
+	return mConfig->getInt(UiSection, "emoji_font_size", Constants::DefaultEmojiFontPointSize);
+}
+
+void SettingsModel::setEmojiFontSize(const int& size){
+	mConfig->setInt(UiSection, "emoji_font_size", size);
+	emit emojiFontSizeChanged(size);
+}
 	
 QString SettingsModel::getSavedScreenshotsFolder () const {
-	return QDir::cleanPath(
-			       Utils::coreStringToAppString(
-							    mConfig->getString(UiSection, "saved_screenshots_folder", Paths::getCapturesDirPath())
-							    )
-			       ) + QDir::separator();
+	auto path = mConfig->getString(UiSection, "saved_screenshots_folder", "");
+	if(path == "")
+		path = Paths::getCapturesDirPath();
+	return QDir::cleanPath(Utils::coreStringToAppString(path)) + QDir::separator();
 }
 
 void SettingsModel::setSavedScreenshotsFolder (const QString &folder) {
@@ -1447,15 +1566,17 @@ void SettingsModel::setSavedScreenshotsFolder (const QString &folder) {
 // -----------------------------------------------------------------------------
 
 static inline string getLegacySavedCallsFolder (const shared_ptr<linphone::Config> &config) {
-	return config->getString(SettingsModel::UiSection, "saved_videos_folder", Paths::getCapturesDirPath());
+	auto path = config->getString(SettingsModel::UiSection, "saved_videos_folder", "");
+	if(path == "")// Avoid to call default function if exist because calling Path:: will create a folder to be writable.
+		path = Paths::getCapturesDirPath();
+	return path;
 }
 
 QString SettingsModel::getSavedCallsFolder () const {
-	return QDir::cleanPath(
-			       Utils::coreStringToAppString(
-							    mConfig->getString(UiSection, "saved_calls_folder", getLegacySavedCallsFolder(mConfig))
-							    )
-			       ) + QDir::separator();
+	auto path = mConfig->getString(UiSection, "saved_calls_folder", "");// Avoid to call default function if exist.
+	if(path == "")
+		path = getLegacySavedCallsFolder(mConfig);
+	return QDir::cleanPath(Utils::coreStringToAppString(path)) + QDir::separator();
 }
 
 void SettingsModel::setSavedCallsFolder (const QString &folder) {
@@ -1467,11 +1588,10 @@ void SettingsModel::setSavedCallsFolder (const QString &folder) {
 // -----------------------------------------------------------------------------
 
 QString SettingsModel::getDownloadFolder () const {
-	return QDir::cleanPath(
-			       Utils::coreStringToAppString(
-							    mConfig->getString(UiSection, "download_folder", Paths::getDownloadDirPath())
-							    )
-			       ) + QDir::separator();
+	auto path = mConfig->getString(UiSection, "download_folder", "");// Avoid to call default function if exist because calling Path:: will create a folder to be writable.
+	if(path == "" )
+		path = Paths::getDownloadDirPath();
+	return QDir::cleanPath(Utils::coreStringToAppString(path)) + QDir::separator();
 }
 
 void SettingsModel::setDownloadFolder (const QString &folder) {
@@ -1524,8 +1644,15 @@ void SettingsModel::setExitOnClose (bool value) {
 	emit exitOnCloseChanged(value);
 }
 
+bool SettingsModel::isCheckForUpdateAvailable(){
+#ifdef ENABLE_UPDATE_CHECK
+	return true;
+#else
+	return false;
+#endif
+}
 bool SettingsModel::isCheckForUpdateEnabled() const{
-	return !!mConfig->getInt(UiSection, "check_for_update_enabled", 1);
+	return !!mConfig->getInt(UiSection, "check_for_update_enabled", isCheckForUpdateAvailable());
 }
 
 void SettingsModel::setCheckForUpdateEnabled(bool enable){
@@ -1533,8 +1660,14 @@ void SettingsModel::setCheckForUpdateEnabled(bool enable){
 	emit checkForUpdateEnabledChanged();
 }
 
-QString SettingsModel::getVersionCheckUrl() const{
-	return Utils::coreStringToAppString(mConfig->getString("misc", "version_check_url_root", Constants::VersionCheckReleaseUrl));
+QString SettingsModel::getVersionCheckUrl(){
+	auto url = mConfig->getString("misc", "version_check_url_root", "");
+	if( url == "" ){
+		url = Constants::VersionCheckReleaseUrl;
+		if( url != "")
+			mConfig->setString("misc", "version_check_url_root", url);
+	}
+	return Utils::coreStringToAppString(url);
 }
 
 void SettingsModel::setVersionCheckUrl(const QString& url){
@@ -1603,6 +1736,32 @@ void SettingsModel::setUseMinimalTimelineFilter(const bool& useMinimal) {
 	emit useMinimalTimelineFilterChanged();
 }
 
+Utils::SipDisplayMode SettingsModel::getSipDisplayMode() const{
+	return static_cast<Utils::SipDisplayMode>(mConfig->getInt(UiSection, getEntryFullName(UiSection, "sip_display_mode"), (int)Utils::SipDisplayMode::SIP_DISPLAY_ALL));
+}
+
+void SettingsModel::setSipDisplayMode(Utils::SipDisplayMode mode){
+	if(!isReadOnly(UiSection, "sip_display_mode")) {
+		mConfig->setInt(UiSection, "sip_display_mode", (int)mode);
+		emit sipDisplayModeChanged();
+	}
+}
+
+int SettingsModel::getMagicSearchMaxResults() const {
+	return mConfig->getInt(UiSection, "magic_search_max_results", 30);
+}
+
+void SettingsModel::setMagicSearchMaxResults(int maxResults) {
+	if(getMagicSearchMaxResults() != maxResults){
+		mConfig->setInt(UiSection, "magic_search_max_results", maxResults);
+		emit magicSearchMaxResultsChanged();
+	}
+}
+
+void SettingsModel::resetDontAskAgainChoices(){
+	setDontAskAgainInfoEncryption(false);
+}
+
 // =============================================================================
 // Advanced.
 // =============================================================================
@@ -1667,6 +1826,16 @@ void SettingsModel::setLogsEnabled (bool status) {
 	emit logsEnabledChanged(status);
 }
 
+bool SettingsModel::getFullLogsEnabled () const {
+	return getFullLogsEnabled(mConfig);
+}
+
+void SettingsModel::setFullLogsEnabled (bool status) {
+	mConfig->setInt(UiSection, "full_logs_enabled", status);
+	Logger::getInstance()->enableFullLogs(status);
+	emit fullLogsEnabledChanged();
+}
+
 // ---------------------------------------------------------------------------
 
 QString SettingsModel::getLogsEmail () const {
@@ -1684,6 +1853,58 @@ bool SettingsModel::isLdapAvailable(){
 	return CoreManager::getInstance()->getCore()->ldapAvailable();
 }
 
+bool SettingsModel::isOAuth2Available(){
+	return AssistantModel::isOAuth2Available();
+}
+
+QString SettingsModel::getOAuth2AuthorizationUrl()const{
+	return Utils::coreStringToAppString(
+					    mConfig->getString(UiSection, "oauth2_authorization_url", Constants::OAuth2AuthorizationUrl)
+					    );
+}
+
+QString SettingsModel::getOAuth2AccessTokenUrl()const{
+	return Utils::coreStringToAppString(
+					    mConfig->getString(UiSection, "oauth2_access_token_url", Constants::OAuth2AccessTokenUrl)
+					    );
+}
+
+QString SettingsModel::getOAuth2RedirectUri()const{
+	return Utils::coreStringToAppString(
+					    mConfig->getString(UiSection, "oauth2_redirect_uri", Constants::OAuth2RedirectUri)
+					    );
+}
+
+QString SettingsModel::getOAuth2Identifier()const{
+	return Utils::coreStringToAppString(
+					    mConfig->getString(UiSection, "oauth2_identifier", Constants::OAuth2Identifier)
+					    );
+}
+
+QString SettingsModel::getOAuth2Password()const{
+	return Utils::coreStringToAppString(
+					    mConfig->getString(UiSection, "oauth2_password", Constants::OAuth2Password)
+					    );
+}
+
+QString SettingsModel::getOAuth2Scope()const{
+	return Utils::coreStringToAppString(
+					    mConfig->getString(UiSection, "oauth2_scope", Constants::OAuth2Scope)
+					    );
+}
+
+QString SettingsModel::getOAuth2RemoteProvisioningBasicAuth()const{
+	return Utils::coreStringToAppString(
+					    mConfig->getString(UiSection, "oauth2_remote_provisioning_basic_auth", Constants::RemoteProvisioningBasicAuth)
+					    );
+}
+
+QString SettingsModel::getOAuth2RemoteProvisioningHeader()const{
+	return Utils::coreStringToAppString(
+					    mConfig->getString(UiSection, "oauth2_remote_provisioning_header", Constants::DefaultOAuth2RemoteProvisioningHeader)
+					    );
+}
+
 // ---------------------------------------------------------------------------
 
 QString SettingsModel::getLogsFolder (const shared_ptr<linphone::Config> &config) {
@@ -1696,7 +1917,32 @@ bool SettingsModel::getLogsEnabled (const shared_ptr<linphone::Config> &config)
 	return config ? config->getInt(UiSection, "logs_enabled", false) : true;
 }
 
+bool SettingsModel::getFullLogsEnabled (const shared_ptr<linphone::Config> &config) {
+	return config ? config->getInt(UiSection, "full_logs_enabled", false) : false;
+}
 // ---------------------------------------------------------------------------
+
+bool SettingsModel::getVfsEncrypted (){
+	QSettings settings;
+	settings.beginGroup("keychain");
+	return settings.value("enabled", false).toBool();
+}
+
+void SettingsModel::setVfsEncrypted (bool encrypted, const bool deleteUserData){
+#ifdef ENABLE_QT_KEYCHAIN
+	if(getVfsEncrypted() != encrypted){
+		if(encrypted) {
+			mVfsUtils.newEncryptionKeyAsync();
+		}else{// Remove key, stop core, delete data and initiate reboot
+			mVfsUtils.needToDeleteUserData(deleteUserData);
+			mVfsUtils.deleteKey(mVfsUtils.getApplicationVfsEncryptionKey());
+		}
+	}
+#endif
+}
+
+// ---------------------------------------------------------------------------
+
 bool SettingsModel::isDeveloperSettingsAvailable() const {
 #ifdef DEBUG
 	return true;
