@@ -30,6 +30,11 @@
 #include "components/core/CoreHandlers.hpp"
 #include "components/contacts/ContactsImporterModel.hpp"
 #include "utils/LinphoneEnums.hpp"
+#include "utils/Utils.hpp"
+
+#ifdef ENABLE_QT_KEYCHAIN
+#include "components/vfs/VfsUtils.hpp"
+#endif
 
 // =============================================================================
 class TunnelModel;
@@ -47,6 +52,7 @@ class SettingsModel : public QObject {
 	Q_PROPERTY(bool fetchRemoteConfigurationEnabled READ getFetchRemoteConfigurationEnabled WRITE setFetchRemoteConfigurationEnabled NOTIFY fetchRemoteConfigurationEnabledChanged)
 	Q_PROPERTY(bool useAppSipAccountEnabled READ getUseAppSipAccountEnabled WRITE setUseAppSipAccountEnabled NOTIFY useAppSipAccountEnabledChanged)
 	Q_PROPERTY(bool useOtherSipAccountEnabled READ getUseOtherSipAccountEnabled WRITE setUseOtherSipAccountEnabled NOTIFY useOtherSipAccountEnabledChanged)
+	Q_PROPERTY(bool autoApplyProvisioningConfigUriHandlerEnabled READ getAutoApplyProvisioningConfigUriHandlerEnabled WRITE setAutoApplyProvisioningConfigUriHandlerEnabled NOTIFY autoApplyProvisioningConfigUriHandlerEnabledChanged)
 	
 	Q_PROPERTY(bool assistantSupportsPhoneNumbers READ getAssistantSupportsPhoneNumbers WRITE setAssistantSupportsPhoneNumbers NOTIFY assistantSupportsPhoneNumbersChanged)
 // Webviews config
@@ -93,7 +99,8 @@ class SettingsModel : public QObject {
 	
 	Q_PROPERTY(QVariantMap videoDefinition READ getVideoDefinition WRITE setVideoDefinition NOTIFY videoDefinitionChanged)
 	
-	Q_PROPERTY(bool videoSupported READ getVideoSupported CONSTANT)
+	Q_PROPERTY(bool videoEnabled READ getVideoEnabled WRITE setVideoEnabled NOTIFY videoEnabledChanged)
+	Q_PROPERTY(bool videoAvailable READ getVideoAvailable NOTIFY videoAvailableChanged)
 	
 	Q_PROPERTY(bool showVideoCodecs READ getShowVideoCodecs WRITE setShowVideoCodecs NOTIFY showVideoCodecsChanged)
 	
@@ -189,11 +196,14 @@ class SettingsModel : public QObject {
 	Q_PROPERTY(int dscpVideo READ getDscpVideo WRITE setDscpVideo NOTIFY dscpVideoChanged)
 	
 	Q_PROPERTY(bool rlsUriEnabled READ getRlsUriEnabled WRITE setRlsUriEnabled NOTIFY rlsUriEnabledChanged)
+	Q_PROPERTY(QString rlsUri READ getRlsUri WRITE setRlsUri NOTIFY rlsUriChanged)
 	
 	// UI. -----------------------------------------------------------------------
 	
 	Q_PROPERTY(QFont textMessageFont READ getTextMessageFont WRITE setTextMessageFont NOTIFY textMessageFontChanged)
 	Q_PROPERTY(int textMessageFontSize READ getTextMessageFontSize WRITE setTextMessageFontSize NOTIFY textMessageFontSizeChanged)
+	Q_PROPERTY(QFont emojiFont READ getEmojiFont WRITE setEmojiFont NOTIFY emojiFontChanged)
+	Q_PROPERTY(int emojiFontSize READ getEmojiFontSize WRITE setEmojiFontSize NOTIFY emojiFontSizeChanged)
 	
 	Q_PROPERTY(QString remoteProvisioning READ getRemoteProvisioning WRITE setRemoteProvisioning NOTIFY remoteProvisioningChanged)
 	Q_PROPERTY(QString flexiAPIUrl READ getFlexiAPIUrl WRITE setFlexiAPIUrl NOTIFY flexiAPIUrlChanged)
@@ -213,14 +223,23 @@ class SettingsModel : public QObject {
 	
 	Q_PROPERTY(bool mipmapEnabled READ isMipmapEnabled WRITE setMipmapEnabled NOTIFY mipmapEnabledChanged)
 	Q_PROPERTY(bool useMinimalTimelineFilter READ useMinimalTimelineFilter WRITE setUseMinimalTimelineFilter NOTIFY useMinimalTimelineFilterChanged)
+	Q_PROPERTY(Utils::SipDisplayMode sipDisplayMode READ getSipDisplayMode WRITE setSipDisplayMode NOTIFY sipDisplayModeChanged)
+	Q_PROPERTY(int magicSearchMaxResults READ getMagicSearchMaxResults WRITE setMagicSearchMaxResults NOTIFY magicSearchMaxResultsChanged)
+	
+	Q_PROPERTY(bool dontAskAgainInfoEncryption READ getDontAskAgainInfoEncryption WRITE setDontAskAgainInfoEncryption NOTIFY dontAskAgainInfoEncryptionChanged)
+	Q_PROPERTY(bool haveDontAskAgainChoices READ getHaveDontAskAgainChoices NOTIFY haveDontAskAgainChoicesChanged)
+	
 	
 	// Advanced. -----------------------------------------------------------------
 	
 	Q_PROPERTY(QString logsFolder READ getLogsFolder WRITE setLogsFolder NOTIFY logsFolderChanged)
 	Q_PROPERTY(QString logsUploadUrl READ getLogsUploadUrl WRITE setLogsUploadUrl NOTIFY logsUploadUrlChanged)
 	Q_PROPERTY(bool logsEnabled READ getLogsEnabled WRITE setLogsEnabled NOTIFY logsEnabledChanged)
+	Q_PROPERTY(bool fullLogsEnabled READ getFullLogsEnabled WRITE setFullLogsEnabled NOTIFY fullLogsEnabledChanged)
 	Q_PROPERTY(QString logsEmail READ getLogsEmail WRITE setLogsEmail NOTIFY logsEmailChanged)
 	
+	Q_PROPERTY(bool isVfsEncrypted READ getVfsEncrypted NOTIFY vfsEncryptedChanged)
+	
 	Q_PROPERTY(bool developerSettingsEnabled READ getDeveloperSettingsEnabled WRITE setDeveloperSettingsEnabled NOTIFY developerSettingsEnabledChanged)
 	
 	Q_PROPERTY(bool isInCall READ getIsInCall NOTIFY isInCallChanged)
@@ -270,6 +289,9 @@ public:
 	bool getFetchRemoteConfigurationEnabled () const;
 	void setFetchRemoteConfigurationEnabled (bool status);
 	
+	bool getAutoApplyProvisioningConfigUriHandlerEnabled () const;
+	void setAutoApplyProvisioningConfigUriHandlerEnabled (bool status);
+	
 	bool getUseAppSipAccountEnabled () const;
 	void setUseAppSipAccountEnabled (bool status);
 	
@@ -366,7 +388,10 @@ public:
 	Q_INVOKABLE QVariantMap getCurrentPreviewVideoDefinition () const;
 	void setVideoDefinition (const QVariantMap &definition);
 	
-	bool getVideoSupported () const;
+	bool getVideoEnabled() const;	// Enabled from settings
+	void setVideoEnabled(const bool& enable);
+	bool getVideoAvailable() const; // Enabled and have enough codecs.
+	bool haveAtLeastOneVideoCodec() const;
 	
 	bool getShowVideoCodecs () const;
 	void setShowVideoCodecs (bool status);
@@ -465,6 +490,9 @@ public:
 	
 	bool getPostQuantumAvailable() const;
 	
+	bool getDontAskAgainInfoEncryption() const;
+	void setDontAskAgainInfoEncryption(bool show);
+	
 	bool getLimeState () const;
 	void setLimeState (const bool& state);
 	
@@ -473,6 +501,9 @@ public:
 	
 	int getIncomingCallTimeout() const;
 	
+	int getCreateEphemeralChatRooms() const;
+	void setCreateEphemeralChatRooms(int seconds);// <=0 deactivate
+	
 	// Network. ------------------------------------------------------------------
 	
 	bool getShowNetworkSettings () const;
@@ -535,9 +566,9 @@ public:
 	bool getRlsUriEnabled () const;
 	void setRlsUriEnabled (bool status);
 	
-	void configureRlsUri ();
-	void configureRlsUri (const std::string& domain);
-	void configureRlsUri (const std::shared_ptr<const linphone::Account> &account);
+	QString getRlsUri() const;
+	void setRlsUri (const QString& rlsUri);
+	void updateRlsUri();
 	
 	Q_INVOKABLE bool tunnelAvailable() const;
 	Q_INVOKABLE TunnelModel * getTunnel() const;
@@ -550,6 +581,12 @@ public:
 	int getTextMessageFontSize() const;
 	void setTextMessageFontSize(const int& size);
 	
+	QFont getEmojiFont() const;
+	void setEmojiFont(const QFont& font);
+	
+	int getEmojiFontSize() const;
+	void setEmojiFontSize(const int& size);
+	
 	QString getSavedScreenshotsFolder () const;
 	void setSavedScreenshotsFolder (const QString &folder);
 	
@@ -560,7 +597,7 @@ public:
 	void setDownloadFolder (const QString &folder);
 	
 	QString getRemoteProvisioningRootUrl() const;
-	QString getRemoteProvisioning () const;
+	Q_INVOKABLE QString getRemoteProvisioning () const;
 	void setRemoteProvisioning (const QString &remoteProvisioning);
 	
 	Q_INVOKABLE bool isQRCodeAvailable() const;
@@ -570,10 +607,11 @@ public:
 	bool getExitOnClose () const;
 	void setExitOnClose (bool value);
 	
+	Q_INVOKABLE static bool isCheckForUpdateAvailable();
 	bool isCheckForUpdateEnabled() const;
 	void setCheckForUpdateEnabled(bool enable);
 	
-	QString getVersionCheckUrl() const;
+	QString getVersionCheckUrl();
 	void setVersionCheckUrl(const QString& url);
 	
 	VersionCheckType getVersionCheckType() const;
@@ -591,6 +629,16 @@ public:
 	bool useMinimalTimelineFilter() const;
 	void setUseMinimalTimelineFilter(const bool& useMinimal);
 	
+	Utils::SipDisplayMode getSipDisplayMode() const;
+	void setSipDisplayMode(Utils::SipDisplayMode mode);
+	
+	int getMagicSearchMaxResults() const;
+	void setMagicSearchMaxResults(int maxResults);
+	
+// Show all "don't ask again" checkboxes and popups.
+	bool getHaveDontAskAgainChoices() const;
+	Q_INVOKABLE void resetDontAskAgainChoices();
+	
 	// Advanced. ---------------------------------------------------------------------------
 	
 	
@@ -607,15 +655,33 @@ public:
 	bool getLogsEnabled () const;
 	void setLogsEnabled (bool status);
 	
+	bool getFullLogsEnabled () const;
+	void setFullLogsEnabled (bool status);
+	
 	QString getLogsEmail () const;
 	void setLogsEmail (const QString &email);
 	
+	bool getVfsEncrypted ();
+	Q_INVOKABLE void setVfsEncrypted (bool encrypted, const bool deleteUserData);
+	
 	Q_INVOKABLE bool isLdapAvailable();
 	
+// OAuth 2
+	Q_INVOKABLE bool isOAuth2Available();
+	QString getOAuth2AuthorizationUrl()const;
+	QString getOAuth2AccessTokenUrl()const;
+	QString getOAuth2RedirectUri()const;
+	QString getOAuth2Identifier()const;
+	QString getOAuth2Password()const;
+	QString getOAuth2Scope()const;
+	QString getOAuth2RemoteProvisioningBasicAuth()const;
+	QString getOAuth2RemoteProvisioningHeader()const;
+	
 	// ---------------------------------------------------------------------------
 	
 	static QString getLogsFolder (const std::shared_ptr<linphone::Config> &config);
 	static bool getLogsEnabled (const std::shared_ptr<linphone::Config> &config);
+	static bool getFullLogsEnabled (const std::shared_ptr<linphone::Config> &config);
 	
 	// ---------------------------------------------------------------------------
 	Q_INVOKABLE bool isDeveloperSettingsAvailable() const;
@@ -645,6 +711,7 @@ signals:
 	void fetchRemoteConfigurationEnabledChanged (bool status);
 	void useAppSipAccountEnabledChanged (bool status);
 	void useOtherSipAccountEnabledChanged (bool status);
+	void autoApplyProvisioningConfigUriHandlerEnabledChanged();
 	
 	void assistantSupportsPhoneNumbersChanged (bool status);
 
@@ -680,7 +747,8 @@ signals:
 	void showAudioCodecsChanged (bool status);
 	
 	// Video. --------------------------------------------------------------------
-	
+	void videoEnabledChanged();
+	void videoAvailableChanged();
 	void videoDevicesChanged (const QStringList &devices);
 	void videoDeviceChanged (const QString &device);
 	
@@ -697,6 +765,8 @@ signals:
 	void callCameraModeChanged();
 	void videoConferenceLayoutChanged();
 	
+	void haveAtLeastOneVideoCodecChanged();
+	
 	// Chat & calls. -------------------------------------------------------------
 	
 	void autoAnswerStatusChanged (bool status);
@@ -737,6 +807,8 @@ signals:
 	
 	void contactsEnabledChanged (bool status);
 	
+	void createEphemeralsChatRoomsChanged();
+	
 	// Network. ------------------------------------------------------------------
 	
 	void showNetworkSettingsChanged (bool status);
@@ -769,12 +841,16 @@ signals:
 	void dscpVideoChanged (int dscp);
 	
 	void rlsUriEnabledChanged (bool status);
+	void rlsUriChanged ();
 		
 	// UI. -----------------------------------------------------------------------
 	
 	void textMessageFontChanged(const QFont& font);
 	void textMessageFontSizeChanged(const int& size);
 	
+	void emojiFontChanged(const QFont& font);
+	void emojiFontSizeChanged(const int& size);
+	
 	void savedScreenshotsFolderChanged (const QString &folder);
 	void savedCallsFolderChanged (const QString &folder);
 	void downloadFolderChanged (const QString &folder);
@@ -787,16 +863,25 @@ signals:
 	void mipmapEnabledChanged();
 	void useMinimalTimelineFilterChanged();
 	
+	void sipDisplayModeChanged();
+	
 	void checkForUpdateEnabledChanged();
 	void versionCheckUrlChanged();
 	void versionCheckTypeChanged();
 	
+	void magicSearchMaxResultsChanged();
+	
+	void dontAskAgainInfoEncryptionChanged();
+	void haveDontAskAgainChoicesChanged();
+	
 	// Advanced. -----------------------------------------------------------------
 	
 	void logsFolderChanged (const QString &folder);
 	void logsUploadUrlChanged (const QString &url);
 	void logsEnabledChanged (bool status);
+	void fullLogsEnabledChanged ();
 	void logsEmailChanged (const QString &email);
+	void vfsEncryptedChanged();
 	
 	void contactImporterChanged();
 	
@@ -808,6 +893,9 @@ private:
 	int mCurrentSettingsTab = 0;
 	MediastreamerUtils::SimpleCaptureGraph *mSimpleCaptureGraph = nullptr;
 	int mCaptureGraphListenerCount = 0;
+#ifdef ENABLE_QT_KEYCHAIN
+	VfsUtils mVfsUtils;
+#endif
 	
 	std::shared_ptr<linphone::Config> mConfig;
 };
