@@ -51,6 +51,7 @@ public:
 	QSharedPointer<ChatRoomModel> getChatRoomModel(ChatRoomModel * chatRoom);
   
 	void add (QSharedPointer<TimelineModel> timeline);	// Use to add a timeline that is not in Linphone list (like empty chat rooms that were hide by configuration)
+	void add (QList<QSharedPointer<TimelineModel>> timelines);
 
 	Q_INVOKABLE void select(ChatRoomModel * chatRoomModel);
 	void setSelectedCount(int selectedCount);
@@ -66,13 +67,13 @@ public slots:
 	void onChatRoomStateChanged(const std::shared_ptr<linphone::ChatRoom> &chatRoom,linphone::ChatRoom::State state);
 	void onCallStateChanged (const std::shared_ptr<linphone::Call> &call, linphone::Call::State state) ;
 	void onCallCreated(const std::shared_ptr<linphone::Call> &call);
-	void onChatRoomDeleted();
+	void onTimelineDeleted();
+	void onTimelineDataChanged();
 	
 signals:
 	void countChanged();
 	void selectedCountChanged(int selectedCount);
 	void selectedChanged(TimelineModel * timelineModel);
-	void updated();
 
 private:
 	virtual bool removeRows (int row, int count, const QModelIndex &parent) override;
