@@ -18,6 +18,8 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <QAction>
+#include <QBitmap>
 #include <QFileInfo>
 #include <QCoreApplication>
 #include <QCryptographicHash>
@@ -26,19 +28,32 @@
 #include <QFile>
 #include <QImageReader>
 #include <QDebug>
+#include <QMimeDatabase>
 #include <QTimeZone>
 #include <QUrl>
 
+#ifdef PDF_ENABLED
+#include <QtPdf/QPdfDocument>
+#include <QtPdfWidgets/QPdfView>
+#include "components/pdf/PdfWidget.hpp"
+#endif
+
 #include "config.h"
 #include "Utils.hpp"
 #include "UriTools.hpp"
+#include "app/App.hpp"
+#include "app/paths/Paths.hpp"
+#include "app/providers/ImageProvider.hpp"
 #include "components/core/CoreManager.hpp"
+#include "components/other/colors/ColorListModel.hpp"
+#include "components/other/colors/ColorModel.hpp"
 #include "components/contacts/ContactsListModel.hpp"
 #include "components/contact/ContactModel.hpp"
 #include "components/contact/VcardModel.hpp"
 #include "components/settings/AccountSettingsModel.hpp"
 #include "components/settings/SettingsModel.hpp"
-#include "app/paths/Paths.hpp"
+#include "components/sip-addresses/SipAddressesModel.hpp"
+
 
 #ifdef _WIN32
 #include <time.h>
@@ -52,12 +67,13 @@ constexpr int SafeFilePathLimit = 100;
 }
 
 std::shared_ptr<linphone::Address> Utils::interpretUrl(const QString& address){
-	auto interpretedAddress = CoreManager::getInstance()->getCore()->interpretUrl(Utils::appStringToCoreString(address), true);
+	bool usePrefix = CoreManager::getInstance()->getAccountSettingsModel()->getUseInternationalPrefixForCallsAndChats();
+	auto interpretedAddress = CoreManager::getInstance()->getCore()->interpretUrl(Utils::appStringToCoreString(address), usePrefix);
 	if(!interpretedAddress){// Try by removing scheme.
 		QStringList splitted = address.split(":");
 		if(splitted.size() > 0 && splitted[0] == "sip"){
 			splitted.removeFirst();
-			interpretedAddress = CoreManager::getInstance()->getCore()->interpretUrl(Utils::appStringToCoreString(splitted.join(":")), true);
+			interpretedAddress = CoreManager::getInstance()->getCore()->interpretUrl(Utils::appStringToCoreString(splitted.join(":")), usePrefix);
 		}
 	}
 	return interpretedAddress;
@@ -79,13 +95,13 @@ char *Utils::rstrstr (const char *a, const char *b) {
 
 // -----------------------------------------------------------------------------
 
-bool Utils::hasCapability(const QString& address, const LinphoneEnums::FriendCapability& capability){
+bool Utils::hasCapability(const QString& address, const LinphoneEnums::FriendCapability& capability, bool defaultCapability){
 	auto addressCleaned = cleanSipAddress(address);
 	auto contact = CoreManager::getInstance()->getContactsListModel()->findContactModelFromSipAddress(addressCleaned);
 	if(contact)
 		return contact->hasCapability(capability);
 	else
-		return false;
+		return defaultCapability;
 }
 
 QDateTime Utils::addMinutes(QDateTime date, const int& min){
@@ -113,14 +129,48 @@ QString Utils::toTimeString(QDateTime date, const QString& format){
 	return getOffsettedUTC(date).toString(format);
 }
 
-QString Utils::toDateString(QDateTime date){
-	return getOffsettedUTC(date).toString("yyyy/MM/dd");
+QString Utils::toDateString(QDateTime date, const QString& format){
+	return QLocale().toString(getOffsettedUTC(date), (!format.isEmpty() ? format : QLocale().dateFormat()) );
+}
+
+// Return custom address to be displayed on UI.
+// In order to return only the username and to remove all domains from the GUI, you may just change the default mode.
+QString Utils::toDisplayString(const QString& str, SipDisplayMode displayMode){
+	if(displayMode == SIP_DISPLAY_ALL) return str;
+	std::shared_ptr<linphone::Address> addr = linphone::Factory::get()->createAddress(str.toStdString());
+	QString displayString;
+	if( addr && ( (displayMode & SIP_DISPLAY_USERNAME) == SIP_DISPLAY_USERNAME))
+		displayString = Utils::coreStringToAppString(addr->getUsername());
+	if(displayString.isEmpty())
+		return str;
+	else
+		return displayString;
 }
 
 QString Utils::getDisplayName(const QString& address){
 	return getDisplayName(interpretUrl(address));
 }
 
+QString Utils::getInitials(const QString& username){
+	if(username.isEmpty()) return "";
+	
+	QRegularExpression regex("[\\s\\.]+");
+	QStringList words = username.split(regex);// Qt 5.14: Qt::SkipEmptyParts
+	QStringList initials;
+	auto str32 = words[0].toStdU32String();
+	std::u32string char32;
+	char32 += str32[0];
+	initials << QString::fromStdU32String(char32);
+	for(int i = 1; i < words.size() && initials.size() <= 1 ; ++i) {
+		if( words[i].size() > 0){
+			str32 = words[i].toStdU32String();
+			char32[0] = str32[0];
+			initials << QString::fromStdU32String(char32);
+		}
+	}
+	return  App::getInstance()->getLocale().toUpper(initials.join(""));
+}
+
 QString Utils::toString(const LinphoneEnums::TunnelMode& mode){
 	switch(mode){
 	case LinphoneEnums::TunnelMode::TunnelModeEnable :
@@ -507,29 +557,7 @@ void Utils::copyDir(QString from, QString to) {
 QString Utils::getDisplayName(const std::shared_ptr<const linphone::Address>& address){
 	QString displayName;
 	if(address){
-		std::shared_ptr<linphone::Address> cleanAddress = address->clone();
-		cleanAddress->clean();
-		QString qtAddress = Utils::coreStringToAppString(cleanAddress->asStringUriOnly());
-		auto model = CoreManager::getInstance()->getContactsListModel()->findContactModelFromSipAddress(qtAddress);
-		if(model && model->getVcardModel())
-			displayName = model->getVcardModel()->getUsername();
-		else{
-			// Try to get display from full address
-			displayName = QString::fromStdString(address->getDisplayName());
-			if( displayName == ""){
-				// Try to get display name from logs
-				auto callHistory = CoreManager::getInstance()->getCore()->getCallLogs();
-				auto callLog = std::find_if(callHistory.begin(), callHistory.end(), [address](std::shared_ptr<linphone::CallLog>& cl){
-						return cl->getRemoteAddress()->weakEqual(address);
-				});
-				if(callLog != callHistory.end())
-					displayName = QString::fromStdString((*callLog)->getRemoteAddress()->getDisplayName());
-				if(displayName == "")
-					displayName = QString::fromStdString(address->getDisplayName());
-				if(displayName == "")
-					displayName = Utils::coreStringToAppString(address->getUsername());
-			}
-		}
+		displayName = CoreManager::getInstance()->getSipAddressesModel()->getDisplayName(address);
 	}
 	return displayName;
 }
@@ -542,11 +570,26 @@ std::shared_ptr<linphone::Config> Utils::getConfigIfExists (const QString &confi
 	return linphone::Config::newWithFactory(configPath.toStdString(), factoryPath);
 }
 
+QString Utils::getApplicationProduct(){
+// Note: Keep '-' as a separator between application name and application type
+	return QString(APPLICATION_NAME"-Desktop").remove(' ')+"/"+QCoreApplication::applicationVersion();
+}
+
+QString Utils::getOsProduct(){
+	QString version = QSysInfo::productVersion().remove(' ');// A version can be "Server 2016" (for Windows Server 2016)
+	QString product = QSysInfo::productType().replace(' ', '-');	// Just in case
+	return product+"/"+version;
+}
+
 QString Utils::computeUserAgent(const std::shared_ptr<linphone::Config>& config){
-	return QStringLiteral(APPLICATION_NAME" Desktop/%1 (%2) %3, Qt %4 LinphoneCore")
-					.arg(QCoreApplication::applicationVersion())
-					.arg(SettingsModel::getDeviceName(config))
-					.arg(QSysInfo::prettyProductName())
+	return QStringLiteral("%1 (%2) %3 Qt/%4 LinphoneSDK")
+					.arg(Utils::getApplicationProduct())
+					.arg(SettingsModel::getDeviceName(config)
+							.replace('\\', "\\\\")
+							.replace('(', "\\(")
+							.replace(')', "\\)")
+					)
+					.arg(Utils::getOsProduct())
 					.arg(qVersion());
 }
 
@@ -559,11 +602,43 @@ bool Utils::isMe(const std::shared_ptr<const linphone::Address>& address){
 }
 
 bool Utils::isAnimatedImage(const QString& path){
+	if(path.isEmpty()) return false;
 	QFileInfo info(path);
-	if( !info.exists())
+	if( !info.exists() || !QMimeDatabase().mimeTypeForFile(info).name().contains("image/"))
 		return false;
 	QImageReader reader(path);
-	return reader.supportsAnimation() && reader.imageCount() > 1;
+	return reader.canRead() && reader.supportsAnimation() && reader.imageCount() > 1;
+}
+
+bool Utils::isImage(const QString& path){
+	if(path.isEmpty()) return false;
+	QFileInfo info(path);
+	if( !info.exists() || CoreManager::getInstance()->getSettingsModel()->getVfsEncrypted()){
+		return QMimeDatabase().mimeTypeForFile(info, QMimeDatabase::MatchExtension).name().contains("image/");
+	}else if(!QMimeDatabase().mimeTypeForFile(info).name().contains("image/"))
+		return false;
+	QImageReader reader(path);
+	return reader.canRead() && reader.imageCount() == 1;
+}
+
+bool Utils::isVideo(const QString& path){
+	if(path.isEmpty()) return false;
+	return QMimeDatabase().mimeTypeForFile(path).name().contains("video/");
+}
+
+bool Utils::isPdf(const QString& path){
+	if(path.isEmpty()) return false;
+	return QMimeDatabase().mimeTypeForFile(path).name().contains("application/pdf");
+}
+
+bool Utils::isSupportedForDisplay(const QString& path){
+	if(path.isEmpty()) return false;
+	return !QMimeDatabase().mimeTypeForFile(path).name().contains("application");// "for pdf : "application/pdf". Note : Make an exception when supported.
+}
+
+bool Utils::canHaveThumbnail(const QString& path){
+	if(path.isEmpty()) return false;
+	return isImage(path) || isAnimatedImage(path) || isPdf(path) || isVideo(path);
 }
 
 bool Utils::isPhoneNumber(const QString& txt){
@@ -574,6 +649,16 @@ bool Utils::isPhoneNumber(const QString& txt){
 	return account && account->isPhoneNumber(Utils::appStringToCoreString(txt));
 }
 
+bool Utils::isUsername(const QString& txt){
+	QRegularExpression regex("^(<?sips?:)?[a-zA-Z0-9+_.\\-]+>?$");
+	QRegularExpressionMatch match = regex.match(txt);
+	return match.hasMatch(); // true
+}
+
+bool Utils::isValidUrl(const QString& url){
+	return QUrl(url).isValid();
+}
+
 QSize Utils::getImageSize(const QString& url){
 	QString path;
 	QUrl urlDecode(url);
@@ -606,45 +691,167 @@ QString Utils::getFileChecksum(const QString& filePath){
     }
     return QString();
 }
+bool Utils::codepointIsEmoji(uint code){
+        return (code >= 0x2600 && code <= 0x27bf) || (code >= 0x2b00 && code <= 0x2bff) ||
+               (code >= 0x1f000 && code <= 0x1faff) || code == 0x200d || code == 0xfe0f;
+}
+
+bool Utils::codepointIsVisible(uint code) {
+	return code > 0x00020;
+}
+
+QString Utils::encodeEmojiToQmlRichFormat(const QString &body){
+	QString fmtBody = "";
+	QVector<uint> utf32_string = body.toUcs4();
+	
+	bool insideFontBlock = false;
+	for (auto &code : utf32_string) {
+		if (Utils::codepointIsEmoji(code)) {
+			if (!insideFontBlock) {
+				fmtBody += QString("<font face=\"" +
+								   CoreManager::getInstance()->getSettingsModel()->getEmojiFont().family() + "\">");
+				insideFontBlock = true;
+			}
+		} else {
+			if (insideFontBlock) {
+				fmtBody += "</font>";
+				insideFontBlock = false;
+			}
+		}
+		fmtBody += QString::fromUcs4(&code, 1);
+	}
+	if (insideFontBlock) {
+		fmtBody += "</font>";
+	}
+	return fmtBody;
+}
+
+bool Utils::isOnlyEmojis(const QString& text){
+	if(text.isEmpty()) return false;
+	QVector<uint> utf32_string = text.toUcs4();
+	for (auto &code : utf32_string)
+		if(codepointIsVisible(code) && !Utils::codepointIsEmoji(code))
+			return false;
+	return true;
+}
+
 
 QString Utils::encodeTextToQmlRichFormat(const QString& text, const QVariantMap& options){
-	
-	QString images;
-	QStringList formattedText;
+	/*QString images;
 	QStringList imageFormat;
 	for(auto format : QImageReader::supportedImageFormats())
 		imageFormat.append(QString::fromLatin1(format).toUpper());
-	auto iriParsed = UriTools::parseIri(text);
-	for(int i = 0 ; i < iriParsed.size() ; ++i){
-		QString iri = iriParsed[i].second.replace('&', "&amp;")
-					.replace('<', "\u2063&lt;")
-					.replace('>', "\u2063&gt;")
-					.replace('"', "&quot;")
-					.replace('\'', "&#039;");
-		if(!iriParsed[i].first)
-			formattedText.append(iri);
-		else{
-			QString uri = iriParsed[i].second.left(3) == "www" ? "http://"+iriParsed[i].second : iriParsed[i].second ;
-			int extIndex = iriParsed[i].second.lastIndexOf('.');
-			QString ext;
-			if( extIndex >= 0)
-				ext = iriParsed[i].second.mid(extIndex+1).toUpper();
-			if(imageFormat.contains(ext.toLatin1())){// imagesHeight is not used because of bugs on display (blank image if set without width)
-				images += "<a href=\"" + uri + "\"><img" + (
-						options.contains("imagesWidth")
-							? QString(" width='") + options["imagesWidth"].toString() + "'"
+	*/
+	QStringList formattedText;
+	bool lastWasUrl = false;
+	
+	if(options.contains("noLink") && options["noLink"].toBool()){
+		formattedText.append(encodeEmojiToQmlRichFormat(text));
+	}else{
+		auto primaryColor = App::getInstance()->getColorListModel()->getColor("i")->getColor();
+		auto iriParsed = UriTools::parseIri(text);
+		
+		for(int i = 0 ; i < iriParsed.size() ; ++i){
+			QString iri = iriParsed[i].second.replace('&', "&amp;")
+						.replace('<', "\u2063&lt;")
+						.replace('>', "\u2063&gt;")
+						.replace('"', "&quot;")
+						.replace('\'', "&#039;");
+			if(!iriParsed[i].first){
+				if(lastWasUrl){
+					lastWasUrl = false;
+					if(iri.front() != ' ')
+						iri.push_front(' ');
+				}
+				formattedText.append(encodeEmojiToQmlRichFormat(iri));
+			}else{
+				QString uri = iriParsed[i].second.left(3) == "www" ? "http://"+iriParsed[i].second : iriParsed[i].second ;
+				/* TODO : preview from link
+				int extIndex = iriParsed[i].second.lastIndexOf('.');
+				QString ext;
+				if( extIndex >= 0)
+					ext = iriParsed[i].second.mid(extIndex+1).toUpper();
+				if(imageFormat.contains(ext.toLatin1())){// imagesHeight is not used because of bugs on display (blank image if set without width)
+					images += "<a href=\"" + uri + "\"><img" + (
+							options.contains("imagesWidth")
+								? QString(" width='") + options["imagesWidth"].toString() + "'"
+								: ""
+						) + (
+							options.contains("imagesWidth")
+							? QString(" height='auto'")
 							: ""
-					) + (
-						options.contains("imagesWidth")
-						? QString(" height='auto'")
-						: ""
-					) + " src=\"" + iriParsed[i].second + "\" /></a>";
-			}else
-				formattedText.append( "<a href=\"" + uri + "\">" + iri + "</a>");
+						) + " src=\"" + iriParsed[i].second + "\" />"+uri+"</a>";
+				}else{
+				*/
+					formattedText.append( "<a style=\"color:"+ primaryColor.name() +";\" href=\"" + uri + "\">" + iri + "</a>");
+					lastWasUrl = true;
+				/*}*/
+			}
 		}
 	}
-	if(images != "")
-		images = "<div>" + images +"</div>";
-	
-	return images + "<p style=\"white-space:pre-wrap;\">" + formattedText.join("") + "</p>";
-}
\ No newline at end of file
+	if(lastWasUrl && formattedText.last().back() != ' '){
+		formattedText.push_back(" ");
+	}
+	return "<p style=\"white-space:pre-wrap;\">" + formattedText.join("") + "</p>";
+}
+
+QString Utils::getFileContent(const QString& filePath){
+	QString contents;
+	QFile file(filePath);
+	if (!file.open(QFile::ReadOnly | QFile::Text))
+		return "";
+	return file.readAll();
+}
+static QStringList gDbPaths;
+
+void Utils::deleteAllUserData(){
+// Store usable data like custom folders
+	gDbPaths.clear();
+	gDbPaths.append(Utils::coreStringToAppString(linphone::Factory::get()->getDataDir(nullptr)));
+	gDbPaths.append(Utils::coreStringToAppString(linphone::Factory::get()->getConfigDir(nullptr)));
+// Exit with a delete code
+	App::getInstance()->exit(App::DeleteDataCode);
+}
+
+void Utils::deleteAllUserDataOffline(){
+	qWarning() << "Deleting all data! ";
+	for(int i = 0 ; i < gDbPaths.size() ; ++i){
+		QDir dir(gDbPaths[i]);
+		qWarning() << "Deleting " << gDbPaths[i] << " : " << (dir.removeRecursively() ? "Successfully" : "Failed");
+	}
+}
+
+//-------------------------------------------------------------------------------------------------------
+//					WIDGETS
+//-------------------------------------------------------------------------------------------------------
+
+bool Utils::openWithPdfViewer(ContentModel * contentModel, const QString& filePath, const int& width, const int& height) {
+#ifdef PDF_ENABLED
+	PdfWidget *view = new PdfWidget(contentModel);
+	view->setMinimumSize(QSize(width, height));
+	view->show();
+	view->open(filePath);
+	return true;
+#else
+	return false;
+#endif
+}
+
+void Utils::setFamilyFont(QAction * dest, const QString& family){
+	QFont font(dest->font());
+	font.setFamily(family);
+	dest->setFont(font);
+}
+void Utils::setFamilyFont(QWidget * dest, const QString& family){
+	QFont font(dest->font());
+	font.setFamily(family);
+	dest->setFont(font);
+}
+QPixmap Utils::getMaskedPixmap(const QString& name, const QColor& color){
+	QSize size;
+	QPixmap img = ImageProvider::computePixmap(name, &size);
+	QPixmap pxr( img.size() );
+	pxr.fill( color );
+	pxr.setMask( img.createMaskFromColor( Qt::transparent ) );
+	return pxr;
+}
