@@ -32,6 +32,9 @@
 #include "LinphoneEnums.hpp"
 #include "Constants.hpp"
 
+class QAction;
+class QWidget;
+
 // =============================================================================
 
 /*
@@ -46,27 +49,52 @@
 #endif // if defined(__GNUC__) && __GNUC__ >= 7
 #endif // ifndef UTILS_NO_BREAK
 
+class ContentModel;
 
 class Utils : public QObject{
 	Q_OBJECT
 public:
 	Utils(QObject * parent = nullptr) : QObject(parent){}
+	
+	typedef enum{
+		SIP_DISPLAY_USERNAME = 0,
+		SIP_DISPLAY_ALL = -1
+	}SipDisplayMode;
+	Q_ENUM(SipDisplayMode)
+	
 	// Qt interfaces	
-	Q_INVOKABLE static bool hasCapability(const QString& address, const LinphoneEnums::FriendCapability& capability);
+	Q_INVOKABLE static bool hasCapability(const QString& address, const LinphoneEnums::FriendCapability& capability, bool defaultCapability = true);
 	Q_INVOKABLE static QDateTime addMinutes(QDateTime date, const int& min);
 	static QDateTime getOffsettedUTC(const QDateTime& date);
 	Q_INVOKABLE static QString toDateTimeString(QDateTime date);
 	Q_INVOKABLE static QString toTimeString(QDateTime date, const QString& format = "hh:mm:ss");
-	Q_INVOKABLE static QString toDateString(QDateTime date);
+	Q_INVOKABLE static QString toDateString(QDateTime date, const QString& format = "");
+	Q_INVOKABLE static QString toDisplayString(const QString& str, SipDisplayMode displayMode = SIP_DISPLAY_ALL);
+	static void cleanDisplayNameCache(const QString& address = "");// if "", clean all cache
 	Q_INVOKABLE static QString getDisplayName(const QString& address);
+	Q_INVOKABLE static QString getInitials(const QString& username);	// Support UTF32
 	Q_INVOKABLE static QString toString(const LinphoneEnums::TunnelMode& mode);
 	Q_INVOKABLE static bool isMe(const QString& address);
 	Q_INVOKABLE static bool isAnimatedImage(const QString& path);
+	Q_INVOKABLE static bool isImage(const QString& path);
+	Q_INVOKABLE static bool isVideo(const QString& path);
+	Q_INVOKABLE static bool isPdf(const QString& path);
+	Q_INVOKABLE static bool isSupportedForDisplay(const QString& path);
+	Q_INVOKABLE static bool canHaveThumbnail(const QString& path);
 	Q_INVOKABLE static bool isPhoneNumber(const QString& txt);
+	Q_INVOKABLE static bool isUsername(const QString& txt);	// Check with Regex
+	Q_INVOKABLE static bool isValidUrl(const QString& url);
 	Q_INVOKABLE QSize getImageSize(const QString& url);
 	Q_INVOKABLE static QPoint getCursorPosition();
 	Q_INVOKABLE static QString getFileChecksum(const QString& filePath);
-	Q_INVOKABLE static QString encodeTextToQmlRichFormat(const QString& text, const QVariantMap& options);
+	static bool codepointIsEmoji(uint code);
+	static bool codepointIsVisible(uint code);
+	Q_INVOKABLE static bool isOnlyEmojis(const QString& text);
+	Q_INVOKABLE static QString encodeEmojiToQmlRichFormat(const QString &body);
+	Q_INVOKABLE static QString encodeTextToQmlRichFormat(const QString& text, const QVariantMap& options = QVariantMap());
+	Q_INVOKABLE static QString getFileContent(const QString& filePath);
+	
+	Q_INVOKABLE static bool openWithPdfViewer(ContentModel *contentModel, const QString& filePath, const int& width, const int& height);	// return true if PDF is enabled
 	
 //----------------------------------------------------------------------------------
 	
@@ -142,10 +170,18 @@ public:
 	static void copyDir(QString from, QString to);// Copy a folder recursively without erasing old file
 	static QString getDisplayName(const std::shared_ptr<const linphone::Address>& address);	// Get the displayname from addres in this order : Friends, Contact, Display address, Username address
 	static std::shared_ptr<linphone::Config> getConfigIfExists (const QString& configPath);
+	static QString getApplicationProduct();
+	static QString getOsProduct();
 	static QString computeUserAgent(const std::shared_ptr<linphone::Config>& config);
 	
 	static bool isMe(const std::shared_ptr<const linphone::Address>& address);
 	
+	static void deleteAllUserData();
+	static void deleteAllUserDataOffline();// When we are out of all events and core is not running (aka in main())
+	
+	static void setFamilyFont(QAction * dest, const QString& family);
+	static void setFamilyFont(QWidget * dest, const QString& family);
+	static QPixmap getMaskedPixmap(const QString& name, const QColor& color);
 };
 
 #endif // UTILS_H_
