@@ -44,6 +44,9 @@ var SCHEME_REGEX = new RegExp('^[^:]+:')
 function buildCommonDialogUri (component) {
   return 'qrc:/ui/modules/Common/Dialog/' + component + '.qml'
 }
+function buildCommonUri (component, subComponent) {
+  return 'qrc:/ui/modules/Common/'+subComponent+'/' + component + '.qml'
+}
 
 function buildLinphoneDialogUri (component) {
   return 'qrc:/ui/modules/Linphone/Dialog/' + component + '.qml'
@@ -260,7 +263,7 @@ function _indexFinder (array, cb, context) {
   var length = array.length
 
   for (var i = 0; i < length; i++) {
-    if (cb(array[i], i, array)) {
+    if (cb( (array.getAt ? array.getAt(i) : array[i]), i, array)) {
       return i
     }
   }
@@ -492,14 +495,6 @@ function fromUTC(date){
                 date.getUTCDate(), date.getUTCHours(),
                 date.getUTCMinutes(), date.getUTCSeconds()));
 }
-// return EXACTLY what date has been set (not take account of Locale timezones, eg. Date(2000,0,1) will print january and not december if timezone lead there.)
-// Use this function for toLocaleString/toLocaleDateString or other
-function exactDate(date) {
-    var timeOffset = date.getTimezoneOffset() * 60000
-    var exactDate = new Date(date.valueOf() - timeOffset)
-    return exactDate
-}
-
 // -----------------------------------------------------------------------------
 
 function formatSize (size) {
@@ -577,23 +572,20 @@ function getExtension (str) {
 // Test if a value is included in an array or object.
 function includes (obj, value, startIndex) {
   obj = ensureArray(obj)
-
   if (startIndex == null) {
     startIndex = 0
   }
-
   var length = obj.length
 
   for (var i = startIndex; i < length; i++) {
     if (
-      value === obj[i] ||
+      value == obj[i] ||
       // Check `NaN`.
       (value !== value && obj[i] !== obj[i])
     ) {
       return true
     }
   }
-
   return false
 }
 
@@ -725,5 +717,8 @@ function printObject(o) {
   for (var p in o) {
     out += p + ': ' + o[p] + '\n';
   }
-  return out;
+  if(!o)
+    return 'Empty'
+  else
+    return out;
 }
